buildsubgridindex <- function(index, window, id.field, buffer=0, limit.extent=TRUE){
  # This function is used by the indexed versions of gridstich and gridsplit
  # it isn't intended for general use but is public right now as that makes debugging easier.
  #   Arguments :
  #     index : the path to a polygon shapefile that specifies how the grid should be cut upt
  #     window : the extent of the access window for the complete grid (basically the result of 
  #       a call to griddescribe on the refrence grid.)
  #     id.field : the name of a field in index or if missing than id's will just be numbered sequentiall
  #     buffer : the amount of space around each grid that should be buffered.
  
  # window <- cdesc
  
  index <- gsub("\\\\", "/", index) # in case \ is used as the separator
  indexdir <- gsub("/[^/]+$","",  index)
  indexname <- gsub("^.*/|[.]shp$", "", index)
  cat("Reading index shapefile.\n")
  ind <- readOGR(dsn=indexdir, layer=indexname, verbose=TRUE)
  if(!missing(id.field) && !id.field %in% names(ind)) 
    stop("The id.field '", id.field,  "'' isn't one of the fields in '", index, "'.", sep="" )
  n <- nrow(ind)
  bounds <- matrix(as.numeric(NA), nrow=n, ncol=4, dimnames=list(1:n, c("xmin", "xmax", "ymin", "ymax")))
  for(i in 1:nrow(ind)){
    polygon <- ind[i, ]
    bounds[i, ] <- as.numeric(t(as.matrix(bbox(polygon))))    
  }
  
  # make buffered version of the bounds
  bbounds <- bounds
  bbounds[, c(1, 3)] <- bounds[, c(1, 3)] - ( buffer * window$cellsize)
  bbounds[, c(2, 4)] <- bounds[, c(2, 4)] + ( buffer * window$cellsize)
  if(FALSE){  # plotting code for debugging / visualization
    #
    setwindow(complete)
    g <- readgrid(complete)
    plot(NA, NA, xlim=range(bounds[, 1:2]), ylim=range(bounds[, 3:4]), asp=1)
    plot(g, add=T)
    for(i in 1:nrow(bounds)) polygon(x=bounds[i, c(1,1, 2, 2)], y=bounds[i, c(3, 4, 4, 3)],
                                     border=rgb(1, 0, 0, .6))
    for(i in 1:nrow(bbounds)) polygon(x=bbounds[i, c(1,1, 2, 2)], y=bbounds[i, c(3, 4, 4, 3)], 
                                      border=rgb(0, 0, 1, .6))
    i <- 1
    polygon(x=bbounds[i, c(1,1, 2, 2)], y=bbounds[i, c(3, 4, 4, 3)], 
            border=rgb(0, 1, 0, .6))
  }
  
  # Filter to just the entities that overlap the complete extent
  xmin <- window$xll
  xmax <- window$xll  + window$cellsize * window$ncol
  ymin <- window$yll
  ymax <- window$yll  + window$cellsize * window$nrow
  bbounds <- as.data.frame(bbounds)
  bounds <- as.data.frame(bounds)
  # sv <- bbounds$xmax > xmin & bbounds$xmin <= xmax & bbounds$ymax > ymin & bbounds$ymin <= ymax 
  sv <- bounds$xmax > xmin & bounds$xmin <= xmax & bounds$ymax > ymin & bounds$ymin <= ymax 
  ind <- ind[sv, ]
  bounds <- bounds[sv, ]
  bbounds <- bbounds[sv, ]
  
  # create vector of id's
  if(!missing(id.field)){
    ids <- ind[[id.field]]
  } else {
    ids <- 1:nrow(ind)      
  }
  
  # Limit the bbounds to either the extent of the complete grid or the extent + buffer based on 
  #  the limit.extent argument. This clips off the portion of the polygons that extends 
  #   way beyond the original extent.
  for(a in (c("xmin", "ymin", "xmax", "ymax"))){
    if(grepl("min", a)){
      val <-  ifelse(limit.extent, get(a),  get(a) - (buffer * window$cellsize))
      sv <- bbounds[[a]] < val 
    } else { 
      val <- ifelse(limit.extent, get(a),  get(a) + (buffer * window$cellsize))
      sv <- bbounds[[a]] > val 
    }
    bbounds[[a]][sv] <- val
  }
  return(list(ind=ind, ids=ids, bounds=bounds, bbounds=bbounds))
  
}
