# Example Code
if(FALSE){ # Skip
  
  # Make example data and plot it
  data <- data.frame(x= runif(1000, 0, 1000), y=runif(1000, 0, 1000), bin=sample(rep(1:5, 200)), id=1:1000)
  min.dist=50
  plot(data[, c("x", "y")], col="grey") # plot the data points
  lines(x=c(0, min.dist), y=c(-25, -25)) # the distance threshold we are using
  
  # Make selection and plot it
  s <- constrainedsample(data=data, min.dist=min.dist, bincol="bin", n=20)
  points(s[, c("x", "y")], col="red")
  
  # Examine selection
  table(s$bin)  
  d <- dist(s[, c("x", "y")])
  min(d)
  if(min(d) < min.dist) stop("No points should be selected less than the min.dist threshold")
}

constrainedsample <- function(data, min.dist, xcol="x", ycol="y",  bincol=NULL, n){
  # This function randomly selects points from a dataset maintaining a minimum distance constraint. 
  #  data - a data frame containing the data to be sampled.
  #  min.dist - the distance constraint for the sampling points within this distance of other 
  #   selected points will be rejected.
  #  xcol, ycol - the name of x and y columns in data. Required.
  #  bincol - optional the name of a column containing bins (strata) for the sampling.  
  #    selection will occur evenly accross bins for as long as possible. If not specified than no bins
  #    are used.  
  #  n - the number of points to select for each bin (or in total if there are no bins.)
  #    
  data <- as.data.frame(data)
  
  if(missing(n)) n <- nrow(data) 
  
  if(! min.dist > 0) stop("min.dist must be greater than zero")
  x <- data[[xcol]]
  y <- data[[ycol]]
  if (is.null(bincol)) bin <- rep(1, length(x)) else bin <- data[[bincol]]
  bins <- sort(unique(bin))
  available <- rep(TRUE, length(x)) # indicated which rows are still available for selection
	
  selected <- matrix(NA, ncol=length(bins), nrow=n)  # Will hold the row numbers selected for each bin.
  random <- sample(1:length(x), size=length(x), replace=FALSE)
  colnames(selected) <- bins
  
  current.row <- 1  # Keeps track of the first empty row in selected - where we save data from the loop 
  
  while(sum(available) > 0 & current.row < n+1){
    for(i in 1:length(bins)){
      current.bin <- bins[i]
      a <- available &  bin %in% current.bin
      if(sum(a) == 0) next # no more are available for this bin
      selected.point <- which(random == min(random[a])) # the index of the selected point
      selected[ current.row, i] <- selected.point
      available <- available &  sqrt((x-x[selected.point])^2 + (y-y[selected.point])^2) > min.dist   
    }
    current.row <- current.row +1 
  }
  selected.vector <- as.vector(selected)
  selected.vector <- selected.vector[!is.na(selected.vector)]
  
  result <- data[selected.vector, ]
  
  return(result)
}
