.griddescribe <- function(path) {
  #--------------------------------------------------------------------------------------------------#
  # Function to read information about a grid - returns a named list:
  #ncol - number of columns in the gri
  #nrow - number of rows in the grid
  #xll, yll - coordinates of the lower left corner of the grid
  #cellsize - size of cells, in map units
  #nodata - value to be used to represent no data cells
  #type - either "integer", "real", or "missing" (missing means the grid doesn't exist)
  #min - minimum value in grid
  #max - maximum value in grid
  #mean - mean of grid
  #sd - standard deviation of grid
  #  Details: if the grid doesn't exist all items of the list will be NA except the type which will 
  #  be "missing"
  #
  #  Note this is a low level funciton which opperates on esri grids only. griddescribe calls this 
  #    when the target isn't a mosaic grid and returns the mosaic information otherwise.
  #--------------------------------------------------------------------------------------------------#
  path <- as.character(path)
  if(!(length(path)==1 && !is.na(path) && !is.null(path))) 
    stop("grid describe called with NULL or NA path")
  
  done <- FALSE
  .status$gsdowntime <- 0  # The amount of time the gridserver has been down
  while(!done){  
    st <- system.time({
      r <- .C("R_griddescribe", integer(1), as.character(path), integer(1), integer(1), double(1), 
              double(1), double(1), integer(1), double(1), double(1), double(1), double(1), 
              PACKAGE="caps_lib")
    })
    .status$gridwait <- .status$gridwait + as.numeric(st[3])
    done <- .donetrying(code=r[[1]], st, reset=FALSE)    
  }
  
  
  if(r[[1]] == -10007) {  # if the grid doesn't exist
    r[[1]] <- 1 # bypass error
    r[[8]] <- 3  # set type to 3
    for(i in 1:length(r)) if(r[[i]] == 0) r[[i]] <- NA  # replace everything else with NA
  }
  parseerror(r[[1]], "griddescribe")
  r <- r[-(1:2)]
  names(r) <- c("nrow", "ncol", "yll", "xll", "cellsize", "type", "min", "max", "mean", "sd")
  r$type <- switch(r$type, "integer", "real", "missing")
  return(r)
}

