.gridinit <- function(server="", local=TRUE, port=3336, log=FALSE){
  #--------------------------------------------------------------------------------------------------#
  # gridint - initialize the grid server.     Ethan Plunkett   December 2010
  #This is an  R wrapper for the caps_lib R_gridinit function
  #
  #  Arguments
  #server - (character) grid gateway server name or root dir path for local access 
  #local - TRUE for local access
  #         FALSE for network (protected) access, uses gateway access server
  #port - (optional, integer) specify the port the default 3336 
  #log - if set to TRUE will store a log file in the current folder
  #
  #--------------------------------------------------------------------------------------------------#
  if(.status$verbosity >= 2) cat("\n.gridinit called with arguments:", 
                                 "\n\tserver=", as.character(server), 
                                 "\n\tlocal=", local, 
                                 "\n\tport=", port,
                                 "\n\tlog=", log, "\n",
                                 sep="")
  if(local){
    .status$gridinitcount$local <- .status$gridinitcount$local + 1
  } else {
    .status$gridinitcount$server <- .status$gridinitcount$server + 1
  }
  .cleanup()
  io.mode <- as.integer(ifelse(local, 2, 1)) # convert to lib argument form
  if(any(is.null(server), is.null(local), is.null(port), is.null(log))) 
    stop("NULL arguments aren't allowed")
  if(any(is.na(server), is.null(local), is.null(port), is.null(log))) 
    stop("NA arguments aren't allowed")
  done <- FALSE
  .status$gsdowntime <- 0  # The amount of time the gridserver has been down
  while(!done){
    st <- system.time({
      r <- .C("R_gridinit", integer(1), as.integer(io.mode), as.character(server), as.integer(port), 
              as.integer(log), PACKAGE="caps_lib")
    })
    .status$gridwait <- .status$gridwait + as.numeric(st[3])
    done <- .donetrying(code=r[[1]], st, reset=FALSE)    
  }
  
  parseerror(r[1], "gridinit")
  
  # .status$grid.server.status <- ifelse(local, "local", "server")	
  
} # end gridint function definition

