.setwindow <-
function(x, ...){
#--------------------------------------------------------------------------------------------------#
#  setwindow method for character objects (paths to grids)
# Arguments : x (character) - path to a grid that will be used to define the window 
# Value - the function invisibly returns a named list.  It ALSO modifies the variable "header"
#   inside the .status environment which defines the grid topology of the access window 
#  equal to the return list.
# Note:  ... isn't used in the function but is required so that the function definition matches
#   the generic function definition.  
  if(!(length(x)==1 && !is.na(x) && !is.null(x))) 
    stop("setwindow.character called with an NA or NULL string.")
  done <- FALSE
  .status$gsdowntime <- 0  # The amount of time the gridserver has been down
  while(!done){  
    st <- system.time({
      r <- .C("R_setwindow", integer(1), as.character(x), integer(1), integer(1), double(1),
              double(1), double(1), integer(1), PACKAGE="caps_lib")
    })
    .status$gridwait <- .status$gridwait + as.numeric(st[3])
    done <- .donetrying(code=r[[1]], st, reset=FALSE)    
  }
  
  parseerror(r[[1]], "setwindow")
  r <- r[-1]
  names(r) <- c("grid", "nrow", "ncol", "yll", "xll", "cellsize", "tileonly")
  r$tileonly <- as.logical(r$tileonly)
  r <- r[c("nrow", "ncol",  "xll", "yll", "cellsize", "tileonly")]  # reorder and drop "grid"
  r$set <- TRUE
  
  invisible(r)
} # end setwindow function definition

