.donetrying <- function(code, st, reset=TRUE){
	
  # This function returns TRUE either if the gridserver appears to be running or if 
  #  we've given up on trying again.
  # it FALSE if the server wasn't AND therefore the call that generated
  #  the errror code should be tried again.   It will only return FALSE if anthill is loaded and 
  #  configured to recover lockservers.
  #
  # Also if the error code indiactes that the window wasn't set
  # and the resetwindow argument is TRUE the funciton will attempt to reset the window
  # 
  # Arguments:
  #   code - the error code returned by a C function in CAPS_LIB
  #   st - the result to a system.time call that tracked how long the function took.
  #   reset - if TRUE then attempt to reset the window if its not set
  #  Value :
  #    this function returns TRUE if either the gridserver is OK or if 
  #      its not OK but we should not try again.  It returns FALSE if we should 
  #      repeat the call that generated code again.  Basically the return 
  #      value could be called "moveon".
  
	  
  if(!code %in% c(.status$gsdowncode, .status$nowindowcode)) return(TRUE)
  
  if(!anthillrunning()) return(TRUE)
  if(anthill:::.settings$recoverservers == 0) return(TRUE)
  if(.status$gsdowntime > anthill:::.settings$maxrecovery) return(TRUE)
  if(.status$verbosity > 1) cat("Gridserver down waiting for anthill to relaunch it.\n")
  flush.console()
  
  
  if(code %in% .status$gsdowncode){
    wi <- .status$gswaitinterval
    Sys.sleep(wi)
    .status$gsdowntime <-   .status$gsdowntime + as.numeric(st[3]) + wi
    .status$gridwait <- .status$gridwait + wi
    return(FALSE)
  }
  
  if(code %in% .status$nowindowcode){
    if(reset){
      cat("The server seems to have lost it's window. Resetting it now.\n")
      resetwindow()
      return(FALSE)
    } else {
      return(TRUE)
    }
  }
   
  
}
