
fileinfo <- function(x, use.old=FALSE){
  if(.status$verbosity >= 3) cat("fileinfo called with argument x:", x, "\n")
  # Returns a list with elements: 
  #    size : the sum of the file sizes of objects in the directory - subdirectoryies excluded (MB)
  #   date : the most recent modification date 
  #   free:  the total free space on disk (MB).
  
  # works on ESRI grids - not mosaics - because of depth of file structure in mosaics
  
  # x <- "c:/temp/gridiotest/dem/"
  
  # Set conversion factor 
  # Note if using base 2 change values in readblockc as well
  # bytes.per.megabyte <- 1048576  #  base 2
    bytes.per.megabyte <- .status$bytes.per.megabyte  #  base 10
  
  
    
  if(!use.old){ # new version
    # x <- "C:/temp/gridiotest/dem"
    
    timestamp <-  paste(rep("a", 1000), collapse="")  # a big string
   # void R_gridinfo(int *ret_v, char **the_path, char **timestamp, double *file_size, int *disk_free) 
      r <- .C("R_fileinfo", integer(1), as.character(x),as.character(timestamp), double(1), integer(1), 
              PACKAGE="caps_lib")
    parseerror(r[[1]], "fileinfo")
    r <- r[-(1:2)]
    names(r) <- c("date", "size", "free")
    r <- r[(c("size", "date", "free"))]
    
    d <- r$date
    d <- sub(":([[:digit:]]*$)", "", d) # lop off 1000's of a second
    
    
    r$date <- as.POSIXct(x=d, format="%d %b %Y, %H:%M:%S")
    return(r)
    
    
  } else { # old version:
    x <- gsub("(/|\\\\)$", "", x)  # drop trailing /
    
    if(!file.exists(x)) return(list(size=NA, date=as.POSIXct(NA), free=NA))
    a <- file.info(x)
    if(!a$isdir) stop(x, " isn't a directory so can't be a grid.")
    
    l <- list.files(x)
    most.recent <- as.POSIXct(NA)
    for(f in l){
      # f <- l[1]
      info <- file.info(paste(x, "/", f, sep=""))
      most.recent <- max(most.recent, info$mtime, na.rm=TRUE)
    }
    
    
    
    
    # get  space used by files and free space
    ow <- getwd()  # Get current workspace 
    on.exit(setwd(ow))  # and make sure that we reset it on exit
    setwd(x)  # but change it for now to the directory we are investigating
    a <- shell("dir", intern=TRUE)
    
    
    # Free space
    b <- a[length(a)]
    b <-gsub("^.*Dir.s.[[:blank:]]*", "", b)
    b <-  gsub("[[:blank:]]*bytes free|,", "", b)
    b <- as.numeric(b)  
    freemb <- b / bytes.per.megabyte
    
    # used by files (one level down only - fine for grids)
    b <- a[length(a)-1]
    b <-gsub("^.*File.s.[[:blank:]]*", "", b)
    b <-  gsub("[[:blank:]]*bytes|,", "", b)
    b <- as.numeric(b)  
    filemb <- b / bytes.per.megabyte
    
    return(list(size=filemb, date=most.recent, free=freemb))
    
  } # end old version
    
    
    
} # end function 
