# FRISKMOSAICS
# Given a list of mosaics, makes sure they are all up-to-date with the 
# source grids.  Result is a vector corresponding to the list of mosaics, 
# with 0 = mosaics are not derived, 
#  1 = mosaics are up-to-date, 
# 2 = mosaics are out of date (error), and 
#  3 = source doesn't exist (probably just a warning).
# 4 = mosaic doesn't exist


if(FALSE){
  library(gridio)
  x <- c("x:/gis/demmosaic", "C:/temp/gridiotest/makemosaic/demmosaic", "a")
  x <- x[1]
  friskmosaics(x)
}


friskmosaics <- function(x, err=FALSE, warn=FALSE){
  stopifnot(is.character(x))
  
  checkone <- function(x){
    mi <- suppressWarnings(tryCatch(mosaicinfo(x), error=function(e) e))
    if(inherits(mi, "error")){
      if(mi$message == "cannot open the connection")
        return(9)
      else
        stop(paste("error in mosaicinfo('", x, "'): ", mi$message, sep=""))
    }
    if(mi$type != "derived") return(0)
    source.adf <- paste(mi$source, "/sta.adf", sep="")
    if(!file.exists(source.adf)) return(3)
    
    # Lookup modification data of source grid
    si <- fileinfo(x=source.adf)    
    
    if(as.POSIXct(mi$sourcetimestamp,format=.status$timeformat) == si$date){
      return(1)
    } else {
      return(2)
    }
  }

  res <- sapply(x, checkone)
  res <- data.frame(code=as.numeric(res), path=names(res))  
  msg.tab <- data.frame(code=c(0, 1, 2, 3, 9), 
                       message=c("mosaic is not derived", 
                       "mosaic is up-to-date", 
                       "mosaic is out of date",  
                       "mosaic source doesn't exist", 
                       "mosaic doesn't exist"))
  
  res <- merge(res, msg.tab, by="code", all.x=TRUE, all.y=FALSE)
  stop.codes <- c(2, 9)
  warning.codes <- c(3)
  
  sv <- res$code %in% c(warning.codes, stop.codes)
  if(warn && any(sv))
    for(i in which(sv)) 
      warning(res$message[i], " ('", res$path[i],"'')", sep="")
  sv <- res$code %in% stop.codes
  if(err && any(sv))
    stop("mosaics with critical problems (code): ", 
         paste("'", res$path[sv], "' (", res$code[sv], ")", sep="", collapse=", "))

  return(res)
}

