friskstitched <- function(x, err=FALSE){
  # Function to see if stitched grids are up to date
  # x <- path to stitched grid
  result <- data.frame(mosaic = "", error = FALSE, message = "", 
                       complete = x, stringsAsFactors = FALSE)
  for (i in 1:length(x)) {
    complete <- x[i]
    
    if(!file.exists(complete)){
      result$error[i] <- TRUE
      result$message[i] <- "Target grid is missing"
      next
    }
    
    
    if(grepl("_s", x[i])){
      mosaic <- gsub("_s$","", complete)
    } else {
      mosaic <- paste0(complete, "_m")
    }
    mosaic <- gsub("\\\\", "/", mosaic)
    result$mosaic[i] <- mosaic
    
    if (!file.exists(mosaic)) {
      result$error[i] <- FALSE
      result$message[i] <- paste("Mosaic doesn't exist")
      next
    }
    
    gridname <- gsub("^.*/", "", complete)
    
    md <- griddescribe(mosaic)
    if (md$type == "missing"  || !md$mosaic) {
      result$error[i] <- FALSE
      result$message[i] <- "No mosaic at mosaic path."
      next
    }
    
    if (md$mosaicinfo$type == "derived" & file.exists(complete)) {
      result$error[i] <- FALSE
      result$message[i] <- "derived mosaic. complete version is the source."
      next
    }
    
    
    logfile <- paste(mosaic, "/stitchlog.txt", sep = "")
    if (file.exists(logfile)) {
      log <- read.table(file = logfile, sep = "\t", 
                        header = TRUE, stringsAsFactors = FALSE, comment.char = ";")
      log$stitchpath <- gsub("\\\\", "/", log$stitchpath)
      log$stitchdate <- as.POSIXct(log$stitchdate, 
                                   format = .status$timeformat)
      moddate <- as.POSIXct(md$mosaicinfo$timestamp, 
                            format = .status$timeformat)
      if ( any(tolower(log$stitchpath) %in% 
                                      tolower(complete) & log$stitchdate > moddate)) {
        result$error[i] <- FALSE
        result$message[i] <- "Grid is derived and up-to-date."
        next
      } else {
        result$error[i] <- TRUE
        result$message[i] <- "Grid is derived and out-of-date (or possible things have been moved or renamed)"
      }
      
      
    } else {
      result$error[i] <- TRUE
      result$message[i] <- "Stitched version lacks log file"
    }
    
    
  } #  end loop through grids
  sv <- result$error
  if(err && any(sv)){
    stop("grids with critical problems: ", 
         paste("'", result$complete[sv], "' (", result$message[sv], ")", sep="", collapse=", "))
  }
  return(result)
}

