if(FALSE){
  # Generate test data
  library(gridio)
  set.seed(1)
  n <- 100
  x <- runif(n, 0, 1000)
  y <- runif(n, 0, 1000)
  z <- rnorm(n, mean=10, sd=10) + y * .02  # Slight north south gradient with a lot of noise
  a <- data.frame(x,y, z)
  coordinates(a) <- c("x", "y")  # convert to SpatialPointsDataFrame
  
  # gaussianinterpolate
  g <- gaussianinterpolate(x=a, sd=50,max.r=300, data.col="z", buffer=50, cellsize=100)
  
  # Plot results
  plot(g)
  cols <- rgb(1, 0, 0, (z - min(z) + .2 * (max(z)- min(z)))/(1.2 * (max(z)-min(z))) ) 
  cex <- (z - min(z) + .5 * (max(z)- min(z)))/(1.5 * (max(z)-min(z))) *2
  points(x, y, col=cols, pch=16, cex=cex)  
  
}

gaussian.interpolate <- function(...) {
	warning("gaussian.interpolate is defunct.  Please use gaussianinterpolate instead.")
	gaussianinterpolate(...)
}

gaussianinterpolate <- 
  function(x, sd,  data.col, refgrid, max.r=3*sd, buffer, cellsize, 
           path, overwrite=FALSE, ...){
  # This function will produce a grid based on vector based kernel smoothing of the points in a SpatialPointsDataFrame
  pts <- x
  x <- coordinates(pts)[,1]
  y <- coordinates(pts)[, 2]
  m <- pts[[data.col]]  # measure
  # Grid at once
	if(missing(refgrid)){
		grid <- list()
		grid$xll=((min(x, na.rm=TRUE)-buffer) %/% cellsize) * cellsize
		grid$yll= ((min(y, na.rm=TRUE)-buffer) %/% cellsize) * cellsize
		grid$cellsize = cellsize
		grid$nrow = (max(y)+buffer - grid$yll) %/% cellsize + 1
		grid$ncol = (max(x)+buffer - grid$xll) %/% cellsize + 1
		grid$m <- matrix(NA, grid$nrow, grid$ncol)
		grid <- grid[c("m", "xll", "yll", "nrow", "ncol", "cellsize")]
    class(grid) <- c("grid", class(grid))    
	} else {  # reference grid supplied
    if(is.character(refgrid)){
      grid <- griddescribe(refgrid)
      grid$m <- matrix(NA, nrow=grid$nrow, ncol=grid$ncol)
      grid <- grid[c("m", "xll", "yll", "nrow", "ncol", "cellsize")]
      class(grid) <- c("grid", class(grid))  
    } else 
      if(inherits(refgrid, "grid")){
      grid <- refgrid()
      grid$m[, ] <- NA
	  } else if(inherits(refgrid, "list") & all(c("xll", "yll", "cellsize", "nrow", "ncol") %in% names(refgrid))){
	    grid <- refgrid
	    grid$m <- matrix(NA, grid$nrow, grid$ncol)
	    grid <- grid[c("m", "xll", "yll", "nrow", "ncol", "cellsize")]
	    class(grid) <- c("grid", class(grid))    
	  }
	}
 # return(grid)
	
  if(!missing(path)){
    if(!coincide(grid, getwindow())) 
      stop("If specifying an output grid make sure to call gridinit and setwindow prior to calling this function. The window must coincide with the output grid extent.")
    gt <- gridtype(path, cache = FALSE)
    if(gt != "missing" & overwrite ) gridkill(path)
    if(gt != "missing" & !overwrite) stop("The output grid already exists and overwrite is set to FALSE.")
  }

  out.pts <- as.SpatialPointsDataFrame(grid)
  out.x <- coordinates(out.pts)[, 1]
  out.y <- coordinates(out.pts)[, 2]
  i <- length(out.x)/2 - grid$ncol/2
  result <- rep(NA, nrow(out.pts))
  
  for(i in 1:nrow(out.pts)){
    this.x <- out.x[i]
    this.y <- out.y[i]
    dist <- sqrt((x-this.x)^2 + (y-this.y)^2)
    sv <- dist < max.r
    if(sum(sv, na.rm=TRUE)==0){
      result[i] <- NA
      next
    }
    weights <- dnorm(x=dist[sv], mean=0, sd=sd)  
    weights <- weights/sum(weights)
    result[i] <- sum(m[sv]*weights)
  }
  
  
  out.pts$z <- result
  g <- as.grid(out.pts)
  
  if(FALSE){
    ncol <- 10
    cols <- rainbow(n=ncol, start=.2, end= .8)
    
    tocolor <- function(x, cols){
      x <- x - min(x, na.rm=TRUE)
      ncol <- length(cols)
      step <- max(x, na.rm=TRUE)/ncol
      stepx <- seq(0, max(x, na.rm=TRUE), by=step)
      stepx[length(stepx)] <- stepx[length(stepx)] + 1
      stepy <- 0:(length(stepx))
      fun <- stepfun(x=stepx, y=stepy)
      ci <- fun(x)
      cols[ci]
    }
    
    
    
    plot(g)
    plot(x, y, col=col, pch=16)
    col <- tocolor(m, cols)    
    points(x, y, col=col, pch=16)
    plot(out.pts, add=T, col=tocolor(result, cols))
    
  }
  if(missing(path)) {
    return(g)
   } else {
     writegrid(g, path=path, as.integer=FALSE, ...)
   }  
}  # End function definition

