getcachedir <- function(grid, locking = FALSE){
  # Arguments:
  #   grid : controls which index file is looked up can either be the path to 
  #    a grid in which case the proper index file for that grid will be returned
  #     OR a numeric indicating the hash to lookup.
  #  locking : if TRUE this function will lock the file prior to reading and unlock it after.
  #  
  
  ci <- getcacheconfig()
  if(!ci$on) return(NA)
  
  index.path <- getcachepath(grid[1])
  
  if(locking){
    msg <- paste(short.name(), "-R", sep="")
    lp <- paste0(short.name(), " ", index.path) # define lock path
    get.lock(lp, message=msg, slash=FALSE)
    on.exit(return.lock(path=lp, message=msg, slash=FALSE))
  }
  # Read file - Note I'm reading it in and then converting to table 
  # so that when there are errors in the second step the dumped frames
  #  contain the file's data as it existed when it caused the error.
  
  l <- readLines(index.path)
  con <- textConnection(l, "r")
  d <- read.table(file=con, sep="\t", header=TRUE, 
                  stringsAsFactors=FALSE, comment.char = ";", 
                  colClasses = .status$cachecolumnformat)
  if(!all(.status$cachecolumns %in% names(d))) 
    stop("Missing columns in the gridcache file:", 
         paste(setdiff(.status$cachecolumns, names(d)), collapse=" ,") )
  
  if(locking){
    return.lock(path=lp, message=msg, slash=FALSE)
    on.exit(NULL)
  }
  
  d$sourcedate <- as.POSIXct(d$sourcedate, format=.status$timeformat)
  d$cachedate <-  as.POSIXct(d$cachedate, format=.status$timeformat)
  d$source <- gsub("\\\\", "/", d$source)
  d$cache <- gsub("\\\\", "/", d$cache)
  
  return(d)
  
}
