getwindow <- function(query.server=FALSE, pane.only=FALSE) {
  # Function to get information on the current access window.
  #
  #  Arguments :
  #     query.server if FALSE the function will return the locally cached window information
  #          stored if TRUE it will query the dll or gridserver for it's 
  #          window.  The second is used by gridinit right after connecting to a gridserver
  #           to update the local cache and shouldn't be needed in any other situation but 
  #            might be useful for debugging. 
  #     pane.only - if the current connection is to a pane of a mosaic then if FALSE it will 
  #        return the virtual access window for the entire mosaice and if TRUE it will return 
  #        information on the entire pane.
  #
  #  Return value:  a list with these elements
  #    ncol - number of columns in the grid
  # 	 nrow - number of rows in the grid
  # 	 xll, yll - coordinates of the lower left corner of the grid
  # 	 cellsize - size of cells, in map units
  #    tileonly - TRUE if the grid is too big to be read in all at once 
  #    set = TRUE if the window is set FALSE otherwise
  #
  #  Note:  The original function always queried the server.  May 2013 I changed this so that it 
  #   defaults to using the localy cached information stored. This speeds things
  #   up.  Especially when it's running in server mode.  
  
  # Note 2: this hasn't been updated for mosaics.  I'm not sure if we'd want getwindow called on a mosaic connection to return the 
  #  entire mosaicwindow or just the active connection's part of it.  Currently it would do the second.
  # For end users I'd imagine that we want it to do the first as they shouldn't really care about the mosaic details. 

  if(!query.server){
    con <- .status$activeconnection$connection
    if(is.na(con)  ){  # || ( !.status$connections$set[con] & !is.na(.status$connections$pane[con])
      return(list(xll=NA, yll=NA, nrow=NA, ncol=NA, cellsize=NA, set=FALSE))
    } else if(is.na(.status$connections$pane[con]) | pane.only){
      l <- as.list(.status$connections[con, ] ) 
      l <- l[c("xll", "yll", "nrow", "ncol", "cellsize", "set")]
      return(l)
    } else {  # mosaic pane and pane.only=FALSE
      l <- .status$mosaicwindow
      l$set=TRUE  # I think this is what we want
      l <- l[c("xll", "yll", "nrow", "ncol", "cellsize", "set")]
      return(l)
    }
  } else {  # if query server
    done <- FALSE
    .status$gsdowntime <- 0  # The amount of time the gridserver has been down
    while(!done){  
      st <- system.time({
        r <- .C("R_getwindow", integer(1), integer(1), integer(1), double(1), 
                double(1), double(1), integer(1),  PACKAGE="caps_lib")
      })
      .status$gridwait <- .status$gridwait + as.numeric(st[3])
      done <- .donetrying(code=r[[1]], st, reset=FALSE)    
    }
      
    ec <- r[[1]]
    r <- r[-(1)]
    names(r) <- c("nrow", "ncol", "yll", "xll", "cellsize")
    if(ec %in% c(-520,-10013)){
      r$set=FALSE 
      for(i in 1:6) r[[i]] <- NA
    } else {
      r$set=TRUE
      r$tileonly=as.logical(r$tileonly)
      parseerror(ec, "griddescribe")
    }
    r <- r[c("xll", "yll", "nrow", "ncol", "cellsize", "set")]
    return(r) 
  }
  
}

