gridcreate <- function(path, as.integer=FALSE, silent=FALSE){
  #--------------------------------------------------------------------------------------------------#
  #  gridcreate     Ethan PlunkettJanuary 2011
  #  This function creates a grid at path with the extent and location of the current access window
  #
  #  Arguments:
  #    path : the location of the new grid relative to the path set in gridinit
  #    as.integer : if TRUE the new grid will store integers if FALSE it will store real numbers
  #    silent : if TRUE than if the grid already exists no warning is given; the grid on disk is 
  #     still left untouched.
  #  Change Log
  #    Feb 2012 - Prexisting grids now result in warnings not errors and those warnings can be 
  #     surpressed with the new "silent" argument
  #--------------------------------------------------------------------------------------------------#
  type.code <- ifelse(as.integer, 1, 2)  # 1= integer, 2=real
  done <- FALSE
  .status$gsdowntime <- 0  # The amount of time the gridserver has been down
  while(!done){  
    st <- system.time({
      r <- .C("R_gridcreate", integer(1), as.character(path), as.integer(type.code), 
              PACKAGE="caps_lib")
    })
    .status$gridwait <- .status$gridwait + as.numeric(st[3])
    
    done <- .donetrying(code=r[[1]], st, reset=TRUE)    
  }
  
  if(r[[1]] == -10017){ # this is the error that is thrown when the grid already exists
    if(!silent)warning("Grid already exists and was left untouched.")
  } else {
    if(r[[1]] < 0){ # if there's an error I'm first going to check the path for problems 
       # and throw an error listing them.  If that fails I'll throw EDI's error
      a <- checkgrid(path, pathonly =TRUE)
      if(a$problem){
        a$problem <- NULL
        stop("gridcreate error with ", path, " : ", paste(names(a)[unlist(a)], collapse = ", "))
      }
      parseerror(r[[1]], "gridcreate")
    }
  }
  
  # Remove info on this grid from gridinfo cache 
  if(path %in% ls(.status$gridinfo))
    rm(list=path, envir = .status$gridinfo)
  
  invisible()
}

