if(FALSE){  # Example usage
  
  x <- list(xll=0, yll=0, nrow=10, ncol=15, cellsize=10)
  y <- list(xll=50, yll=20, nrow=5, ncol=40, cellsize=10)
  gridintersect(x, y)  
  
  # With a grid object
  x$m <- matrix(1:150, nrow=10, ncol=15)
  class(x) <- c("grid", class(x))  
  i <- gridintersect(x, y)
  x$m
  i$m  
  
}




gridintersect <- function(x,y){
  #------------------------------------------------------------------------------------------------#
  # Ethan Plunkett    2013
  # Function find the intersection of two extents, x and y.  They can be a grid, any other list 
  #   containing the grid alignment info, or the path to a grid on disk.
  #  Value = if x is a gridobject (in memory) it returns the data in x that occupies the intersection of the extents 
  #   defined by x and y.
  #  if (x is a path to a grid or a list specifying an extent ) the function will return a list 
  #    specifying the extent of the intesection.
  #  If the two grids don't overlap the function will return NULL.
  #------------------------------------------------------------------------------------------------#
  if(is.character(x)){
    x <- griddescribe(x[1])
    if(x$type == "missing") stop("x must be a list object or the path to a grid on disk.")
  }
  if(is.character(y)){
    y <- griddescribe(y[1])  
    if(x$type == "missing") stop("x must be a list object or the path to a grid on disk.")
  }

  # Verify that cellsize and snapping are OK
  checkcellalignment(x, y)
  
  # Note these are cell centers
  x.xrange <- c2x(c(1, x$ncol), x)
  y.xrange <- c2x(c(1, y$ncol), y)
  x.yrange <- r2y(c(x$nrow, 1), x)
  y.yrange <- r2y(c(y$nrow, 1), y)
  
  # Check to make sure they overlap
  overlap <- function(a, b) ( max(a[1],b[1]) <= min(a[2], b[2])) 
  if(!overlap(x.xrange, y.xrange) || !overlap(x.yrange, y.yrange)){
    warning("The grid extents don't overlap at all.")
    return(NULL)
  }
  # calculate the range of the overlap
  xrange <- c(max(x.xrange[1], y.xrange[1]), min(x.xrange[2], y.xrange[2]))
  yrange <- c(max(x.yrange[1], y.yrange[1]), min(x.yrange[2], y.yrange[2]))

  cellsize <- x$cellsize
  yll <- min(yrange) - .5 * cellsize
  xll <- min(xrange) - .5 * cellsize
  nrow <- (max(yrange) - min(yrange)  + cellsize)/cellsize
  ncol <- (max(xrange) - min(xrange)  + cellsize)/cellsize
  

  # Make a new empty grid
  newextent <- list( nrow=nrow, ncol=ncol, xll=xll, yll=yll, cellsize=cellsize)
  
  # If we were passed a grid we return a grid object with the data from x in the intersection
  if(inherits(x, "grid")) {
    return(matchextent(x, y=newextent))
  } else {  # otherwise just return the intersection of the extents.
    return(newextent)
  }
  
  
}
