if(FALSE){  # SKIP
  
  # Example Code 
  
  ### Setup a temporary directory with a sample grid in it 
  # Get path to example dem grid (included with package)
  require(gridio)
  datapath <- system.file("exampledata", package="gridio")  # grid path to example grid
  datapath <- shortPathName(datapath)
  datapath <- paste(datapath, "/.", sep="")
  
  # Make a temporary directory to write new grids to
  dir <- tempdir() # get temporary directory
  # dir <- "C:/temp/gridiotest/stiching"
  dir <- gsub("\\\\", "/", dir)
  
  # Clear it out
  if(file.exists(dir)) unlink(dir, recursive=TRUE)
  if(!file.exists(dir)) dir.create(dir)
  list.files(dir)
  
  # Copy example data into temporary directory
  file.copy(datapath, dir, recursive=TRUE)
  
  
  cleanup() # disconnect from any prior gridservers 
  
  # Setup paths
  original <- paste(dir, "/dem", sep="")
  tiledparts <- paste(dir, "/tiledT[tile]", sep="")
  indexedparts <- paste(dir, "/indexedT[tile]", sep="")
  tiledstitch <- paste(dir, "/dem_tiled", sep="")
  indexedstitch <- paste(dir, "/dem_indexed", sep="") 
  
  # index <- "G:/Mass/Towns/TOWNS_POLY.shp"
  index <- paste(dir, "/towns/towns.shp", sep="")
  id.field <- "TOWN_ID"
  
  buffer <- 10
  overwrite= TRUE
  
  # Verify that splitting and stitching the same data produces a grid identical to the original
  
  # Split based on tiles
  gridsplit(complete=original, parts=tiledparts, rowsize=150, tilesize=50, buffer=buffer)
  
  # Split based on index shapefile
  gridsplit(complete=original, parts=indexedparts,index=index, buffer=buffer, id.field = id.field, tilesize=100)
  
  # Stich based on tiles
  gridstitch(parts=tiledparts, complete=tiledstitch,ref=original, buffer=buffer, overwrite=overwrite, tilesize=75)
  
  # stich based on index
  gridstitch(parts=indexedparts, complete=indexedstitch,ref=original,index=index, id.field=id.field,
             overwrite=TRUE, tilesize=75)
  
  cleanup()
  gridinit()
  setwindow(original)
  g1 <- readgrid(original)
  g2 <- readgrid(tiledstitch)  
  g3 <- readgrid(indexedstitch)
  
  
  stopifnot(all.equal(g1, g2))
  stopifnot(all.equal(g1, g3))
  
  
  # Verify that the right data is coming from each subgrid (for index based subgrids)
  # by making copies of the subgrids in which all the cells are populated with the id.field
  # and then stitching those subgrids back together.
  
  # Build the index and make copies of subgrids populated with their ids
  a <- buildsubgridindex(index=index, window=griddescribe(original), id.field=id.field)
  ids <- a$ids
  ind <- a$ind
  paths <- character(length(ids))
  for(i in 1:length(a$ids)) paths[i] <- gsub("[tile]", ids[i], x=indexedparts, fixed=TRUE)
  outpaths <- paste(dir, "/idT", ids, sep="")
  for(i in 1:length(paths)){    
    setwindow(paths[i])
    g <- readgrid(paths[i])
    g$m[, ] <- ids[i]
    writegrid(g, path=outpaths[i], as.integer=TRUE)
  }
  parts <- paste(dir, "/idT[tile]", sep="") 
  complete <- paste(dir, "/stitchedids", sep="")
  
  # Stitch them together
  gridstitch(parts=parts, complete=complete, index=index, id.field=id.field, ref=original)
  
  cleanup()
  gridinit()
  setwindow(original)
  
  g4 <- readgrid(complete)
  plot(g4, use.old=F)
  plot(a$ind, border="red", add=TRUE)
  
  # Now make the same directly from the polygon index
  sp <- as.SpatialPointsDataFrame(g1)
  proj4string(sp) <- proj4string(ind)
  o <- over(sp, ind)
  g5 <- g1
  g5$m[, ] <- o[[id.field]]
  plot(g5)
  stopifnot(all.equal(g4, g5))
  
  
  
  # setup for line by line execution of function
  
  # Universal Args
  rowsize <- 150 
  colsize <- 200
  tilesize <- 50
  buffer = 5
  server <- port <- NULL
  index <- "G:/Mass/Towns/TOWNS_POLY.shp"
  id.field <- "TOWN_ID"
  limit.extent=TRUE
  add=FALSE
  overwrite = TRUE
  ref <- original
  
  # Function specific args
  
  # Spliting by tiles
  complete <- original
  parts <- tiledparts
  
  # Splitting by index
  complete <- orginal
  parts <- indexedparts
  
  # Stiching by tiles
  complete <- tiledstitch
  parts <- tiledparts
  transparent=FALSE
  
  # Stiching by index
  complete <- indexedstitch
  parts <- indexedparts
  transparent=TRUE
}


#------------------------------------------------------------------------------------------------#
# Function to break apart a grid into tiled subgrids
#  
# Arguments:
#   complete - the path to the whole grid
#   parts - the path to the component grids should include "[tile]" which is a placeholder for the 
#     tilenumber.  If it doesn't include [tile] the tile number will be appended
#   rowsize, colsize - the number of rows and columns (cells) that make up the core of each subgrid.
#   buffer - the distance (in cells) beyond the tile core that will also be included in each subgrid.
#   tilesize - the tilesize actually used for reading and writing (so that subgrids that are too big
#   to fit in memory can be processed).
#   index - optional this is the path to an index shapefile containing polygons delinieating the 
#      the core of each subgrid.
#   id.field - this is the field name in the index file that is used for identifying the subgrids
#      must contain integers only
#   limit.extent <- this is currently only relevant to the index based tiling.  If TRUE the subgrids
#     will never extend beyond the original extent of the complete grid.  If FALSE they will extend
#     by the buffer distance.
#   server, port - the server and port to use when reading or writing the complete grid - the parts 
#     will always be read and written in local mode.  If NULL local mode is used for everything.
#------------------------------------------------------------------------------------------------#


gridsplit <- function(complete, parts, rowsize, buffer, colsize=rowsize, index, id.field, 
                      limit.extent=TRUE, tilesize=2000, server=NULL, port=NULL){
  
  #------------------------------------------------------------------------------------------------#
  # Note this is basically two functions one for regular tiles and one for index based tiling.
  #
  # Part 1  - regular tiles
  #
  #------------------------------------------------------------------------------------------------#
  
  if(missing(index)){  
    
    cleanup()  # disconnect from any gridserver
    bigextent <- NULL
    gobig <- function(){  # this sets up for reading from the large grid
      cleanup()
      if(!is.null(server)){
        gridinit(server=server, port=port)
      } else {
        gridinit()
      }
      if(!getwindow()$set){
        if(is.null(bigextent)){
          setwindow(complete) 
        } else {
          setwindow(bigextent)
        }
      }
      tileinit(rowsize=rowsize,buffer=buffer, colsize=colsize)
    }
    
    gosmall <- function(tile, coreonly=FALSE){  # this sets up for reading or writing from a component grid
      gobig()
      settile(tile)    
      e <- tiledetails(coreonly=coreonly)
      cleanup()
      gridinit()
      setwindow(e)
    }
    
    gobig()
    cdesc <- griddescribe(complete)
    writeinteger <- switch(cdesc$type, 
                           "real" = FALSE, 
                           "integer" = TRUE, 
                           stop("The complete grid \"", complete, "\" is either missing or of an unregonized type.")
    )
    
    e <- getwindow()  # the extent of the entire landscape (big grid)
    n <- ntiles()
    
    for(i in 1:n){  # these are the big tiles (Subgrids)
      cat("Working on sub-grid", i, "of", n, "\n")
      if(grepl("[tile]", fixed=TRUE, x=parts)){
        outpath <- gsub("[tile]", i, fixed=TRUE, x=parts)
      } else {
        outpath <- paste(parts, i)
      }
      outdir <- gsub("/[^/]+$", "", outpath)
      if(!file.exists(outdir)) dir.create(outdir, recursive=TRUE)
      
      gosmall(i, coreonly=FALSE)  # set extent to this subgrids extent
      tileinit(rowsize=tilesize, buffer=0) # this is tiling the subgrid into readable chunks
      for(j in 1:ntiles()){  # iterate through tiles in the subgrid  
        settile(j)
        d <- tiledetails()
        gobig()
        g <- readblock(path=complete, 
                       startrow=max(1, y2r(d$yll + 0.5*d$cellsize,e ) - d$nrow + 1),  
                       startcol=max(1, x2c(d$xll + 0.5*d$cellsize, e)), 
                       nrow=d$nrow, ncol=d$ncol, buffer=0)
        gosmall(i, coreonly=FALSE)
        tileinit(rowsize=tilesize, buffer=0) # this is tiling the subgrid
        writeblock(x=g, path=outpath, as.integer=writeinteger)
      }  # end loop through tiles (within a subgrid)
      cat("") 
    } # end loop through subgrids
    
  } # END part 1 (regular tiles)
  
  
  
  #------------------------------------------------------------------------------------------------#
  #
  # Part 2 - Index based tiling
  #
  #------------------------------------------------------------------------------------------------#
  require(rgdal)
  if(!missing(index)){
    
    if(is.null(server)){
      cleanup()
      gridinit()
    }
    
    gobig <- function(){
        cleanup()
        if(!is.null(server)){
          gridinit(server=server, port=port)
          if(!getwindow()$set) setwindow(complete)
        } else {
          gridinit()
          setwindow(complete)       
        }
    }
    
    
    gosmall <- function(x){
        cleanup()
        gridinit()
        setwindow(x)
    }
    
    cdesc <- griddescribe(complete)
    writeinteger <- switch(cdesc$type, 
                           "real" = FALSE, 
                           "integer" = TRUE, 
                           stop("The complete grid \"", complete, "\" is either missing or of an unregonized type.")
    )
    
    # Build index of the bounding boxes for each polygon in the index file 
    a <- buildsubgridindex(index=index, window=cdesc, id.field=id.field, buffer=buffer, limit.extent)
    ids <- a$ids  # the id names 
    bounds <- a$bounds  # bounding boxes for the core of each subgrid
    bbounds <- a$bbounds # bounding boxes for the buffered subgrids
    ind <- a$ind  # SpatialPolygonsDataFrame containing the polygons we are intersted in
    rm(a)
    
    # Loop through each polygon copy it to a new grid
    for(i in 1:nrow(ind)){
      
      
      # Set output path for this subgrid
      if(grepl("[tile]", fixed=TRUE, x=parts)){
        outpath <- gsub("[tile]", ids[i], fixed=TRUE, x=parts)
      } else {
        outpath <- paste(parts, ids[i])
      }
      outdir <- gsub("/[^/]+$", "", outpath)
      if(!file.exists(outdir)) dir.create(outdir, recursive=TRUE)
      cat("Working on sub-grid ", i, " of ", length(ids), ' : "', outpath, '"', "\n", sep="")
      
      # Determine extent of this subgrid
      cellsize <- cdesc$cellsize
      celloffset <- (bbounds[i, "xmin"] - cdesc$xll) %/% cellsize
      xll <- cdesc$xll + cellsize * celloffset
      celloffset <- (bbounds[i, "ymin"] - cdesc$yll) %/% cellsize
      yll <- cdesc$yll + cellsize * celloffset
      ncol <- ceiling( (bbounds[i, "xmax"] - xll ) / cellsize)
      nrow <- ceiling( (bbounds[i, "ymax"] - yll ) / cellsize)
      l <- list(xll=xll, yll=yll, nrow=nrow, ncol=ncol, cellsize=cellsize)
      
      # Set window to subgrid and tile subgrid for copying
      gosmall(l)
      tileinit(tilesize, buffer=0)
      n <- ntiles()
      for(j in 1:n){
        cat("Tile ", j, "of", n, "\n")
        settile(j)
        td <- tiledetails()
        gobig()
        t <- readblock(path=complete, extent=td)
        gosmall(l)
        writeblock(t, path=outpath, as.integer=writeinteger)
        tileinit(tilesize, buffer=0)      
      } # for each subtile
      
    } # end for each subgrid
    
  } # end part 2 (indexed subgrid)
  
} # end function definition


