
if(FALSE){  # example and testing code
  
  library(gridio)
  
  # Make dataset (include NA's in all grids)
  a <- as.grid(x = matrix(rnorm(10000, mean = seq(from = 1, to = 3, length.out = 10000)),nrow = 100, ncol = 100 ), xll = 0, yll = 0, cellsize = 30)
  b <- a
  b$m[] <- rep(1:10, each = 1000)
  c <- b
  c$m <- matrix(rep(1:10, each = 1000), nrow = 100, ncol = 100, byrow = TRUE) 
  a$m[2, ] <- NA
  b$m[, 2] <- NA
  c$m[6:15, 6:15] <- NA
  
  
  # Plot
  plot(a)
  plot(b)
  plot(c)
  
  
  # Calculate stats on grids in memory
  res <- gridstats(x = a, by = list(b= b, c= c))
  
  
  
  # Setup grids on disk
  dir <- tempdir()
  dir.create(dir)
  paths <- paste0(dir, letters[1:3])
  gridinit()
  setwindow(a)
  writegrid(a, path = paths[1])
  writegrid(b, path = paths[2])
  writegrid(c, path = paths[3])
  
  
  library(anthill)
  config()
  
  # Calculate stats on grids on disk (using local session)
  res2 <-  gridstats(x = paths[1], by = list(b = paths[2], c = paths[3]))
  standard.cols <- c("min", "max", "count", "sum", "sd", "mean", "countNA")
  
  # And via anthill
  pgridstats(x = paths[[1]], by = list(b= paths[2], c= paths[3]), 
             result.file = paste0(dir, "results.rds"), owner = "Your Initials", name = "statstest")
  
} # end 


tilestats <- function(tile, x, by, cacheok = TRUE ){
  settile(tile)
  x.t <- readtile(x, cacheok = cacheok)
  by.t <- lapply(by, FUN = readtile, cacheok = cacheok) 
  res <- gridstats(x = x.t, by = by.t)
  return(res)
}


gridstats <- function(x, by, tilesize = 2000, tiles, cacheok = TRUE){
  # cat("gridstats called on", class(x), "object\n")
  standard.cols <- c("min", "max", "count", "sum", "sd", "mean", "countNA")
  if(any(names(x) %in% standard.cols)) 
    stop("can't use ", intersect(names(x), standard.cols), " as a gridname.") 
  if( inherits(x, "character")){
    
    tileinit(tilesize, 0)
    if(missing(tiles)) tiles <- 1:ntiles()
    
    res <- lapply(tiles, FUN = tilestats, x= x, by = by, cacheok = cacheok)
    return(mergestats(res))
    
  } else if(inherits(x, "grid")){
    l <- c(list(x=x), by)
    d <- assembledataframe(l)
    grps <- do.call(group_by_, args = c(list(.data = d), as.list(names(d)[-1])))
    res <- dplyr::summarise(grps, 
                     min = min(x, na.rm = TRUE),
                     max = max(x, na.rm = TRUE), 
                     count = sum(!is.na(x)), 
                     sum = sum(as.numeric(x), na.rm = TRUE), 
                     sd = sd(x, na.rm = TRUE),
                     mean = NA,
                     countNA = sum(is.na(x)) )
    
    res$mean <- res$sum / res$count
    return(as.data.frame(res))
  } else {
    stop("x should be a path to a grid on disk or a grid object")
  } 
}


# Function to assemble a dataframe from a list of grids
# column names come from names in the list
# Value is a 


mergestats <- function(x){
  library(dplyr)
  standard.cols <- c("min", "max", "count", "sum", "sd", "mean", "countNA")
  combine.sd <- function(mean.a, count.a, sd.a, mean.b, count.b, sd.b, mean.c){
    if(count.a > 0 & count.b > 0)
      return(sqrt( ( count.a * ( sd.a^2 +  (mean.a - mean.c)^2 )  + count.b * ( sd.b^2 + (mean.b - mean.c)^2 )  )/ (count.a + count.b)))
    if(count.a > 0) return(sd.a)
    if(count.b > 0) return(sd.b)
    return(NA)
  }
  group.cols <- setdiff(names(x[[1]]), standard.cols)
  all.grps <- do.call(rbind, args = lapply(x, FUN = function(x) x[, group.cols, drop = FALSE]))
  u <- unique(all.grps) 
  u <- u[do.call(order, args = u), , drop = FALSE]  
  result <- data.frame(u, min = NA, max = NA, count = 0, sum = 0, sd = NA, mean = NA, countNA = 0)
  ids <- do.call(paste, args = u)
  
  for(i in seq_along(x)){
    cat(i, "\n")
    ids.i <- do.call(paste, x[[i]][group.cols])
    mv <- match(ids.i, ids)
    
    new.sum <- result$sum[mv] + x[[i]]$sum
    new.count <- result$count[mv] + x[[i]]$count
    new.mean <- new.sum / new.count
    
    sv <- !is.na(result$sd[mv])
    if(any(!sv))
      result$sd[mv][!sv] <- x[[i]]$sd[!sv]  # if the existing value is NA overwrite with new
    if(any(sv)){
      mv2 <- mv[sv]
      if(length(mv2) > 0)
        result$sd[mv2] <- combine.sd(mean.a = result$mean[mv2], count.a = result$count[mv2],
                                     sd.a = result$sd[mv2],
                                     mean.b =  x[[i]]$mean[sv], count.b = x[[i]]$count[sv],
                                     sd.b = x[[i]]$sd[sv], mean.c = new.mean[sv] )
    }
    
    result$min[mv] <- pmin(result$min[mv], x[[i]]$min, na.rm = TRUE)
    result$max[mv] <- pmax(result$max[mv], x[[i]]$max, na.rm = TRUE)
    result$count[mv] <- new.count
    result$sum[mv] <- new.sum
    result$mean[mv] <- new.mean  
    result$countNA[mv] <- result$countNA[mv] + x[[i]]$countNA
  }
  return(result)
}


# result.file <- "z:/Working/ethan/temp/result.Rdata"
pgridstats <- function(x, by, result.file, owner, name, tilesize = 2000, tiles, cacheok = TRUE, ...){
  
  oc <- saveconnections()
  on.exit(restoreconnections(oc))
  
  refgridinit(x)
  
  # Update gridinfo and check for missing grids
  paths <- c(x, unlist(by))
  missing = sapply(paths, FUN = function(x) griddescribe(x)$type == "missing")
  if(any(missing))
    stop("missing grid(s): '", paste(paths[missing], collapse ="'', '"), "'")
  
  # clean path to result file
  result.file <- gsub("\\\\", "/", result.file)
  
  gi <- savegridinfo()
  con <- saveconnections()
  
  tileinit(tilesize, 0)
  if(missing(tiles)) tiles <- 1:ntiles()
  
  result.dir <- gsub("/[^/]*$", "", result.file)
  stopifnot(file.exists(result.dir))
  tempdir <- paste0(result.file, ".dir")
  dir.create(tempdir)
  tempfile <- paste0(tempdir, "/[tile].rds")
  
  
  par <- list(x = x, by = by, gi = gi, con = con, tilesize = tilesize, cacheok = cacheok, tempfile = tempfile,
              tempdir = tempdir, result.file = result.file)
  
  tstats <- function(tile, par){
    library(gridio)
    restoreconnections(par$con)
    restoregridinfo(par$gi)
    tileinit(par$tilesize, 0)
    ts <- tilestats(tile = tile, x = par$x, by = par$by, cacheok = par$cacheok)
    saveRDS(ts, file = gsub("[tile]", tile, x = par$tempfile, fixed = TRUE))
  }
  
  mergetiles <- function(par, tiles){
    library(gridio)
    tilefiles <- paste0(par$tempdir, "/", tiles, ".rds")    
    stats <- lapply(tilefiles, FUN = readRDS)
    res <- mergestats(x = stats)
    saveRDS(res, file = par$result.file)
    unlink(par$tempdir, recursive = TRUE)
  }
  
  call <- c("tstats(par = par)", "wait", "mergetiles(par=par, tiles = tiles)")
  subtask = c(make.range(values = tiles), NA, NA)
  subtaskarg = c("tile", NA, NA)
  objects <- c( "mergetiles", "tstats", "tiles", "par")
  # "tilestats", "gridstats", "assembledataframe", "mergestats") # these should be dropped once they are added to package
  simple.launch(call = call, subtask = subtask,  subtaskarg = subtaskarg, owner = owner, name = name, 
                objects = objects, ...)
  
  cat("\nAfter project completes results can be read with:\n\t", 
      "readRDS('", result.file, "')\n", sep ="")
  
}








