gridstitch <- function( parts,complete, buffer,  ref, index, id.field, tilesize=2000, server=NULL, port=NULL, 
                        add=FALSE, transparent, overwrite=FALSE, core.only=TRUE){
  # Function to stich together grids that have been broken into regular tiles
  
  if(missing(transparent)) transparent <- !missing(index)
  if(!missing(index) && transparent == FALSE) 
    warning("Stiching together grids based on a polygon index with transparent set to FALSE is not advised.")  
  
  cleanup()  # disconnect from any gridserver
  refextent <- NULL
  gobig <- function(){  # this sets up for reading from the large grid
    cleanup()
    if(!is.null(server)){
      gridinit(server=server, port=port)
    } else {
      gridinit()
    }
    if(!getwindow()$set){
      if(is.null(refextent) || !refextent$set){
        setwindow(ref) 
      } else {
        setwindow(refextent)
      }
    }
  }
  gobig()
  refextent <- getwindow()
  
  ##  For debugging
  #tileinit(10000, 0)
  #plotextent()
  ##
  
  
  if(file.exists(complete)){
    if(overwrite){
      gridkill(complete) 
    } else {
      stop("The grid ", complete, " already exists. Use overwrite=TRUE or specify a different ",  
           " output path.") 
    }
  }
  
  #  Build index of the bounding boxes for each polydon in the index file 
  indexed <- FALSE
  if(!missing(index)){
    indexed <- TRUE
    a <- buildsubgridindex(index=index, window=refextent, id.field=id.field, buffer=0, limit.extent=TRUE)
    ids <- a$ids  # the id names 
    ind <- a$ind  # SpatialPolygonsDataFrame containing the polygons we are intersted in
    rm(a)
  }
  
  
  # Generate a list of paths (of input grids) 
  dir <- gsub("/[^/]*$", "", parts)
  if(!any(grepl("[tile]", parts, fixed=TRUE))){
    parts <- paste(parts, "[tile]", sep="")
  }
  if(!indexed){
    paths <- paste(dir, "/", list.files(dir), sep="")
    exp <- gsub("[tile]", "[[:digit:]]+", x=parts, fixed=TRUE) 
    exp <- paste(exp, "$", sep="")  # 
    paths <- grep(exp, x=paths, ignore.case=TRUE, value=TRUE)
  } else {
    paths <- character(length(ids))
    for(i in 1:length(ids)) paths[i] <- gsub("[tile]", ids[i], fixed=TRUE, parts)
    e <- file.exists(paths)
    if(!all(e) )stop("Missing component grids: ", paste(paths[!e], collapse=", "), sep="")
  }
  
  
  for(i in 1:length(paths)){
    path <- paths[i]
    
    if(i==1) write.as.integer <- griddescribe(path)$type == "integer"
    
    cat("\nWorking on sub-grid", i, "of", length(paths), path, "\n")
    cleanup()
    gridinit()
    setwindow(path)
    tileinit(tilesize, 0)
    
    
    # Get the extent of the core of this subgrid (trim off the buffer)
    if(!indexed){
      e <-getwindow()  # the extent
      ce <- e #  the core of the extent
      ce$xll <- ce$xll + (buffer * ce$cellsize)
      ce$yll <- ce$yll + (buffer * ce$cellsize)
      ce$nrow <- ce$nrow - (buffer * 2 ) 
      ce$ncol <- ce$ncol - (buffer * 2 ) 
    }
    
    
    for(j in 1:ntiles()){  # tile the subgrid so that we don't overwhelm R's memory.
      cat("\n\tTile ", j,  " of ", ntiles())
      # Determine the exact portion of the tile we need to read 
      # Along the edges we generally don't need to read the whole tile or possibly any of the tile.
      settile(j) 
      d <- tiledetails()
      
      
      # Read 
      
      if(!indexed){
        cat(" - reading")
        d <- gridintersect(ce, d)  # this is now the extent of the tile that overlap the core of this subgrid
        if(is.null(d)) {
          cat(" - skipped")
          next  # if there's no overlap move on to the next tile
        }
        t <- readblock(path=path, extent=d, buffer=0)
        
        #               startrow=max(1, y2r(d$yll + 0.5*d$cellsize,e ) - d$nrow + 1),  
        #               startcol=max(1, x2c(d$xll + 0.5*d$cellsize, e)), 
        #              nrow=d$nrow, ncol=d$ncol, buffer=0)
        
      } else {  # indexed
        # Make a mask that indicates which cells we want to keep 
        #  For logistical reasons TRUE in this grid is the cells we want to keep and FALSE
        #  is the cells we want to mask 
        if(core.only){
          mask <- as.SpatialPointsDataFrame(newtile())
          proj4string(mask) <- proj4string(ind) # hack to get around the fact that the projection
          # isn't defined in the mask object but over checks for identical projection
          mask2 <- over(mask, geometry(ind[i, ]))
          mask$mask <- mask2
          mask <- as.grid(mask, data.col="mask")  
          if(all(is.na(mask$m))){
            cat(" - skipping (all masked)")
            next  # if there's no overlap with the core of the polygon move on
          }
          sv <- is.na(mask$m)
          mask$m  <- matrix(TRUE, nrow=mask$nrow, ncol=mask$ncol)
          mask$m[sv] <- FALSE
          
          a <- which(apply(mask$m, 1, any))
          retained.rows <- min(a):max(a)
          a <- which(apply(mask$m, 2, any))
          retained.cols <- min(a):max(a)
        
          
          mask2 <- mask
          mask2$m <- mask$m[ retained.rows,retained.cols, drop=FALSE]
          mask2$xll <- as.numeric(mask$xll + (min(retained.cols) -1) * mask$cellsize)
          mask2$yll <- as.numeric(mask$yll + (mask$nrow - max(retained.rows)) * mask$cellsize)
          mask2$nrow <- nrow(mask2$m)
          mask2$ncol <- ncol(mask2$m)
          mask <- mask2
          rm(mask2)
          cat(" - reading")
          t <- readblock(path, extent=mask)
          t$m[!mask$m] <- NA
        } else {  # end core only
          cat(" - reading")
          t <- readtile(path)
        } 
        
        if(all(is.na(t$m))){ 
          cat(" - skipping (all NA)")
          next
        }
        
      } # end if indexed
        
      cat(" - writing (tile ", j, ", subgrid , ", i, ")")
    
      gobig()
      writeblock(t, path=complete, buffer=0, add=add, transparent=transparent,
                 as.integer=write.as.integer)
      
      cleanup()
      gridinit()
      setwindow(path)
      tileinit(tilesize, 0)
      
    }  # end loop through tiles (in subgrid)
    
  } # end loop through subgrids
  
}  # end function definition
