#--------------------------------------------------------------------------------------------------#
# gridtable(x, ...)              Ethan Plunkett                            July 31, 2012
# these functions return a table object for the entire grid.  
# If x is a character object it is assumed to be a path to a grid on disk and 
#  the function calculates information on it one tile at a time.
# If x is a grid object than the result is the same as table(x$m, useNA="ifany").
#--------------------------------------------------------------------------------------------------#
gridtable <- function(x, ...) UseMethod("gridtable")
# Generic method for gridtable

gridtable.grid <- function(x, digits=NA, ...){
  # grid method for gridtable
  a <- x$m
  if(!is.na(digits))
    a <- round(a, digits=digits)
  return(table(a, useNA="ifany"))
}

if(FALSE){
  x <- "z:/LCC/GIS/Work/Landcover/ESMplus/ner/esmplus_m"
  gridioverbosity(1)
  tilesize <- 2000
  tiles
  source("z:/LCC/LCAD/Code/buildtilemap.R")
  tm <- buildtilemap(2000)
  tiles <- tm[1:3]
  gridtable(x, 2000, tiles) # single grid
  grids <- c("z:/LCC/GIS/Work/Landcover/ESMplus/ner/esmplus_m",
             "Z:/LCC/GIS/Work/Ancillary/RegionMaps/tncecoregions_m")
  gridtable(grids, 2000, tiles) # multiple grids
}

gridtable.character <- function(x, tilesize=2000, tiles, digits=NA,  ...){
  #------------------------------------------------------------------------------------------------#
  # gridtable.character        Ethan Plunkett                   July 31, 2012
  #  Edited April 2014 - Now works with a vector of grids in which case the counts become
  #   unique combinations of values.  
  #------------------------------------------------------------------------------------------------#
  digits <- as.numeric(rep_len(digits, length.out=length(x)))
  
  tileinit(tilesize, 0)
  if(missing(tiles)) tiles <- 1:ntiles()
  l <- vector(mode="list", length=length(tiles))
  for(i in 1:length(tiles)){
    settile(tiles[i])
    d <- vector(mode="list", length=length(x))
    for(j in 1:length(x)){
      
      a <- as.vector(readtile(path=x[j])$m)
      if(!is.na(digits[j]))
        a <- round(a, digits=digits[j])
      d[[j]] <- a  
    }
    l[[i]] <- do.call(what="table", args=c(d, list(useNA="ifany")))
    if(.status$verbosity > 0)
      cat("tile", i, "of", length(tiles), "completed\n")
  }
  d <- do.call("mergetables", c(l, list(numeric=TRUE)))
  return(d)
}

if(FALSE){
  result <- "z:/Working/Ethan/test/table.Rdata"
  x <- "z:/LCC/GIS/Work/Landcover/ESMplus/ner/esmplus_m"
  library(gridio)
  library(anthill); config()
  refgridinit(x)
  gridioverbosity(1)
  tilesize <- 2000
  source("z:/LCC/LCAD/Code/buildtilemap.R")
  tm <- buildtilemap(2000)
  tiles <- tm[1:3]
  
  
  
  
  name="gridtable"
  owner = "ethan"
  
  grids <- c("z:/LCC/GIS/Work/Landcover/ESMplus/ner/esmplus_m",
             "Z:/LCC/GIS/Work/Ancillary/RegionMaps/tncecoregions_m")
  pgridtable(grids, result="z:/Working/Ethan/test/gt.Rdata", tiles=tiles, owner="ebp") # multiple grid
  
  set.priority("gridtable", 6)
  load(result)
}


pgridtable <- function(x, result, owner, name, tilesize = 2000, tiles, cacheok=TRUE, digits=NA, ...){
  if(missing(tiles)){
    oc <- saveconnections()
    refgridinit(x[1])
    tileinit(tilesize, 0)  
    tiles <- 1:ntiles()
    on.exit(restoreconnections(oc))
  }
  digits <- as.numeric(rep_len(digits, length.out=length(x)))
  if(!grepl("\\.Rdata$", result))
    stop("Result should be the path to a file with extension '.Rdata'")
  dir <- gsub("[/\\\\][^/\\\\]*$", "", result)
  if(!file.exists(dir)) 
    stop("Output directory does not exist.  Create it before running.")
  if(missing(owner)) stop("owner is not optional.  What's your name?")
  if(missing(name)) name = "gridtable"
  
  basepath <- gsub("\\.Rdata", "", result)
  tiledir <- paste(basepath, "_tiles", sep="")
  if(!file.exists(tiledir)) dir.create(tiledir)
  
  tableone <- function(x, tile, tilesize, basepath, cacheok, digits){
    library(gridio)
    refgridinit(x[1])
    tileinit(tilesize, 0)
    settile(tile)
    d <- vector(mode="list", length=length(x))
    for(j in 1:length(x)){
      a <- as.vector(readtile(path=x[j], cacheok=cacheok)$m)
      if(!is.na(digits[j])){
        a <- round(a, digits=digits)
      }
      d[[j]] <- a
    }
    t <- do.call(what="table", args=c(d, list(useNA="ifany")))
    file <- paste(basepath, "_tiles/", tile, ".Rdata", sep="")
    save(t, file=file)
  }  
  
  merge <- function(tiles, basepath){
    paths <-paste(basepath, "_tiles/", tiles, ".Rdata", sep="")
    l <- vector(mode="list", length=length(paths))
    for(i in 1:length(l)){
      load(paths[i])
      l[[i]] <- t
    }
    d <- do.call("mergetables", c(l, list(numeric=TRUE)))
    save(d, file=paste(basepath, ".Rdata", sep=""))
    unlink(paste(basepath, "_tiles", sep=""), recursive=TRUE) # delete the individual tile data
  }
  call <- c("tableone(x,tilesize, basepath, cacheok, digits)", "wait", "merge(tiles, basepath)")
  subtaskarg <- c("tile", NA, NA)
  subtask <- c(paste("range:", compact.range(tiles), sep=""), NA, NA)
  
  simple.launch(call=call, subtaskarg=subtaskarg, subtask=subtask, name=name, owner=owner, ...)
  
}
