
if(FALSE){

  grid.path <- "z:/LCC/GIS/Future/kernelgrids/ner/bdev_400"

}

launchbatchstitch <- function(x, owner, reference = "Z:/LCC/GIS/Work/Ancillary/Reference/ref_ner", 
                              host = "W00", parallel = FALSE, name = "batchstitch", ...){
  #------------------------------------------------------------------------------------------------#
  # Function to launch batchstitch on the cluster
  # This relies on the new host functionality which controls which machines a project can run on.
  # The default values of most arguments are set to work on the LCD Northeast Region Grids on the
  # landscape ecology cluster to make this more broadly useful I could add a default reference grid
  # to anthill's config file; alternatively someone could write a wrapper with their own defualts.
  # 
  # Arguments:
  #    x : a vector of mosaics to stitch
  #    owner : the owner of the project on anthill (your name)
  #    reference : the path to a full reference grid that the stitched grid will ultimately match up with
  #    host : the computer on which stitching should be done.  Stitching relies on arcpy which 
  #       throws errors with network drives so this should be the host for which the drive that the mosaic is on
  #         is local.  In the landscape ecology lab this is W00 for Z: and L00 for X
  #    parallel :  if FALSE the default than a single anthill task will stitch all the grids in sequence if TRUE than 
  #       each grid will be stitched as a separate task.  Only use TRUE if the mosaics you are stitching reside 
  #      in separate directories.  Also, TRUE is probably unadvisable when you have a long list of 
  #      mosaics most of which are up-to-date, as the overhead would be high for checking each grid.
  #   name : the project name on anthill
  # 
  
  
  if(!anthillrunning()) stop("Anthill must be loaded and configured prior to calling this.")
  if(parallel){
    fun <- function(i){
      library(gridio)
      gridinit()
      res <- batchstitch(x[i], reference)
      if(res$error[1]) stop(res$message[1])
    }
    simple.launch(call="fun()", name = name, owner = owner, subtaskarg = "i", 
                  subtask = make.range(length(x), scramble = FALSE), 
                  objects = c("fun", "x", "reference"), host= host, ...)
  } else {
    # Not parallel.  Still runs on cluster but one thread process all the grids sequentially
    fun <- function(){
      library(gridio)
      gridinit()
      res <- batchstitch(x, reference)
      if(any(res$error))stop("mosaics ", paste(which(res$error), collapse =" "), "failed to stitch.")
    }
    simple.launch(call="fun()", name = name, owner = owner,objects = c("fun", "x", "reference"),
                  host = host, ...)
  }
}


