#
if(FALSE){ # This first block is test and example code
  
  ### Setup a temporary directory with a sample grid in it 
  # Get path to example dem grid (included with package)
  require(gridio)
  
  source("X:/gridiolib/gridio.test/update.package.R")
  
  
  
  # Make a temporary directory to write new grids to
  if(FALSE){
    datapath <- system.file("exampledata", package="gridio")  # grid path to example grid
    datapath <- shortPathName(datapath)
    datapath <- paste(datapath, "/.", sep="")
    
    # dir <- tempdir() # get temporary directory
    if(!file.exists(tempdir)) dir.create(tempdir, recursive=TRUE)
    
    tempdir <- gsub("\\\\", "/", tempdir)
    # Clear it out
    if(file.exists(tempdir)) unlink(tempdir, recursive=TRUE)
    if(!file.exists(tempdir)) dir.create(tempdir)
    list.files(tempdir)
    
    # Copy example data into temporary directory
    file.copy(datapath, tempdir, recursive=TRUE)
    
    # Make a mask grid  
    cleanup()
    gridinit()
    dem <- paste(tempdir, "/dem", sep="")
    mask <- paste(tempdir, "/mask", sep="")
    setwindow(dem)
    g <- readgrid(dem)
    g$m[,] <- NA
    g$m[row(g$m) + col(g$m) > 300] <- 1 
    plot(g, use.old=TRUE)  
    writegrid(g, path=mask)
    
  } # end skip
  
  tempdir <- "C:/temp/gridiotest/makemosaic"
  
  
  # Setup paths
  source <- paste(tempdir, "/dem", sep="")
  mosaic <- paste(tempdir, "/demmosaic", sep="")
  mosaic2 <- paste(tempdir, "/demmosaic2", sep="")
  mosaic3 <- paste(tempdir, "/demmosaic2", sep="")
  mask <- paste(tempdir, "/mask", sep="")
  rowsize <- 100
  colsize <- 100
  tilesize <- 50
  server=NULL
  port=NULL
  
  unlink(mosaic, recursive=T)
  makemosaic(source, mosaic, 100)
  
  unlink(mosaic2, recursive=T)
  makemosaic(source, mosaic2, reference=mask,  100)
  
  panemap <- '000101111110'
  unlink(mosaic3, recursive=T)
  makemosaic(source, mosaic3, panemap=panemap,  100)
  
  gs <- readgridservers()
  mosaicinit(servers=gs, reference=mosaic)
  g <- readgrid(mosaic)
  
}  # END TESTING CODE


# makemosaic 
# Arguments:
# 1.	source - path and name of existing grid
# 2.	mosaic - path and name of new mosaicked grid
# 3.	rowsize - number of cell rows in each pane
# 4.	colsize - number of cell columns in each pane
# 5.	panemap (optional) - logical vector indicating which panes have data.
#        Use mosaicinfo to get the panemap from another mosaic.
# 6.	reference (optional) - a reference grid used to populate panemap
# 7.  tilesize - the size of the tiles that are read and written in each operation. This is independent of the
#      colsize and rowsize that are used to define the mosaic components on disk.
# 8.  server (optional) - the server used for interacting with the whole landscape
# 9.  port (optional) - the port used for interacting withthe whole landscape 
#  If neither panemap nor reference are supplied, the panemap is generated from the source grid.
#  If server is undefined than reads will be done in local mode.  (Writes are always local)

makemosaic <- function(source, mosaic, rowsize,  colsize=rowsize, panemap, reference, tilesize=2000,
                       server=NULL, port=NULL){
  
  
  # set the mode we are using to generate the panemap
  mapmode <- "source"
  if(!missing(reference)) mapmode <- "reference"
  if(!missing(panemap)) mapmode <- "panemap"
  
  source <- gsub("\\\\", "/", source) # convert to forward slashes
  source <- gsub("/$", "", source)  # drop trailing slash 
  
  
  mosaic <- gsub("\\\\", "/", mosaic) # convert to forward slashes
  mosaic <- gsub("/$", "", mosaic)  # drop trailing slash 
  name <- gsub("^.*/", "", mosaic)  
  now <- function() format(Sys.time(), format = .status$timeformat)
  
  cleanup()  # disconnect from any gridserver
  
  gobig <- function(){  # this sets up for reading from the large grid
    cleanup()
    if(!is.null(server)){
      gridinit(server=server, port=port)
    } else {
      gridinit()
    }
    if(!getwindow()$set){
      setwindow(source) 
    }
    tileinit(rowsize=rowsize, 0, colsize=colsize)
  }
  
  gosmall <- function(tile, coreonly=FALSE){  # this sets up for reading or writing from a component grid
    gobig()
    settile(tile)    
    e <- tiledetails(coreonly=coreonly)
    cleanup()
    gridinit()
    setwindow(e)
  }
  
  gobig()
  sdesc <- griddescribe(source, cache = FALSE)
  
  if(mapmode == "reference"){
    rdesc <- griddescribe(reference)
    if(rdesc$type == "missing") stop("reference grid is missing")
  }
  
  writeinteger <- switch(sdesc$type, 
                         "real" = FALSE, 
                         "integer" = TRUE, 
                         stop("The source grid \"", source, "\" is either missing or of an unregonized type.")
  )
  
  # Get a lock on the mosaic directory and make it
  if(anthillrunning()){
    get.lock(mosaic)
    on.exit(return.lock(mosaic))
  }
  if(file.exists(mosaic)) stop("Mosaic directory already exists. Can't make new mosaic.")
  makedir(mosaic, recursive=TRUE, locking=FALSE)
  
  
  e <- getwindow()  # the extent of the entire landscape (big grid)
  n <- ntiles()
  
  # Make panemap a logical vector
  if(mapmode == "panemap"){
    if(is.character(panemap))
      panemap <-  as.logical(as.numeric(strsplit(panemap, split=character(0))[[1]]))
  } else { 
    panemap <- rep(TRUE, n)
  }
  
  # Preallocate object to store paneinformation
  paneinfo <- data.frame(drive=rep(NA, n), server=NA, port=NA, active=1, ncol=NA, nrow=NA, 
                         xll=NA, yll=NA, cellsize=NA, landscape=NA, comment=NA)
  
  paneinforow <- 1  #the row we are currently writing to)
  paneinfoitems <- c("xll", "yll", "nrow", "ncol", "cellsize")  # fields populated from the pane's window
  paneinfomv <-match(paneinfoitems, table=colnames(paneinfo))  # match vector used to fill in table
  
  
  for(i in 1:n){  # Loop through panes
    
    # if the panemap is supplied skip panes that aren't needed
    if(!panemap[i]) next
    
    cat("Working on pane", i, "of", n, "\n")
    
    
    outpath <- panepath(mosaic, id=i, npanes=n) 
    outdir <-  sub("(/|\\\\)[^/\\\\]*$","", outpath )
    makedir(outdir, locking=FALSE)
    
    gosmall(i, coreonly=FALSE)  # set extent to this subgrids extent
    pane <- getwindow()
    tileinit(rowsize=tilesize, buffer=0) # this is tiling the subgrid into readable chunks
    
    panehasdata <- FALSE
    for(j in 1:ntiles()){  # iterate through tiles in the subgrid  
      settile(j)
      d <- tiledetails()
      gobig()
      g <- readblock(path=source, 
                     startrow=max(1, y2r(d$yll + 0.5*d$cellsize,e ) - d$nrow + 1),  
                     startcol=max(1, x2c(d$xll + 0.5*d$cellsize, e)), 
                     nrow=d$nrow, ncol=d$ncol, buffer=0)
      if(mapmode == "source")  if(!all(is.na(g$m) | g$m == 0) ) panehasdata <- TRUE
      
      if(mapmode == "reference"){
        ref <- readblock(path=reference, 
                         startrow=max(1, y2r(d$yll + 0.5*d$cellsize,e ) - d$nrow + 1),  
                         startcol=max(1, x2c(d$xll + 0.5*d$cellsize, e)), 
                         nrow=d$nrow, ncol=d$ncol, buffer=0)
        if(!all(is.na(ref$m) | ref$m == 0) ) panehasdata <- TRUE
      }
      
      gosmall(i, coreonly=FALSE)
      tileinit(rowsize=tilesize, buffer=0) # this is tiling the subgrid
      
      writeblock(x=g, path=outpath, as.integer=writeinteger)
    }  # end loop through tiles (within a subgrid)
    
    # Update panemap if it wasn't supplied and delete (empty)
    #  output panes if they didn't have any data and thus aren't in the map.
    if(mapmode %in% c("reference", "source")){
      panemap[i] <- panehasdata
      if(!panehasdata){
        gridkill(outpath)
        next
      }
    }
    
    # Save data on this pane
    paneinfo[paneinforow, paneinfomv] <- unlist(pane[paneinfoitems])
    paneinfo$comment[paneinforow] <- paste("Pane ", i)
    paneinforow <- paneinforow + 1
    
  } # end loop through panes
  
  st <- fileinfo(x=paste(source, "/sta.adf", sep=""))$date
  gobig()
  ts <- tilescheme()
  
  # convert panemap into character
  panemap <- paste(as.character(as.integer(panemap)), collapse="")
  
  # Write descriptor file
  lines <- c( 
    paste("name = '", name,"'", sep=""), 
    "type = 'derived'", 
    paste("timestamp = '", now(), "'", sep=""), 
    paste("source = '", gsub("/", "\\\\", source), "'", sep=""), 
    paste("sourcetimestamp = '",   format(st, format =.status$timeformat), "'" , sep=""), 
    paste("extent = ", 
          with(sdesc, paste(ncol,
                            nrow, 
                            formatdouble(xll), 
                            formatdouble(yll), 
                            formatdouble(cellsize),
                            "-9999", # nodata 
                            ifelse(type=="integer", 1, 2), sep=",")), 
          sep=""),
    paste("rowsize = ", rowsize, sep=""),
    paste("colsize = ", colsize, sep=""),
    paste("rows = ", ts$rows, sep=""), 
    paste("cols = ", ts$cols, sep=""), 
    paste("panemap = '", panemap, "'", sep="")
  )
  writeLines(lines, con=paste(mosaic, "/mosaicdescrip.txt", sep=""))
  
  # Write pane info to gridservers.txt within mosaic folder
  paneinfo <- paneinfo[1:nrow(paneinfo) < paneinforow, ]  # drop unused rows
  
  paneinfo$xll <- formatdouble(paneinfo$xll)
  paneinfo$yll <- formatdouble(paneinfo$yll)
  paneinfo$cellsize <- formatdouble(paneinfo$cellsize)
  
  gridiowritetable(x=paneinfo, file=paste(mosaic, "/gridservers.txt", sep=""))
  
  # Remove info on this grid from gridinfo cache 
  if(mosaic %in% ls(.status$gridinfo))
    rm(list=mosaic, envir = .status$gridinfo)
  
} # end function definition
