# assignInNamespace("makewindow", makewindow, ns="gridio")

makewindow <- function(nrow, ncol, xll, yll, cellsize){
  #--------------------------------------------------------------------------------------------------#
  
  # makewindow   Ethan Plunkett Jan 2011
  #
  #  Function to make an access window without refrencing a grid file
  #  Arguments:
  # nrow, ncol: the number of rows and columns in the grid
  #xll, yll : the x and y coordinates of the lower left corner
  #cellsize : the dimensions of each cell (they must be square)
  
  #--------------------------------------------------------------------------------------------------#
  # Arguments (c function):
  #	  err  (int*)   :  pointer to a  variable containing the error code
  #    y_count   (int*)    : pointer to a variable containing the number of rows in the target grid
  #    x_count   (int*)    : pointer to a variable to receive the number of columns in the target grid
  #    y_ll      (double*) : pointer to a variable to receive the y coordinate of lower left corner
  #    x_ll      (double*) : pointer to a variable to receive the x coordinate of lower left corner
  #    cell_size (double*) : pointer to a variable to receive the size of a cell in map units 
  #	  block_only(int*)    : pointer to a variable to receive the server mode: 1 if only block 
  #			IO is permitted, 0 otherwise
  #
  #--------------------------------------------------------------------------------------------------#
  
  if(is.na(.status$activeconnection$connection)) stop("There is no active connection. Call gridinit() prior to setwindow() or makewindow()")
  
  r <- .makewindow(nrow, ncol, xll, yll, cellsize)
  
  check <- checkwindow(r) 
  if(!check$r){
    .cleanup()
    con <- .status$activeconnection$connection
    local <- .status$connections$local[.status$activeconnection$connection] || .status$activeconnection$cache
    if(local){
      .gridinit(server="", local=TRUE, log=.status$connections$log[con])
    } else {   
      .gridinit(server=.status$connections$server[con], 
                local=FALSE,
                port = .status$connections$port[con], 
                log = .status$connections$log[con]
      )
    }
    stop("New window doesn't align with prior windows.", check$msg)
  } # end failed check
  
  for(i in c("nrow", "ncol", "xll", "yll", "cellsize","set")) 
    .status$connections[.status$activeconnection$connection, i] <- r[[i]] 
  
  
  if(is.na(.status$referencewindow$cellsize)){
    for(i in names(r))  .status$referencewindow[[i]] <- r[[i]]
    .status$workingresolution <- r$cellsize
  }
  
  
  invisible(r)
}

