if(FALSE){  # Example usage and test code
  library(gridio)
  source("x:/gridiolib/gridio.test/update.package.R")
  reference <- "c:/temp/gridiotest/makemosaic/dem/" 
  cleanup()
  
  gridinit()
  setwindow(reference)
  rowsize <- 100;colsize <- 100
  tileinit(rowsize=rowsize, colsize=colsize, buffer=0)  
  plotextent()
  library(anthill)
  config(path="x:/anthill/control") # for ethan's machine
  gs <- readgridservers()
  servers <- gs
  
  gridinit(add=TRUE, drive="C:")
  setwindow(reference)
  
  w <- griddescribe(reference)
  findconnection(w, "c:/test")
  
  cleanup()
  reference <- "c:/temp/gridiotest/makemosaic/demmosaic/"
  mosaicinit(servers=gs, reference=reference)
  
  
  
  .status$connections
  setconnection(1)
  activateconnection()
  setconnection(2)
  activateconnection()
  .status$activeconnection
  
  cleanup()
  mosaicinit(reference=reference)  
  
}


mosaicinit <- function( reference,  servers,  rowsize, colsize, panemap, log=FALSE, desc){
  #--------------------------------------------------------------------------------------------------#
  #   Defines the mosaic scheme for all grids.  Must be called before reading/writing mosaic grids.  
  #   It needs to know:
  #     rowsize
  #     colsize
  #     panemap - string with compressed binary vector (e.g., 001010) indicating which panes contain data
  #     servers - either:
  #       vector of server names (empty for local server), corresponding to 1's in panemap
  #       the body of gridservers.par (used to populate servers and ports)
  #   
  #     ports - vector of server ports, corresponding to servers
  
  #     reference - (optional) either:
  #       - path to a mosaic.  Populates rowsize, colsize, window, and panemap (all from mosaic
  #       descriptor). 
  #       - path to a reference grid matching the entire virtual mosaic grid. Populates
  #       window and panemap (zero or nodata in panes -> 0, values -> 1) 
  #       - If reference is omitted then
  #       rowsize, colsize, window, and panemap must be supplied as individual arguments (not yet
  #       implemented in APL version).
  #   Mosaic and extent input comes either from:
  #     all values as arguments,  
  #     or, arguments are a path to a mosaic
  #     or, arguments are a path to a reference grid, rowsize, colsize
  #   Gridserver info comes either from:
  #     gridservers.par
  #   or as vectors of servers,  ports, and drives corresponding to the non-missing panes  --- NOT IMPLEMENTED YET
  #   It checks:
  #     That the virtual window of the new mosaic is compatible with the referencewindow by 
  #     calling CHECKWINDOW.
  #   It sets:
  #     mosaic
  #     mosaicwindow
  #     referencewindow and workingresolution if they aren't defined already.
  #     and it creates connections for each pane.  
  
  #--------------------------------------------------------------------------------------------------#
  # reference <- "c:/temp/gridiotest/makemosaic/demmosaic/" ; cleanup(); gridinit()
  if(.status$verbosity > 2) cat('mosaicinit called\n')
  call.cleanup <- FALSE 
  if(missing(reference)) { 
    w <- getwindow()
    if(!w$set) stop("No reference grid supplied and the reference window isn't set via a prior call to gridinit.")
    window <- w[c("nrow", "ncol", "xll", "yll", "cellsize")]
    no.connections <- FALSE
  } else {  # reference argument used
    if(missing(desc)){
      if(is.na(.status$activeconnection$connection)){ # if no connections
        gridinit()
        call.cleanup <- TRUE
      }
      desc <- griddescribe(reference)
    }    
    
    if(desc$type == "missing") stop("The supplied reference grid can't be read: ", reference)
    if(desc$mosaic){  # reference is a mosaic
      md <- desc$mosaicinfo
      rowsize <- md$rowsize
      colsize <- md$colsize
      panemap <- md$panemap
      window <- md$extent
    } else {  # reference is a grid (not mosaic)
      con <- findconnection(desc, reference)
      if(is.na(con)){
        gridinit()
        setwindow(desc)
      } else {
        setconnection(con)
      }
      
      # Get extent information on each pane
      tileinit(rowsize=rowsize, colsize=colsize, buffer=0)
      npanes <- ntiles()
      paneinfo <- list(length(npanes))
      for(i in 1:npanes){
        settile(i)
        paneinfo[[i]] <- tiledetails()
      }
      
      # Read in managable tiles and compare to panes to update panemap
      panemap <- rep(FALSE, npanes)
      tileinit(2500, 0)
      cat("Reading tiles from ", reference, " to build panemap. This may take a while.")
      for(i in 1:ntiles()){
        settile(i)
        t <- readtile(reference, cacheok=TRUE)
        for(j in 1:npanes){
          # j <- 1
          ct <- gridclip(t, paneinfo[[j]])
          if(any(!is.na(ct$m) & !ct$m == 0)) panemap[j] <- TRUE
        }
      }
      window <- desc[c("nrow", "ncol", "xll", "yll", "cellsize")]
    }  # end reference grid supplied (not mosaic)    
  } # end refernece argument used
  
  if(call.cleanup) cleanup()  # put things back as they were
  
  # Make sure everything is copesetic
  if(missing("rowsize") | missing("colsize")) stop("rowsize and/or colsize is undefined")
  if(missing( "window")) stop("window is undefinied")
  if(missing( "panemap")) stop("panemap is undefinied")
  if(!all(.status$extentitems %in% names(window))) stop("Window is missing some components")
  r <- checkwindow(c(window, list(set=TRUE)))
  if(!r$r) stop("New window created by mosaicinit isn't compatible with prior windows: ", r$msg)
  
  newmosaicwindow <- window[.status$extentitems]
  newmosaic <- list(
    rowsize=rowsize,
    colsize=colsize,
    rows = ceiling(window$nrow / rowsize),
    cols = ceiling(window$ncol / colsize),
    lastrowsize = window$nrow %% rowsize,
    lastcolsize = window$ncol %% colsize,
    panemap = panemap
    
  )
  newmosaic$panes <- newmosaic$rows * newmosaic$cols
  if(newmosaic$lastrowsize == 0) newmosaic$lastrowsize <- rowsize
  if(newmosaic$lastcolsize == 0) newmosaic$lastcolsize <- colsize
  
  if(!is.na(.status$mosaic$rowsize)){  # if mosaic is already defined
    problem <- FALSE  
    if(!isTRUE(all.equal(.status$mosaicwindow, newmosaicwindow))) problem <- TRUE
    if(!isTRUE(all.equal(.status$mosaic, newmosaic)) ) problem <- TRUE
    if(problem){
      warning("Prior mosaic doesn't match new mosaic.  Dropping prior mosaic.")
      .status$connections <- .status$connections[is.na(.status$connections$pane), , drop=FALSE] 
    }
  }
  
  if(.status$verbosity > 5) cat("\t\tmosaicinit: done gathering data.\n")
  
  .status$mosaic <- newmosaic
  .status$mosaicwindow <- newmosaicwindow
  
  # Now figure out the connections
  for(i in which(panemap)){
    # i <- 1 
    pd <- panedetails(i)
    
    if(!missing(servers) && is.data.frame(servers)){    
      matches <- rep(FALSE, nrow(servers))
      for(j in 1:nrow(servers))
        matches[j]  <- coincide(pd, as.list(servers[j, ])) 
      
      sr <- which(matches) # server row
      n <- length(sr)
      if(n==0) 
        stop("There is no server for the window: ", 
             paste(names(window), ": ", (unlist(window)), collapse=", ", sep=""))  
      if(n >1){
        # Previously I didn't allow any duplicated windows.  Now I allow duplicated windows as 
        # long as they don't have identical associated drives 
        if(any(duplicated(servers$drive[sr])))
          warning("Multiple matching servers in list with identical drive letters.  Using those higher on the list.")
        sr <-sr[!duplicated(servers$drive[sr])]
      }
      for(j in sr){
        s <- servers$server[j]
        local <- is.null(s) || is.na(s) || s == "" 
        new.connection <- data.frame(set=local,   
                                     xll=pd$xll, 
                                     yll=pd$yll, 
                                     nrow=pd$nrow, 
                                     ncol=pd$ncol,
                                     cellsize=pd$cellsize, 
                                     local=local,
                                     server=servers$server[j], 
                                     port=servers$port[j],
                                     log=log, 
                                     pane=i,
                                     drive=servers$drive[j])
        .status$connections <- rbind(.status$connections, new.connection) 
      }                                                                 
      
    }  # end server was data frame
    
    if(missing(servers)){
      new.connection <- data.frame(set=TRUE,   
                                   xll=pd$xll, 
                                   yll=pd$yll, 
                                   nrow=pd$nrow, 
                                   ncol=pd$ncol,
                                   cellsize=pd$cellsize, 
                                   local=TRUE,
                                   server=NA, 
                                   port=NA,
                                   log=log, 
                                   pane=i,
                                   drive=NA)
      .status$connections <- rbind(.status$connections, new.connection) 
    }
    
    
  } # end loop through panes 
  
  
  # if the reference window isn't set set it to the window
  if(is.na(.status$referencewindow$xll)) .status$referencewindow <- .status$mosaicwindow
  
  # Cleanup duplicated pane connections this drops rows for which all of the listed columns are identical
  a <- .status$connections
  a <- a[ , c( "xll", "yll", "nrow", "ncol", "cellsize", "drive")]
  # Note I debated on whether or not "local" should be in there but drive already pretty much covers that
  sv <- duplicated(a)
  if(any(sv)){
    warning("Some connections are identical and are being dropped.")
    .status$connections <- .status$connections[!sv, ]
  }
  
  if(.status$verbosity > 5) cat("\t\tmosaicinit:setting connnection.\n")
  
  # set connection to a random pane
  con <- sample(which(!is.na(.status$connections$pane)), size=1)
  setconnection(con)
  setcache(TRUE)  # This might need to be set back to TRUE try with caching off
  activateconnection()
  
  # set default write format to mosaic
  .status$as.mosaic <- TRUE
  
  
} # end function definition
