
# loop through rows and cols
#(row and col should be focal row and column)


if(FALSE){  # example usage
  
  ### Setup a temporary directory with a sample grid in it 
  # Get path to example dem grid (included with package)
  require(gridio)
  datapath <- system.file("exampledata", package="gridio")  # grid path to example grid
  datapath <- shortPathName(datapath)
  datapath <- paste(datapath, "/.", sep="")
  
  # Make a temporary directory to write new grids to
  dir <- tempdir() # get temporary directory
  if(!file.exists(dir)) dir.create(dir)
  
  # Copy example data into temporary directory
  file.copy(datapath, dir, recursive=TRUE)
  # system(paste("open", dir)) # if you want to look at contents of temporary directory
  ###  Done setting up directory
  
  # Setup paths
  dem <- paste(dir, "/dem", sep="") # path to dem file.
  mwsd <- paste(dir, "/sd", sep="") # path to dem file.
  
  # initialize
  cleanup() # disconnect from any prior gridservers 
  gridinit()
  setwindow(dem) # setwindow to dem file
  
  grid <- readgrid(dem)
  
  # Calculate a moving window mean on a grid in memory
  gmean <- movingwindow( grid, radius = 10,  FUN = mean, na.rm = TRUE)
  
  # Calculate a moving window sd on a grid on disk
  movingwindow(x = dem, radius = 10, FUN = sd, na.rm = TRUE, outgrid = mwsd, overwrite = TRUE, tilesize = 300)  
  gsd  <- readgrid(mwsd)
  
  
  
}


movingwindow <- function(x, radius, FUN, ...) 
  UseMethod("movingwindow")

movingwindow.character <- function(x, radius, FUN, outgrid, tilesize, overwrite = FALSE,  tiles, cacheok, as.integer = FALSE, ... ){
  
  if(!missing(tiles) & missing(tilesize)) 
    stop("If you specify tiles to run you must also specify the tilesize.")
  if(missing(tilesize)) tilesize = 2000
  
  if(missing(cacheok)) cacheok <- anthillrunning()
  
  if(!getwindow()$set) stop("gridinit must be called prior to this function.")
  xinfo <- griddescribe(x)
  if(xinfo$type == "missing") stop("Grid", x, "not found.")
  for(i in c("nrow", "ncol", "xll", "yll", "cellsize")){
    if(xinfo[[i]] != getwindow()[[i]]) 
      stop("Window extent does not match grid. Call setwindow first.")
  }
  
  if(missing(outgrid)) stop("you must specify an output grid (outgrid)")
  if(griddescribe(outgrid)$type != "missing"){
    if(overwrite) 
      gridkill(outgrid)
    else
      stop("grid \"", outgrid, "\" already exists use overwrite=TRUE or a different output grid.")
  }
  # check for valid output path
  check <- checkgrid(outgrid, pathonly = TRUE)
  if(check$problem){
    check$problem <- NULL
    stop("invalid outgrid path: ", paste(names(check)[unlist(check)], collapse =", "))
  }
  
  tileinit(tilesize, buffer = radius)
  
  if(missing(tiles)){
    tiles <- 1:ntiles()
  } else {
    if(!all(tiles) %in% 1:ntiles()) 
      stop("These tiles don't exist in the tilescheme:", 
           paste(setdiff(tiles, 1:ntiles()), collapse = ", "))
  }
  for(tile in tiles){
    settile(tile)
    t <- readtile(path = x, coreonly = FALSE, cacheok = cacheok)
    res <- movingwindow(t, radius = radius, FUN = FUN, buffer = radius, ...)
    writetile(res, path = outgrid, coreonly = TRUE, as.integer = as.integer)
  }
  
} # end movingwindow.character

movingwindow.grid <- function(x, radius, FUN, buffer = 0, ...){
  # Arguments:
  #  x : a grid object
  # radius : the radius (in cells beyond focal cell) of the window
  #   eg radius of 2 yields 5 x 5 window dim
  # FUN : the function to call on the resulting window
  # buffer : don't bother calculating values for cells in a band this wide around the edge.
  #     this is used when processing in tiles to save some computation time (b/c only the core will be used)
  # ...  other arguments to be passed to FUN
  # 
  #  Value:
  #   A grid of the same dimension as the input grid where each cell has been replaced by the
  #   result of FUN called on the cells nearby.
  
  radius <- round(radius)
  
  result <- x
  result$m[, ] <- NA
  nrow <- x$nrow
  ncol <- x$ncol
  
  col.first <-  1 + buffer
  col.last <- ncol - buffer
  row.first <- 1 + buffer
  row.last <- nrow - buffer
  
  for(row in row.first:row.last) for(col in col.first:col.last){
    row.min <- max(row - radius, 1)
    row.max <- min(row + radius, nrow)
    col.min <- max(col - radius, 1)
    col.max <- min(col + radius, ncol)  
    result$m[row, col] <- FUN(x$m[row.min:row.max, col.min:col.max], ...)
  }
  return(result)  
  
}





