# Define generic overlay funciton
overlay <- function(x, ...) UseMethod("overlay")

# And a grid method
overlay.grid <- function(x, y, transparent=TRUE, add=FALSE, coreonly=TRUE, buffer=0, ...){
  # add=TRUE takes precidence over transparent
  
  # Check snapping
  checkcellalignment(x, y)
  
  # Set the buffer
  if(coreonly) {
    buffer <- tilescheme()$buffer
    if(is.na(buffer)) stop("If coreonly argument is TRUE then tileinit or subtileinit must be set
                           prior to calling overlay")
  }
  buffer <- round(buffer) # Buffer must be an integer
  if(buffer < 0) stop("Buffer must be a postive integer")
  if(buffer*2 >= x$nrow | buffer*2 >= x$ncol) stop("After removing the buffer there is nothing left.")
  
  
  # Find the range of x and y.  These are cell centers.
  x.xrange <- c2x(c(1+buffer, x$ncol-buffer), x)
  x.yrange <- r2y(c(x$nrow - buffer, 1 + buffer), x)
  y.xrange <- c2x(c(1, y$ncol), y)
  y.yrange <- r2y(c(y$nrow, 1), y)
  
  # Check to make sure they overlap
  overlap <- function(a, b) ( max(a[1],b[1]) < min(a[2], b[2]))
  if(!overlap(x.xrange, y.xrange) || !overlap(x.yrange, y.yrange))
    stop("The grid extents don't overlap at all.")
  
  # calculate the range of the overlap
  xrange <- c(max(x.xrange[1], y.xrange[1]), min(x.xrange[2], y.xrange[2]))
  yrange <- c(max(x.yrange[1], y.yrange[1]), min(x.yrange[2], y.yrange[2]))
  
  
  #  Define row and column indexes for the overlapping region of the destination and source grids
  xri <- y2r(yrange[2], x):y2r(yrange[1], x)
  xci <- x2c(xrange[1], x):x2c(xrange[2], x)
  
  yri <- y2r(yrange[2], y):y2r(yrange[1], y)
  yci <- x2c(xrange[1], y):x2c(xrange[2], y)
  
  # Copy or add data from the source to the destination in the zone of overlap
  if(add==TRUE){
    xnai <- is.na(x$m[xri, xci])
    ynai <- is.na(y$m[yri, yci])  
    # If both aren't NA add them together
    sv <- !xnai & !ynai # selection vector 
    y$m[yri, yci][sv] <- y$m[yri, yci][sv] + x$m[xri, xci][sv]
    # If source is not na and destination is overwrite
    sv <- !xnai & ynai  
    y$m[yri, yci][sv] <- x$m[xri, xci][sv]
    # (If both are NA we can just leave as is)  
  } else {
    if(transparent){ # (add == FALSE & transparent == TRUE)
      sv <- !is.na(x$m[xri, xci])
      y$m[yri, yci][sv] <- x$m[xri, xci][sv]      
    } else { # (add == FALSE & transparent==FALSE)
      y$m[yri, yci] <- x$m[xri, xci]
    }
  }
  return(y)

}

