panedetails <- function(id){
  #------------------------------------------------------------------------------------------------#
  #   panedetails   Ethan Plunkett    Sept 2013  
  # This function returns llx, lly, startrow, startcol, nrow, ncol for the pane
  #
  #  Code is adapted from tiledetails
  #------------------------------------------------------------------------------------------------#
  
  w <- .status$mosaicwindow
  cellsize <- w$cellsize
  
  # generate row and column index of the current pane
  j <- id %%.status$mosaic$cols
  if (j == 0) j <- .status$mosaic$cols
  i <- ((id - 1)%/%.status$mosaic$cols) + 1
    
  lastrow <- i == .status$mosaic$rows # flag to indicate the last row
  lastcol <- j == .status$mosaic$cols  # flag to indicate last col
  
  
  xll <- w$xll + (j-1) * cellsize * .status$mosaic$colsize
  yll <- w$yll + w$nrow*cellsize - 
    ( i * cellsize * .status$mosaic$rowsize ) # this works for all but the bottom row  
  if(lastrow){
    yll <- w$yll 
  }
  nrow <- ifelse(lastrow,  .status$mosaic$lastrowsize, .status$mosaic$rowsize)
  ncol <- ifelse(lastcol, .status$mosaic$lastcolsize, .status$mosaic$colsize) 
  
  startcol <- x2c(xll + 0.5 * cellsize, list=w)
    
  startrow <- y2r(yll +  0.5 * cellsize,list=w)  -  nrow + 1
  
  return(list(xll=xll, yll=yll, nrow=nrow, ncol=ncol,  startrow=startrow, 
              startcol=startcol, cellsize=cellsize))
  
}

