panepath <- function(path, name, id, npanes){
  # Arguments:
  # path : the path to a mosaic grid 
  # name : the name of the mosaic grid (taken from the descriptor file - generally the same 
  #    as the last directory of the path unless the grid has been moved.
  # id : the id of the pane of interest
  # npanes : the number of panes in the mosaic (counting all the panes regardless of whether they
  #          have data)
  # Value :
  # It returns the path the file that contains the raster data for the pane of interest.
  #
  #
  #  Note the length of the innermost file name is restricted to 13 characters.
  
  
  path <- gsub("(/|\\\\)$", "", path )  # drop trailing delimiter
  
  if(missing(name)) name <- gsub("^.*(/|\\\\)", "", path)
  
  # Pad the id
  digits <- nchar(as.character(npanes))
  id <- paste(paste(rep(0, digits), collapse="", sep=""), id, sep="")
  id <- substr(id, start=nchar(id)- digits +1 , stop=nchar(id) )
  
  # Add the name truncating it as necessary to make 13 digits
  name2 <- paste(substr(name, start=1, stop=13-digits), id, sep="")  
  
  # assemble the path
  result <- paste(path, "/", name2, "/", name2, sep="")
  
  return(result)
  
  
}
