plotextent <- function(grid, list, subtiles=TRUE){
  # plotextent    Ethan Plunkett Jan 2011
  # 
  # This function plots the extent of the access window and the the tile scheme
  # an optional argument either "grid" or "list" can be specified and the function will plot the extent of it as well. 
  # Arguments : 
  #  grid : (optional) either a character indicating the path to a grid on disk (relative to 
  #   base path set by gridinit).
  #    an object of class grid on disk, 
  #    an object that inherits the class "sp" on which the function bbox can be called 
  #    or a list with items xll, yll, nrow, ncoll, and cellsize.
  #  list : here for back compatabilty.
  # subtiles : if TRUE then plot the subtile boundaries (if subtiles are defined) if FALSE don't
  
  
  # Check for a tile scheme
  w <- getwindow()
  if(!w$set)  stop("Setwindow (and gridinit) must be called prior to this function.")
  if(is.na(tilescheme()$rowsize)) tiles <- FALSE else tiles <- TRUE
  
  # Get bounds of the access window
  hb <- getbounds(w)
  
  # Determine plot boundaries - maximum extent of access window and grid
  pb <- hb  # plot bounds
  gb.defined <- FALSE
  if(!missing(list) && missing(grid)) grid <- list
  if(!missing(grid)){
    gb <- getbounds(grid)
    for(i in 1:2){
      pb[i, 1] <- min(hb[i, 1], gb[i,1])
      pb[i, 2] <- max(hb[i, 2], gb[i,2])
    }
    gb.defined <- TRUE
  }  
  
  if(tiles){
  # Determine the x and y values of the tile boundaries
  xvals <- w$xll + (0:(.status$tilescheme$cols-1)) * w$cellsize * .status$tilescheme$colsize
  lastx <- xvals[length(xvals)] + .status$tilescheme$lastcols * w$cellsize
  xvals <- c(xvals, lastx)
  yvals <- w$yll + w$nrow * w$cellsize - (0:(.status$tilescheme$rows-1)) * w$cellsize * .status$tilescheme$rowsize
  lasty <- yvals[length(yvals)] - (.status$tilescheme$lastrows * w$cellsize)
  yvals <- c(yvals, lasty)
  
  # Update plot boundaries - this is necessary because if subtiles are defined the tiles may extend
  # beyond the gridio window (header).
  pb$max[1] <- max(pb$min[1], xvals)
  pb$min[2] <- min(pb$min[2], yvals)  
  
  } # end if tiles
  
  # Make blank plot window
  pb <- as.matrix(pb)
  plot(NA, NA, xlim=pb[1,], ylim=pb[2,], asp=1, xlab="x", ylab="y")
  
  # Define a function to plot a bounding box
  plotbb <- function(bb, ...)   # takes a bounding box and plots it as a rectangle of lines (on the existing plot frame)
    lines(x=bb[1,c(1,2,2,1,1)], y=bb[2, c(1,1,2,2,1)], ...)  
  
  # Plot in tile boundaries
  if(tiles){
  yrange <- range(yvals)
  xrange <- range(xvals)
  matlines( x=rbind(xvals, xvals),y=yrange, col="darkgrey", lty=1)
  matlines(x=xrange, y=rbind(yvals, yvals), col="darkgrey" , lty=1)
  }
  
  #  Plot subtile boundaries (if appropriate)
  if(tiles & !is.na(.status$subtilescheme$rowsize) & subtiles){
    sxvals <- seq(from=min(xvals), to=max(xvals), 
                  by=.status$subtilescheme$colsize * w$cellsize)
    syvals <- seq(from=min(yvals), to=max(yvals), 
                  by=.status$subtilescheme$rowsize * w$cellsize)  
    yrange <- range(syvals)
    xrange <- range(sxvals)
    # subset to those that aren't tile boundaries
    sxvals <- setdiff(sxvals, xvals)
    syvals <- setdiff(syvals, yvals)
    matlines( x=rbind(sxvals, sxvals),y=yrange, col="lightgrey", lty=2)
    matlines(x=xrange, y=rbind(syvals, syvals), col="lightgrey", lty=2)
  }
  
  # Add tile labels
  if(tiles){
  xbounds <- xvals
  ybounds <- yvals
  labelx <- numeric(length(xbounds)-1)
  for(i in 1:(length(xbounds)-1)) {
    labelx[i] = mean(xbounds[c(i, i+1)])
  }
  labely <- numeric(length(ybounds)-1)
  for(i in 1:(length(ybounds)-1)) {
    labely[i] = mean(ybounds[c(i, i+1)])
  }
  for(r in 1:length(labely))for(c in 1:length(labelx)){
    tileno=(r-1)*tilescheme()$cols + c
    text(x=labelx[c], y=labely[r], label=tileno, col=rgb(.3, .3, .3))
  }
  } # end if iles
  
  # Plot bounding box around the grid or list object in red
  plotbb(hb)  
  if(gb.defined) plotbb(gb, col=rgb(1, 0, 0, 0.6) , lwd=2, lty=1)
  
  invisible()
}

