# Function to turn values for tiles into values for 


rasterizetiles <- function(values, tile.ids, subtile.ids){
  # Given data that corresponds to either tiles or subtiles this function
  # will create a new grid with cells that correspond to the tiles or subtiles
  
  
  
  if(sum(missing(tile.ids),  missing(subtile.ids)) != 1) stop("One and only one of tile.ids or subtile.ids must be specified." )
  

  if(!missing(tile.ids)){  # working in tiles but not subtiles
    ts <- tilescheme()
    w <- getwindow()
    nrow <- ts$rows
    ncol <- ts$cols
    xll <- w$xll
    a <- (ts$rowsize - ts$lastrows )  * w$cellsize
    yll <- w$yll - a
    if(ts$rowsize != ts$colsize) stop("Tiles aren't square.  Can't make a grid.")
    cellsize <- ts$rowsize *w$cellsize
    n <- nrow*ncol
    d <- rep(NA, n)
    mv <- match(tile.ids, 1:n)
    d[mv] <- values
    
    grid <- list(m= matrix(d, nrow=nrow, ncol=ncol, byrow = TRUE), 
                 xll = xll, yll = yll, nrow = nrow, ncol = ncol, cellsize = cellsize)
    class(grid) <- c("grid", class(grid))

    
  }
  
  if(!missing(subtile.ids)){
    ss <- .status$subtilescheme
    if(is.na(ss$nr)) stop("The subtile scheme isn't definied. Call subtileinit prior to this function.")
    ts <- tilescheme()
    w <- getwindow()
    
    nrow <- (ts$rows -1) * ss$nr + ts$lastrows / ss$rowsize
    
    ncol <- (ts$cols - 1) * ss$nc + ts$lastcols /  ss$colsize
    
    xll <- w$xll
    a <- (ts$rowsize - ts$lastrows )  * w$cellsize
    yll <-  ( w$yll + w$nrow * w$cellsize ) - nrow * ss$rowsize *  w$cellsize
    if(ss$rowsize != ss$colsize) stop("Subtiles aren't square.  Can't make a grid.")
    cellsize <- ss$rowsize *w$cellsize
    n <- nrow*ncol
    d <- rep(NA, n)
    mv <- match(subtile.ids, 1:n)
    d[mv] <- values
    
    grid <- list(m= matrix(d, nrow=nrow, ncol=ncol, byrow = TRUE), 
                 xll = xll, yll = yll, nrow = nrow, ncol = ncol, cellsize = cellsize)
    class(grid) <- c("grid", class(grid))
  }
  
  if(FALSE){
    plotextent()
    plot(grid, add=TRUE, use.old=T)
    plotextent(grid)
  }
  
  return(grid)
  
}