if(FALSE){ # SKIP
readblockc <- function(path, startrow, startcol, nrow, ncol, buffer=0, extent, as.matrix=FALSE, 
                       na.value=-9999, as.integer, cacheok, desc){
  
  # Note:  readblock is the user level function it handles mosaicing.  
  #        readblockc is next in the chain.  It handles cacheing.
  #        .readblock is last.  It is a wrapper to the C function that does the actual reading.
    

  # Set conversion factor 
  # Note if using base 2 change values in fileinfo as well
  # mb.per.gb <- 1024 # base 2
  mb.per.gb <- 1000 # base 10 
  verbose <- .status$verbosity >= 3
  
  
  if(.status$verbosity >= 2) cat("reablockc\n")
  if(.status$verbosity >= 4) cat("Arguments:\n\t", 
                                 "path =", path, "\n\t", 
                                 "startrow = ", ifelse(missing(startrow), "[missing]",  startrow), "\n\t", 
                                 "startcol = ", ifelse(missing(startcol), "[missing]",  startcol), "\n\t", 
                                 "nrow = ", ifelse(missing(nrow), "[missing]", nrow), "\n\t", 
                                 "ncol = ", ifelse(missing(ncol), "[missing]", ncol), "\n\t",
                                 "buffer = ", buffer, "\n\t",
                                 "extent = ", ifelse(missing(extent), "[missing]", "[not missing]"),   "\n\t", 
                                 "as.matrix = ", as.matrix, "\n\t", 
                                 "na.value = ", na.value, "\n\t", 
                                 "as.integer = ", ifelse(missing(as.integer), "[missing]", as.integer), "\n\t", 
                                 "cacheok = ", ifelse(missing(cacheok), "[missing]", cacheok),  "\n\t", 
                                  "desc = ", ifelse(missing(desc), "[missing]", "[not missing]"), 
                                 "\n") 
  
  # path <- "c:/temp/gridiotest/dem/"; cacheok=TRUE
  
  # Note readblock now spans three functions
  # readblock - handles mosaics calling readblockc repeatedly.
  # readblockc - handles caching calling .readblock once on either a cached copy or the source
  # .readblock - interfaces directly with the dll.

  path <- gsub("/[[:blank:]]*$", "", path)
  
  mingridcapacity = 10 # the minimum space available in the cache expressed as a multiple of the 
  # current grid size.  Thus with 10 we are only going to cache if the 
  # total cache space is at least 10 times the size of the current grid
  
  # Verify that caching is on
  ci <- getcacheconfig()
  if(!ci$on) cacheok <- FALSE  
 
  
  
  # Get information on grid size and cache size and verify that there's sufficient space to 
  #  that caching makes sense.
  if(cacheok){
    library(anthill)
    main.lock.path <- paste0(short.name(), " cache") 
    index.path <- getcachepath(path)
    index.lock.path <- paste0(short.name(), " ", index.path)
    
    msg <- paste(short.name(), "-R", sep="")
    si <- fileinfo(path) 
    if(is.na(si$size)){
      stop("There is no grid:", path)
    }
    
    get.lock(index.lock.path, message=msg, slash=FALSE)
    on.exit(return.lock(index.lock.path, slash=FALSE)) # in case there are errors
    
    d <- getcachedir(locking=FALSE)
    
    cachesize <- sum(d$size)
    
    free <- fileinfo(paste(ci$cachepath, "/gridcache.txt", sep=""))$free
    
    # tot.available is the total space the cache can occupy (regardless of how big it currently is)
    tot.available <- min(free - ci$minfree*mb.per.gb + cachesize, ci$maxsize*mb.per.gb)
    
    if(tot.available < ( mingridcapacity * si$size) ){
      cacheok <- FALSE
      return.lock(lp, slash=FALSE)  # Return lock in special case where we decide there isn't space to cache
      on.exit()
    }
  }
  
  if(!cacheok){
    if(verbose) cat(" Reading uncached grid.\n")
    setcache(FALSE)
    activateconnection()
    return(.readblock(path=path, startrow=startrow, startcol=startcol, nrow=nrow, ncol=ncol, 
                      buffer=buffer, extent=extent, as.matrix=as.matrix, na.value=na.value, 
                      as.integer=as.integer, desc=desc))
  }
  
  # if we made it this far than we are going to cache this grid
  
  # This is an alternative to unlink that might be more effective
  del.dir.tree <- function(x){
    x <- gsub("/", "\\\\", x)
    x <- sub("////$", "", x)
    shell(paste("RD /S /Q ", x, sep=""))
  }
  
  # define a function to delete a grid from the cache
  delete.cached.grid <- function(x, d){
    # x = path to source grid
    # d = the result of a call to getcachedir 
    #  This function both deletes the file on disk and removes it from d which 
    # is then returned in it's modified state
    ri  <- which(tolower(d$source)  %in% tolower(x))
    if(length(ri) > 1) stop("Duplicate grids in the cache. Something is wrong.")
    if(length(ri) < 1) stop("No grid", x, "in cache.")
    if(tolower(d$source[ri]) != tolower(d$cache[ri])){  # if it's not cached in place
      target <- gsub("/[^/]*$", "", d$cache[ri])
      # prior to deleting make sure the target is inside the cache directory 
      if(!grepl(tolower(ci$cachepath), tolower(target), fixed=TRUE)) 
        stop("Can't delete ", target, " (an expired cache grid); grid is not in the cache directory.\n")
      # unlink(target, recursive=TRUE)
      del.dir.tree(target)
    }
    d <- d[-ri, , drop=FALSE]
    return(d)
  }
  
  
 
  
  # function to decide which grids to delete
  pick.losers <- function(d, sn){
    # d = result of a call to getcachdir
    # sn = the additional space needed in MB
    a <- d$reads
    a <- gsub( "^.*/", "", a)
    last.read <- as.POSIXct(a, format=.status$timeformat)
    
    d <- d[d$status != "copying", ]  # can't delete copying grids!
    d <- d[order(last.read, decreasing=FALSE), ]  # sort with oldest first
    
    sv <- cumsum(d$size) > sn
    if(!any(sv)) return(NA)  # indicates we can't make space
    last.row <- min(which(sv))   # identify how many we have to delete to meet
    # our target
    
    return(d$source[1:last.row])
  } # end pick losers function
  
  
  ri  <- which(tolower(d$source)  %in% tolower(path))
  if(length(ri) > 1) stop("Duplicate grids in the cache. Something is wrong.")
  iscached <- length(ri)==1
  
  
  if(iscached){
    first <- TRUE
    # If someone else is copying our grid into the cache then wait for them to finish
    while(d$status[ri] %in% "copying"){
      
      # Check that it hasn't been copying for more than 10 minutes 
      tdiff <- difftime(Sys.time(),  d$cachedate[ri])
      units(tdiff) <- "mins"
      if(as.numeric(tdiff) > 30){
        stop("Cached version of '", path, "' has been 'copying' for more than 10 minutes on '",
             short.name(), "'.")
      }
      
      if(verbose){
        if(first == TRUE){
          cat("\tWaiting for someone else to copy the grid from the cache.\n")
          first <- FALSE
        } else {
          cat(".") 
        }
      }
      
      msg <- paste(short.name(), "-R waiting for copying to complete", sep="")
      return.lock(lp, message=msg, slash=FALSE)
      on.exit()
      Sys.sleep(30)
      
      get.lock(lp, message=msg, slash=FALSE)
      on.exit(return.lock(lp, slash=FALSE)) # in case there are errors
      d <- getcachedir(locking=FALSE)
      
      ri  <- which(tolower(d$source)  %in% tolower(path))
      if(length(ri) == 0) {
        iscached < FALSE
        break
      }
      
    }
    if(iscached  && !(d$status[ri] %in% "ready")) 
      stop("Grid is no longer copying but isn't 'ready'.  Something is wrong.")
  }
  
  # Check for expired grids
  if(iscached && d$sourcedate[ri] != si$date){      
    if(tolower(d$source[ri]) == tolower(d$cache[ri])){ # grid is cached in place
      d$sourcedate[ri] <- si$date  # then update the date and all is well
    } else {  # if it's not cached in place and is expired then delete it
      if(verbose) cat("Deleting expired grid.", d$cache[ri],"\n")
      free <- free + d$size[ri]
      d <- delete.cached.grid(path, d)  
      iscached <- FALSE 
    }
  }
  
  # if it's not cached then copy it to the cache
  if(!iscached ){ 
    source.drive <- gsub("/.*", "",  path) 
    cacheinplace <- grepl(paste("^" ,source.drive, sep=""), ci$cachepath, ignore.case=TRUE)
    
    if(cacheinplace){
      cachedate <- Sys.time()
      wpath <- gsub("/", "\\\\", path)
      newrow <- data.frame(source=wpath,
                           cache=wpath, 
                           status="ready",  
                           cachedate=cachedate, 
                           sourcedate=si$date, 
                           reads=NA,
                           size=si$size, 
                           cols=desc$ncol, 
                           rows=desc$nrow, 
                           xll=desc$xll, 
                           yll=desc$yll,
                           cellsize=desc$cellsize, 
                           nodata=-9999, 
                           type=desc$type, 
                           min=desc$min, 
                           max=desc$max, 
                           mean=desc$mean, 
                           std=desc$sd, 
                           stringsAsFactors=FALSE)
      d <- rbind(d, newrow)
      ri <- dim(d)[1]
      
    } else {  # Not caching in place, copying a grid
      cachesize <- sum(d$size)
      available <- min(free - ci$minfree*1024, ci$maxsize*1024 - cachesize)  # unused capacity
      if(available < si$size){  # if insufficient space
        
        sn <- si$size - available
        l <- pick.losers(d=d, sn=sn)
        
        if(is.na(l)){
          #  l is NA if there's no way to free up sufficient space   
          #  This shouldn't happen but if there's a lot of grids in the process of copying it just
          # might.  We solve it by reading the block from the source with cacheok=FALSE
          putcachedir(d) 
          return.lock(lp, message=msg, slash=FALSE)             # free the lock
          on.exit()
          setcache(FALSE)
          activateconnection()  
      
          return(.readblock(path=path, startrow=startrow, startcol=startcol, nrow=nrow, ncol=ncol, 
                            buffer=buffer, extent=extent, as.matrix=as.matrix, na.value=na.value, 
                            as.integer=as.integer, desc=desc))
        } else {
          # Delete grids to free up space
          if(verbose) cat("Deleting grids to free space: \n\t", paste(l, collapse="\n\t"), "\n", sep="")
          setcache(TRUE)
          activateconnection()
          for(i in 1:length(l)) d <- delete.cached.grid(l[i], d)
        } 
      }  # end insufficient space
      
      # Copy the grid 
      setcache(TRUE)
      activateconnection()
      sv <- !(tolower(d$source) == tolower(d$cache)) # copied grids (excluded cached in place)
      if(length(sv) ==0 || sum(sv)==0){
        new.id <- 1
      } else {
        used.ids <- as.numeric(gsub("^.*/([^/]+)/.*$","\\1",  d$cache[sv]))
        # new.id <- min(setdiff(1:(sum(sv)+1),used.ids))  # old code used first empty slot
        new.id <- max(used.ids) + 1
      }
      name <- gsub("^.*/", "", path)
      cache.dir <- paste(gsub("(/|\\\\)$", "", ci$cachepath), "/", new.id, sep="")
      cache.path <- paste(cache.dir, "/", name, sep="")
      
      cachedate <- Sys.time()
      if(file.exists(cache.dir)) unlink(cache.dir, recursive=TRUE)
      dir.create(cache.dir)
      newrow <- data.frame(source=gsub("/", "\\\\", path), 
                           cache=gsub("/", "\\\\", cache.path), 
                           status="copying", 
                           cachedate=cachedate, 
                           sourcedate=si$date, 
                           reads=NA, size=si$size, 
                           cols=desc$ncol, 
                           rows=desc$nrow, 
                           xll=desc$xll,
                           yll=desc$yll, 
                           cellsize=desc$cellsize, 
                           nodata=-9999, 
                           type=desc$type, 
                           min=desc$min, 
                           max=desc$max, 
                           mean=desc$mean, 
                           std=desc$sd,
                           stringsAsFactors=FALSE)
      d <- rbind(d, newrow)
      putcachedir(d) 
      return.lock(lp, message=msg, slash=FALSE) 
      on.exit()
      if(verbose) cat("Copying grid to cache. - ")
      gridcopy(path, cache.path)
      if(verbose) cat("Done copying grid to cache.\n")
      

      get.lock(lp, message=msg, slash=FALSE)
      on.exit(return.lock(lp, slash=FALSE)) # in case there are errors
      d <- getcachedir(locking=FALSE)
      
      ri  <- which(tolower(d$source)  %in% tolower(path))
      if(length(ri) != 1)
        stop("There should be one and only one entry for ", path,
             " in cache_dir.txt")
      
      d$status[ri] <- "ready"
      
    } # end copying 
  }  # end grid wasn't in cache
  
  # Update read time(s)
  reads <- d$reads[ri] 
  now <- format(Sys.time(), format=.status$timeformat)
  if(is.na(reads)){
    reads <- now
  } else {
    reads <- strsplit(reads, "/")[[1]]
    n <- length(reads)
    if(n > 4) reads <- reads[n-3:n]  # drop all but last four timestamps
    reads <- c(reads, now)  # add this one
    reads <- paste(reads, collapse="/")
  }
  d$reads[ri] <- reads
  
  putcachedir(d) 
  return.lock(lp, message=msg, slash=FALSE) 
  on.exit()
  
  # Read block from the cache
  
  setcache(TRUE)
  activateconnection()
  if(verbose) cat("Reading grid from cache\n")
  return(.readblock(path=d$cache[ri], startrow=startrow, startcol=startcol, nrow=nrow, ncol=ncol, 
                    buffer=buffer, extent=extent, as.matrix=as.matrix, na.value=na.value, 
                    as.integer=as.integer, desc=desc))
  
}
} # END SKIP