refgridinit <- function(ref, both=FALSE, servers, desc){
  # ref - the path to a reference grid or the path to a reference mosaic
  # both - if TRUE and ref points to a mosaic then connections will be created for both 
  #  the mosaic panes and the complete grid.
  # servers - the gridserver table as returned by readgridservers (in anthill)
  #   (optional) readgridserver will called if it is missing.
  # desc - the result of a call to griddescribe ref - optional - if supplied saves
  #  a call to griddescribe.
  if(.status$verbosity > 1) cat("refgridinit called\n")
  if(missing(servers)){
    if(!anthillrunning()) 
      stop("Anthill isn't running.  Either use gridinit(), pass servers to the function, or load and configure anthill.")  
    servers <- readgridservers()
  }
  
  
  find.server <- function (x, path=NA, servers) {
    # Hacked copy of find connection  
    drivematches <- extentmatches <- rep(FALSE, nrow(servers))
    for (i in 1:length(extentmatches)) 
      if (coincide(as.list(servers[i,]), x)) 
        extentmatches[i] <- TRUE
    if (sum(extentmatches) == 0) 
      return(NA)
    if (sum(extentmatches) == 1 | path == "" | is.na(path)) 
      return(which(extentmatches)[1])
    path <- tolower(path)
    path <- gsub("\\\\", "/", path)
    for (i in 1:length(drivematches)) {
      d <- as.character(servers$drive[i])
      if (is.na(d) || d == "") {
        drivematches[i] <- NA
      }
      else {
        p <- substr(path, 1, nchar(d))
        drivematches[i] <- p == d
      }
    }
    a <- drivematches & extentmatches
    if (sum(!is.na(a) & a) > 0) 
      return(which(a)[1])
    a[is.na(a)] <- TRUE
    if (sum(a) > 0) 
      return(which(a)[1])
    return(which(extentmatches)[1])
  } # end findserver
  
  if(missing(desc)){
    gridinit()
    desc <- griddescribe(ref)
    if(desc$type == "missing") 
      stop("The reference grid is missing (", ref, ")", sep="")
  }
  
  if(!desc$mosaic || both){
    r  <- find.server(desc, path=ref, servers=servers)
    if(is.na(r)) stop("No server matches ", ref)
    gridinit(server=servers$server[r], port=servers$port[r])
    if(!isTRUE(.status$connections$set[.status$activeconnection$connection]))
      setwindow(desc)
  }
  if(desc$mosaic)
    mosaicinit(reference=ref, servers=servers, desc=desc)
}
