replace.nas <- function(m, k, min.cells=3){
  #------------------------------------------------------------------------------------------------#
  #  replace.nas          Ethan Plunkett   
  #  
  #  Replace NA values (brute force approach) - SLOW
  #  This function uses the kernel k to calculate a replacement for each NA value in the matrix
  #    cells are only replaced if there are at least min.cells non NA cells within the kernel window.  
  #  Changes :
  #     March 8, 2012 - rewrote so loop is through NA cells rather than rows and columns
  #       This is much more efficient. 
  #------------------------------------------------------------------------------------------------#
  r <- (nrow(k)-1)/2 # the radius of the kernel (not counting the center cell)
  m.new <- m
  
  nai <- which(is.na(m))
  cols <- (nai-1)%/% nrow(m) +1
  rows <- (nai-1) %% nrow(m) + 1
  
  for(i in 1:length(nai)){
    row <- rows[i]
    col <- cols[i]
    n.neighbors <- sum(!is.na(m[max((row-1), 0):min((row+1), nrow(m)), max((col-1), 0):min((col+1), ncol(m))]))
		if(n.neighbors < min.cells) next # skip if there aren't enough neighbors
		m.new[row, col] <- calckernel(m, k, row, col)
	}
  
  return(m.new)
}
