
samplegrid <- function(grid.path, loc, proj, tilesize=2000, checkproj=TRUE, init=TRUE, cacheok = TRUE){
  # Function to sample a grid at specified locations
  # Arguments:
  # grid.path - the path to the grid to be sampled
  # loc - a spatial points data frame can be created from a dataframe with the coordinates() function if checkproj is TRUE
  #  than loc should have a projection defined as well which can be done with the proj4string() function.  
  # proj - the projection associated with the grid on disk - this argument is not necessary if 
  #  the projection of the grid is defined on disk) 
  #  tilesize - the tilesize with which to process the grid
  # checkproj - if TRUE the projections are checked and reprojection is mananged by the function if FALSE
  #  it is assumed that the coordinate systems match.
  # init - if TRUE the function calls gridinit in local mode on the target grid.  Otherwise it 
  #   assumes that gridinit and setwindow have already been called (either in local or server mode)
  #  
  # Value:
  #  a vector of grid values - one for each point in loc is returned
  
  
  # Reproject if necessary
  if(checkproj){
    require(rgdal)
    if(missing(proj)) proj  <- CRS(GDALSpatialRef(grid.path))
    if(inherits(proj, "character")) proj <- CRS(proj)
    loc2 <- spTransform(loc, proj)
  } else {
    loc2 <- loc
  }
  
  # If local is true intiialize local gridserver
  # Otherwise we are assuming that the gridserver is already initialized and the window set
  if(init){
    cleanup()
    gridinit()
    setwindow(grid.path)
  }
  
  # Initialize tile scheme
  tileinit(tilesize, 0)
  samp <- rep(NA, length(loc2))
  for(i in 1:ntiles()){
    settile(i)
    d <- tiledetails()
    rows <- y2r(loc2@coords[, 2], d)
    cols <- x2c(loc2@coords[, 1], d)
    sv <- rows > 0 & rows <= d$nrow  & cols > 0 & cols <= d$ncol
    if(sum(sv)== 0) next  # skip tiles that don't have points 
    grid <- readtile(grid.path, cacheok = cacheok)
    samp[sv] <- grid$m[cbind(rows[sv], cols[sv])]    
    
  }
  return(samp)
}

