stci <- function(coreonly=FALSE){
  #------------------------------------------------------------------------------------------------#
  #  stci   Ethan Plunkett    March 8 2012
  #
  #  funciton to return an index of the columns of a tile that contain the subtile
  #
  #  it assumes that the matrix being indexed coincides with the current tile (including the buffer)
  #  Arguments :
  #     coreonly : If TRUE then the index will select only the core cells of the subtile.  If FALSE
  #       the index will reference both the core and the buffer of the subtile
  #------------------------------------------------------------------------------------------------#
  
  # Make local copies of tilescheme stuff
  b <- .status$tilescheme$buffer
  colsize <- .status$subtilescheme$colsize
  j <- .status$subtilescheme$j
  
  # Define the core of this subtile
  lc <-  b + 1 + colsize * (j -1) # left column
  rc  <- lc + colsize - 1   # right column
  
  # Expand out to include the buffer (if necessary)
  if(!coreonly){
    lc <- lc - b
    rc <- rc + b
  }
  
  return(lc:rc)
}
