sti <- function(coreonly=FALSE){
  #------------------------------------------------------------------------------------------------#
  #  sti   Ethan Plunkett    March 6 2012
  # 
  #  this funciton returns an index which can be used to extract a subtile from a tile
  #  (sub tile index) 
  #  it assumes that the matrix being indexed coincides with the current tile (including the buffer)
  #  Arguments :
  #     coreonly : If TRUE then the index will select only the core cells of the subtile.  If FALSE
  #       the index will reference both the core and the buffer of the subtile
  #------------------------------------------------------------------------------------------------#
  
  # Make local copies of tilescheme stuff
  b <- .status$tilescheme$buffer
  rowsize <- .status$subtilescheme$rowsize
  colsize <- .status$subtilescheme$colsize
  i <- .status$subtilescheme$i
  j <- .status$subtilescheme$j
  
  # Define the core of this subtile
  lc <-  b + 1 + colsize * (j -1) # left column
  rc  <- lc + colsize - 1   # right column
  tr  <-  b + 1 + rowsize * (i -1)   # top row
  br  <- tr + rowsize - 1   # bottom row

  # Expand out to include the buffer (if necessary)
  if(!coreonly){
    lc <- lc - b
    rc <- rc + b
    tr <- tr - b
    br <- br + b
  }
  
  # return(list(rows=tr:br, cols = lc:rc))
  
  # Make a matrix to represent the entire tile
   td <- tiledetails(coreonly=FALSE)
   m <- matrix(FALSE, nrow=td$nrow, ncol=td$ncol)
  
  
   # Switch subtile cells to TRUE
   m[tr:br, lc:rc] <- TRUE
 

  
  return(m)
}

