if(FALSE){
  library(gridio)
  
  mosaic <- "Z:/Working/ethan/temp/subregions"
  complete <- "Z:/Working/ethan/temp/subregions_s"
  reference <- "Z:/LCC/GIS/Work/Ancillary/Reference/ref_ner"
  
  pyramids=TRUE
  gridinit()
  gridkill(complete)
  
  script.path = "Z:/Users/Ethan/gridio/inst/python/MosaicTiles.py"
  python.path="C:/Python26/ArcGIS10.0/python.exe"
  
  stitchpy(mosaic=mosaic, complete=complete, reference=reference, script.path = script.path)
}


stitchpy <- function(mosaic, complete, reference, python.path="C:/Python26/ArcGIS10.0/python.exe", 
                     script.path, pyramids=TRUE){
  if(missing(script.path))
    script.path = system.file("python/MosaicTiles.py", package="gridio")
  
  # Cleanup paths
  mosaic <- gsub("\\\\", "/", mosaic) # convert to forward slashes
  mosaic <- gsub("/$", "", mosaic)  # drop trailing slash 
  complete <- gsub("\\\\", "/", complete) # convert to forward slashes
  complete <- gsub("/$", "", complete)  # drop trailing slash 
  logfile <- paste(mosaic, "/stitchlog.txt", sep="")
  
  oc <- saveconnections()
  on.exit(restoreconnections(oc))
  cleanup()
  gridinit()
  
  if(file.exists(complete)) 
    stop("Output path: ", complete, " already exists.", sep="")
  
  # Generate paths to the panes
  md <- mosaicinfo(mosaic, lock=anthillrunning())  
  
  # You can't build pyramids on small grids!
  if(md$extent$ncol <= 1024 || md$extent$nrow <= 1024) 
    pyramids <- FALSE 
  
  # These are used to set the pyramid environment
  # for integer grids I'm using Nearest neighbor interpolation for real grids I'm using Bilinear interpolation.
  # The last part of the string is the compression. LZ77 is lossless default will use jpeg if it can 
  pyramidstring <- ifelse(md$extent$type == "integer", 
                          "PYRAMIDS -1 NEAREST LZ77",  
                          "PYRAMIDS -1 NEAREST DEFAULT") #"PYRAMIDS -1 BILINEAR DEFAULT")  
  
  stopifnot(coincide(md$extent,griddescribe(reference)))
  paneids <- which(md$panemap)
  panepaths <- character(length(paneids))
  for(i in 1:length(paneids))
    panepaths[i] <- panepath(path=mosaic, name=md$name, id=paneids[i], npanes=length(md$panemap))
  
  # Edit python script 
  # if(missing(reference)) reference <- panepaths[1] # complete reference is now required to set the extent environment
  
  outdir <- gsub( "/[^/]*$", "", complete)
  outname <- gsub("^.*/", "", complete)
  cf <- paste(mosaic, "/stitchcompleted", sep="") # completed file created at end of python script
  l <- readLines(con=script.path)
  l <- gsub("[outdir]", outdir, l,  fixed=TRUE)
  l <- gsub("[refgrid]", reference, l, fixed=TRUE)
  l <- gsub("[outname]", outname, l, fixed=TRUE)
  l <- gsub("[tiles]", paste('"', panepaths,'"', collapse=', ', sep=""), l, fixed=TRUE)
  l <- gsub("[completedfile]", cf, l, fixed=TRUE)
  l <- gsub("[inmosaic]", mosaic, l, fixed=TRUE)
  l <- gsub("[inputname]", md$name, l, fixed=TRUE)
  l <- gsub("[pyramids]", as.integer(as.logical(pyramids)), l, fixed=TRUE)
  l <- gsub("[pyramidstring]", pyramidstring, l, fixed=TRUE)
  s <- paste(mosaic, "/stitch.py", sep="")
  
  writeLines(text=l, con=s)
  
  #cat(l[10:20], sep="\n")
  
  # Delete files created by script (in a prior stiching operation on the grid)
  if(file.exists(cf)) file.remove(cf)
  for(f in c(file.path(mosaic, "GDB.gdb"),
             file.path(mosaic, paste(outname, ".amd", sep="")),
             file.path(mosaic, paste(outname, ".amd.xml", sep=""))) ) {
    #cat(f, "\n")
    if(file.exists(f)) unlink(f, recursive=TRUE) 
  }
  
  # Run python script
  
  command <- paste(python.path, s,  sep=" ")
  cat("Executing system command: ", command, "\n")
  system(command= command, intern=TRUE)
  if(!file.exists(cf))
    stop("Python stitching failed to complete.")
  file.remove(s, cf)
    
  a <- rbind(as.data.frame(md$extent[.status$extentitems]), as.data.frame(griddescribe(complete)[.status$extentitems]))
  if(!coincide(md$extent, griddescribe(complete)))
    stop("The grid produced by the stitching operation doesn't match the reference grid.")
  
  logrow <- data.frame(stringsAsFactors = FALSE, 
                       stitchpath = gsub("/", "\\\\", complete),
                       stitchdate = format(x = Sys.time(), format = .status$timeformat) )
  
  if(file.exists(logfile)){
    log <- read.table(file=logfile,  sep="\t", header=TRUE, 
                      stringsAsFactors=FALSE, comment.char = ";")
    log <- rbind(log, logrow)
  } else {
    log <- logrow
  }
  
  gridiowritetable(log, file=logfile)
    
  cat("Done stitching ", mosaic, " (mosaic) into ", complete, ".\n", sep="")    
 
  
}
