subtiledetails <- function(coreonly=TRUE){
  #------------------------------------------------------------------------------------------------#
  #   subtiledetails   Ethan Plunkett    July 2012
  # This function returns llx, lly, startrow, startcol, nrow, ncol for the current subtile
  #   if coreonly is TRUE it will return those values for the core of the tile (not including the buffer)
  #   if coreonly is FALSE it will return values for the core + the buffer.
  # 
  #------------------------------------------------------------------------------------------------#
  td <- tiledetails(coreonly=TRUE)
  ss <- .status$subtilescheme
  cellsize <- td$cellsize
  core.xll <- td$xll + (ss$j -1) * ss$colsize * cellsize
  core.yll <- td$yll + (ss$rows - ss$i) * ss$rowsize * cellsize
  core.nrow <- ss$rowsize
  core.ncol <- ss$colsize
  
  core.startcol <- x2c(core.xll + 0.5 * cellsize, list = .status$header)
  core.startrow <- y2r(core.yll + 0.5 * cellsize, list = .status$header) - 
    core.nrow + 1
  
  
  if (coreonly) 
    return(list(xll = core.xll, yll = core.yll, nrow = core.nrow, 
                ncol = core.ncol, startrow = core.startrow, startcol = core.startcol, 
                cellsize = cellsize))
  
  xll <- core.xll - cellsize * .status$tilescheme$buffer
  yll <- core.yll - cellsize * .status$tilescheme$buffer
  nrow <- core.nrow + 2 * .status$tilescheme$buffer
  ncol <- core.ncol + 2 * .status$tilescheme$buffer
  startcol <- core.startcol - .status$tilescheme$buffer
  startrow <- core.startrow - .status$tilescheme$buffer
  return(list(xll = xll, yll = yll, nrow = nrow, ncol = ncol, 
              startrow = startrow, startcol = startcol, cellsize = cellsize))
  
}
