tiledetails <- function(coreonly=TRUE){
  #------------------------------------------------------------------------------------------------#
  #   tiledetails   Ethan Plunkett    January 2011
  # This function returns llx, lly, startrow, startcol, nrow, ncol for the current tile
  #   if coreonly is TRUE it will return those values for the core of the tile (not including the buffer)
  #   if coreonly is FALSE it will return values for the core + the buffer.
  # Changes:
  #    March 6, 2012  - 
  #       updated to work with subtiles - note if there are subtiles then lastrows and lastcols are
  #       augmented so that they are evenly divisible to the subtile dimension.  This means the
  #       core of the tiles may extend beyond the window to the south and east (but not north and
  #       west.)
  #------------------------------------------------------------------------------------------------#
  lastrow <- .status$tilescheme$i == .status$tilescheme$rows # flag to indicate the last row
  lastcol <- .status$tilescheme$j == .status$tilescheme$cols  # flgag to indicate last col
  w <- .status$referencewindow
  
  cellsize <- w$cellsize
  
  # First for the core:
  core.xll <- w$xll + (.status$tilescheme$j-1) * cellsize * .status$tilescheme$colsize
  core.yll <- w$yll + w$nrow*cellsize - 
    ( .status$tilescheme$i * cellsize * .status$tilescheme$rowsize ) # this works for all but the bottom row  
  if(lastrow){
    # First calculate how many extra rows there are at the bottom (that the tile core extends
    #  beyond the window).  This will be zero unless there are subtiles in which case it may be more
    #  than zero if extra rows are needed to make the tile an even multiple of the subtile size.
    extra.rows <- .status$tilescheme$rowsize * (.status$tilescheme$rows -1) + 
                  .status$tilescheme$lastrows - w$nrow
    # yll is the windows yll adjusted for the extra cells
    core.yll <- w$yll - extra.rows * cellsize # for the bottom row
  }
  core.nrow <- ifelse(lastrow,  .status$tilescheme$lastrows, .status$tilescheme$rowsize)
  core.ncol <- ifelse(lastcol, .status$tilescheme$lastcols, .status$tilescheme$colsize) 
  
  core.startcol <- x2c(core.xll + 0.5 * cellsize, list=w)
    
  core.startrow <- y2r(core.yll +  0.5 * cellsize,list=w)  -  core.nrow + 1
  
  if(coreonly) return(list(xll=core.xll, yll=core.yll, nrow=core.nrow, ncol=core.ncol, 
                 startrow=core.startrow, startcol=core.startcol, cellsize=cellsize))
  
    # Now for the core + buffer 
  xll <- core.xll - cellsize * .status$tilescheme$buffer
  yll <- core.yll - cellsize * .status$tilescheme$buffer
  nrow<- core.nrow + 2* .status$tilescheme$buffer
  ncol <- core.ncol + 2* .status$tilescheme$buffer
  startcol <- core.startcol - .status$tilescheme$buffer
  startrow <- core.startrow - .status$tilescheme$buffer
  return(list(xll=xll, yll=yll, nrow=nrow, ncol=ncol, startrow=startrow, startcol=startcol, cellsize=cellsize))
}
