tilehist <- function(data.path, class.path=NULL, tilesize=2000, breaks=NULL, binsize=10, ...){
  noclasses <- if(is.null(class.path)) TRUE else FALSE  # set flag
  tileinit(tilesize, 0)


  if(is.null(breaks)){
    d <- griddescribe(data.path)
    centers = seq(floor(d$min/binsize)*binsize, ceiling((d$max - .5*binsize)/binsize)*binsize, binsize)
    breaks <- c(centers - binsize/2, centers[length(centers)]+binsize/2)
  }
  if(noclasses){
    counts <- numeric(length(breaks)-1)
  } else {
    class.list <- NULL
    classes <- NULL
    counts <- list() # one for each class in the class grid
  }
  for(tile in 1:tilescheme()$totaltiles){
     settile(tile)
     cat("tilehist working on tile", tile, "of", tilescheme()$totaltiles, "\n")
     dg <- readtile(data.path)
     if(!noclasses){
       cg <- readtile(class.path)
        # Add any newly encounterd classes to our classes list and our counts data structure    
       tile.classes <- unique(as.vector(cg$m))
       tile.classes <- sort(tile.classes[!is.na(tile.classes)])
       new.classes <- setdiff(tile.classes,classes)
       classes <- c(classes, new.classes)
       new.list <- vector(mode="list", length=length(new.classes))
       names(new.list) <- new.classes
       counts <- c(counts, new.list)  # This is a list with one element for each observed class each element will be a numeric vector of the counts in each bin of each class
       # Update the counts for each class
       for(class in tile.classes){
         # class <- tile.classes[1] # for testing
         h <- hist(dg$m[cg$m %in% class], plot=FALSE, breaks=breaks, ...)
         i <- which(names(counts) == class)
         if(is.null(counts[[i]])) counts[[i]] <- h$counts else
         counts[[i]] <- counts[[i]] + h$counts
       }
     } else {  # no classes :
       h <- hist(dg$m,plot=FALSE, breaks=breaks, ...)
       counts <- counts + h$counts
     }
  }
  result <- list(counts=counts, breaks=breaks, mids=centers)
  if(!noclasses) result$classes <- classes
  class(result) <- c("tilehist", class(result))
  return(result)
}
