if(FALSE){  # Testing and example code function is below.
  
  # source("X:/gridiolib/gridio.test/update.package.R")
  library(anthill)
  library(gridio)
  
  
  # gridinit and mosaic init
  reference <- "c:/temp/gridiotest/makemosaic/dem/" 
  cleanup()
  
  gridinit()
  setwindow(reference)
  
  if(FALSE){ # Launch lockserver
    system("x:/Anthill/package/Locklib/lock_server.exe 3340" , wait=FALSE, 
           intern=FALSE, invisible=FALSE, show.output.on.console=FALSE)
    config("x:/anthill/control")
    launch.gridservers()
  }
  
  
  
  gs <- readgridservers()
  servers <- gs
  
  reference <- "c:/temp/gridiotest/makemosaic/demmosaic/"
  mosaicinit(servers=gs, reference=reference)
  
  tileinit(150, 0)  
  oc <- saveconnections()
  restoreconnections(oc)
  
  # Create a new mosaic
  ingrid <-   "c:/temp/gridiotest/makemosaic/dem"
  outgrid <- "c:/temp/gridiotest/makemosaic/newmosaic3"
  
  
  unlink(outgrid, recursive=TRUE)
  file.exists(outgrid)
  
  gridioverbosity(0)
  for(t in 1:ntiles()){
    settile(t)
    g <- readtile(ingrid, cacheok=TRUE) 
    writetile(g, path=outgrid, as.integer=FALSE, as.mosaic=TRUE)  
  }
  g1 <- readgrid(ingrid)
  g2 <- readgrid(outgrid)
  all.equal(g1, g2)
  
  # setup for line by line
  tileinit(150, 0)
  settile(1)
  
  x <- readtile(ingrid)
  plotextent()
  plot(x, add=TRUE)
  
  path <- outgrid
  buffer=0
  transparent=TRUE
  add=FALSE
  as.integer=FALSE
  na.value=-9999
  as.mosaic=TRUE  
}  # end testing code 


writeblock <-
  function(x, path, buffer=0, transparent=FALSE, add=FALSE, as.integer, 
           na.value=-9999, as.mosaic, desc){
    
    
    #--------------------------------------------------------------------------------------------------#
    #  writeblock   Ethan PlunkettJanuary 2011
    #  
    #  Function to write a grid object (in R) into a block of a grid on disk.  
    #    The type of data to be written is determine by the exisiting grid.  If no grid exists 
    #    than the as.integer flag controls the type of grid that is created (integer or real).
    #    Setting transparent to TRUE allows writing of lapping non-rectangular data, such as watersheds;
    #    only non-NA data will be written.  Setting add to TRUE adds the data in x to the existing grid 
    #    (skipping cells with NA). Add takes precidence over transperent.  This is the grid 
    #    method for the writeblock function and thus will be used automatically when writeblock 
    #   
    #    
    #  Arguments:
    #    x : a grid to write
    #    path : the path to the grid (can be just the name)
    #    buffer : buffer around matrix in cells indicating how many cells to cut from the edges of the 
    #      matrix.
    #    ... : other arguments are passed to writeblock.matrix  and may include:
    #        transparent : if TRUE NA values will not be written to the grid (existing values will persist) 
    #        add : if TRUE the value of the matrix will be added to the grid (NA ells will be skipped).
    #          add takes precedance over transparent.
    #        as.integer : (Optional) If the grid does not exist on disk this determines the type of the 
    #          new grid that is created if the grid does exist on disk this determines how it is written 
    #          to (possibly producing an error if they don't match.  The type is either integer or real 
    #          when as.integer is TRUE or FALSE. If as.integer is omitted the the function will check 
    #          the type of grid on disk prior to writing to it and if the grid is missing by default 
    #          create a real grid (with a warning).
    #        na.value : the value used to tranmit NA values to the C function.  Set it to something else
    #          if there are valid -9999 cells in your grid. On disk and in in R the cells will be 
    #          set to NA; it's only in the middle that this number is used.
    #       desc : (optional) mainly for internal use.  If provided (as when writeblock is called
    #          from writegrid) then we can skip a call to griddescribe in this function.
    #--------------------------------------------------------------------------------------------------#
    
    locking <- anthillrunning()  # If anthill isn't loaded I'm assuming that this is 
      # a single user not operating in parallel and that it's OK to skip the locking.
    if(missing(as.mosaic)) as.mosaic <- .status$as.mosaic
    
    path <- as.character(path)
    path <- gsub("\\\\", "/", path)
    path <- gsub("/$", "", path)
    if(!(length(path)==1 && !is.na(path) && !is.null(path))) 
      stop("write block called with NULL or NA path")
    
    if(missing(desc)) desc <- griddescribe(path, cache = FALSE)
    
    setcache(FALSE)
    if(buffer > 0) x <- crop(x, buffer) 
    
    if(desc$type=="missing" & as.mosaic){
      newmosaic(path=path, as.integer=as.integer)
    } else {
      as.mosaic <- desc$mosaic
      as.integer <- desc$type == "integer"    
    } 
    if(as.mosaic){ 
      if("mosaicinfo" %in% names(desc)){
        md <- desc$mosaicinfo
      } else {
        md <- mosaicinfo(path, lock=locking, cache = FALSE)
      }
      if(is.na(.status$mosaic$rowsize))
        stop("You must call mosaicinit before trying to write to a mosaic.")
      
      # Test that if conforms to the mosaic scheme in memory
      if(!desc$type == "missing"){
        if(!coincide(desc, .status$mosaicwindow)) stop("Mosaic grid doesn't conform to mosaic window.")  
        if(!all(isTRUE(all.equal(.status$mosaic$rowsize, md$rowsize)), 
                isTRUE(all.equal(.status$mosaic$colsize, md$colsize)) ))
          stop("Mosaic grid's rowsize and tilesize don't match the scheme defined by mosaicinit")
      }      
      
      # Loop through panes writing out the overlapping portion
      updated.panes <- rep(FALSE, length(md$panemap))  
      for(pane in which(.status$mosaic$panemap)){  # note use panemap from memory so that we can 
        # add panes that might not have data in the file
        
        y <- panedetails(pane)
        
        # Calculate the range of each object.  Note these are cell centers.
        x.xrange <- c2x(c(1, x$ncol), x)  
        y.xrange <- c2x(c(1, y$ncol), y)
        x.yrange <- r2y(c(x$nrow, 1), x)
        y.yrange <- r2y(c(y$nrow, 1), y)
        
        # If they don't overlap move on to the next pane
        rangeoverlap <- function(a, b) ( max(a[1],b[1]) <= min(a[2], b[2])) 
        if(!rangeoverlap(x.xrange, y.xrange) || !rangeoverlap(x.yrange, y.yrange)) next
        
        
        # calculate the range of the overlap  (still cell centers of overlapping cells)
        xrange <- c(max(x.xrange[1], y.xrange[1]), min(x.xrange[2], y.xrange[2]))
        yrange <- c(max(x.yrange[1], y.yrange[1]), min(x.yrange[2], y.yrange[2]))
        
        # Calculate the extent for the overlap zone
        overlap.extent <- list(
          xll = xrange[1] - x$cellsize * 0.5,
          yll = yrange[1] - x$cellsize * 0.5,
          nrow = round((yrange[2]-yrange[1]) / x$cellsize  + 1),  # call to round added because of rare "misalignment" of grids in the 16th digit. 
          ncol = round((xrange[2]-xrange[1]) / x$cellsize  + 1),
          cellsize = x$cellsize)
        
        # Clip x based on that extent
        out <- gridclip(x, overlap.extent)

        # If there's no data for this pane (all NA) skip writing it
        if(( transparent | add) && all(is.na(out$m)))  next
        updated.panes[pane] <- TRUE
        
        # Set the connection
        setconnection(findconnection(path=path, pane=pane))
        activateconnection()
        
        # Write the block
        ppath <- panepath(path, name=md$name, id=pane, npanes=length(md$panemap) )
        pdir <- gsub("/[^/]*$", "", ppath)
        makedir(pdir, locking=locking)
        startcol <- x2c(out$xll + 0.5 * out$cellsize, list = y)
        startrow <- y2r(out$yll + 0.5 * out$cellsize, list = y) -  out$nrow + 1
        .writeblock(x=out$m, path=ppath, startrow=startrow , startcol=startcol,  buffer=0, 
                    transparent=transparent, add=add, as.integer=as.integer, na.value=na.value)
        
      } # end loop through panes
      
      if(locking){
        get.lock(path)
        on.exit(return.lock(path))
      }
      md <- mosaicinfo(path, lock=FALSE, cache = FALSE) # don't lock because I already have it.
      md$panemap <- md$panemap | updated.panes
      writemosaicdesc(md=md, path=path)
      
      
    }  else { # (not a mosaic) 
      
      # Find the connection that matches the grid (or the reference window if the grid doesn't exist yet)
      if(desc$type == "missing"){
        con <- findconnection(.status$referencewindow, path=path)
        desc <- .status$referencewindow
      } else {
        con <- findconnection(desc, path=path)
      }
      setconnection(con)
      activateconnection()
      startx <- x$xll + .5 * x$cellsize # the center of the first (westernmost) cell
      starty <- x$yll + (x$nrow - .5) * x$cellsize # the center of the first (northernmost) cell
      startcol <- x2c(x=startx, desc)  # in the access window as defined by header
      startrow <- y2r(y=starty, desc)
      
      .writeblock(x$m, path=path, buffer=0, startcol=startcol, startrow=startrow, add=add, 
                  transparent=transparent, as.integer=as.integer, na.value=na.value)     
    } # end else (not a mosaic)
    
    # Remove info on this grid from gridinfo cache (Because writing to it changes it)
    if(path %in% ls(.status$gridinfo))
      rm(list=path, envir = .status$gridinfo)
  }
