writegrid <- function(x, path, as.integer=FALSE, na.value=-9999){
  #--------------------------------------------------------------------------------------------------#
  # Write grid function for a "grid" object (this is our s3 class).
  # Arguments :
  #  x : an obejct of class "grid"
  #  path : the path to write out the grid to.
  #  as.integer : if this is set to TRUE the grid will be written as an integer grid
  #    otherwise it will be written as a double (real).  If it currently contains
  #    real numbers the conversion to integer will round down (floor) the contentents.
  #  na.value : this value is used to transmit NA values to the C code.  Ultimately these
  #    will be written as NA in the grid. The only reason to change it from the default
  #    would be if you have cells with the value -9999 that you want preseved in the grid.
  #  use.old : if this is TRUE the old version of the function will be used (relying on 
  #    edi's writegrid function). If FALSE the new version will be used which relies on 
  #    writeblock thus getting around the memory limitations of writegrid.
  # Note: r normally stores all numeric values (including integers) as doubles thus there's 
  #  no easy test to see if a matrix contains all integers or not.
  #  I could include code to test each value in the matrix (see example in ?integer) 
  #  but that would slow things down.  Instead I'm counting on the user to 
  #  set the as.integer flag to TRUE if they want the grid written as integers.
  #  This is a "grid" method for the overloaded writegrid function thus to call it 
  #  you may simply use writegrid(g) where g is a grid object.
  #--------------------------------------------------------------------------------------------------#
  # Arguments (to C function):
  #  err  (int): error code
  #  grid_name     (char*) : path (optional) and name of the target grid relative to the declared 
  #    root of the grid pool  
  #  y_count       (int)   : number of rows in the grid to write
  #  x_count       (int)   : number of columns in the grid to write
  #  missing_value (int)   : value in grid to be converted into ESRI MISSINGDATA
  #  mtx_grid*  (F8/I4) : pointer to grid matrix for storing the data to write
  #--------------------------------------------------------------------------------------------------#
  
  d <- griddescribe(path)
  if(d$type != "missing") gridkill(path)
  
  if(.status$as.mosaic) 
    newmosaic(path=path, as.integer=as.integer)
  else
    gridcreate(path, as.integer=as.integer)
  writeblock(x, path=path,  transparent = FALSE, add = FALSE, as.integer = as.integer, 
             na.value = na.value, desc=d)  	
  
}

