\name{checkgrid}
\alias{checkgrid}
\title{
function to verify and diagnose problems with grids
}
\description{
This function tests to see if a grid is properly stored, named, and formatted for use with gridio
}
\usage{
checkgrid(x, test = TRUE, pathonly = FALSE)
}


\arguments{
  \item{x}{
The path to a single grid object.
}
  \item{test}{
If \code{FALSE} only preliminary tests will be performed (without using ESRI's API).  If \code{TRUE} the preliminary tests are performed and the grid is described and read from if the prelimanary tests don't reveal problems.  These last tests take more time and are more likely to lead to a hard crash. 
}
\item{pathonly}{ If \code{TRUE} then only the path will be checked. This is called internally by \code{\link{gridcreate}} prior to creating and writing to a grid and allows much more informative error messages.
}

}
\value{
A list, the name of each item is an error condition and its value is a logical indicating whether that error occurred:
  \item{file missing}{\code{TRUE} if the grid directory is missing}
  \item{name too long}{\code{TRUE} if the name of the grid exceeds 13 character}
  \item{is multitiled}{\code{TRUE} if the grid is a multitiled grid (see note below)}
  \item{illegal charater in name}{ \code{TRUE} if the grid includes characters that are not alpha, numeric, '_', or '-'}
  \item{space in path}{ \code{TRUE} if there is a space anywhere in the grid path}
  \item{path too long}{ \code{TRUE} if the full path is longer than 128 characters (see note below)}
  \item{path dangerously long}{ \code{TRUE} if the full path is longer than 115 characters (see note below)}
  \item{info dir missing}{ \code{TRUE} if there is no info directory associated with the grid}
  \item{component files missing}{\code{TRUE} if the grid directory doesn't contain the standard, minimal files: \file{dblbnd.adf}, \file{hdr.adf}, \file{sta.adf}, \file{w001001.adf}, and \file{w001001x.adf} }

The following tests will only be performed and returned if \code{test} is \code{TRUE}, \code{pathonly} is \code{FALSE}, and all the preceding tests have passed.
  \item{failed describe}{ \code{TRUE} if \code{\link{griddescribe}} reports an error}
  \item{grid describe reports missing grid}{\code{TRUE} indicates that \code{\link{griddescribe}} (and thus ESRI's API) report that there is no grid at path \code{x}}
  \item{failed read test}{\code{TRUE} indicates that reading the grid \code{x} produced an error}

This last item will always be present:
\item{problem}{\code{TRUE} if any of the tests reported problems and \code{FALSE} if all tests indicate the grid is OK}
  
} 

\author{
Ethan Plunkett
}
\note{

ESRI grid names are restricted to 13 characters and the full path is restricted to 128 characters.  See: 
\url{https://desktop.arcgis.com/en/arcmap/latest/extensions/spatial-analyst/performing-analysis/output-raster-formats-and-names.htm}
With networked drive the full (not the mapped) path to the drive seems to count against the limit thus I test both for a path longer than 128 (too long) and longer than 115 which is likely to be problematic if you are using a network drive.  Ideally, I would resolve the full name of mapped drives to test, but currently I do not.

ESRI grids always have at a minimum these components: \file{dblbnd.adf}, \file{hdr.adf}, 
\file{sta.adf}, \file{w001001.adf}, and \file{w001001x.adf}.  See:
\url{http://www.digitalpreservation.gov/formats/fdd/fdd000281.shtml}

ESRI grids can be "multitiled" in which case the API gridio relies on will not work.  Multitiled grids have multiple files of the format \file{wXXXXXX.adf} (where the X is numeric).  Generally, this occurs with larger grid file sizes and thus is effected both by the number of cells in the grid and the storage type of the grid. See:
\url{http://www.digitalpreservation.gov/formats/fdd/fdd000281.shtml}
\url{https://trac.osgeo.org/gdal/ticket/1198}

}


\seealso{
  \code{\link{ismultitiled}} checks to see if a grid is multitiled (which is also checked by this function).
  \code{\link{makemosaicpy}} can be used to make a gridio (not ESRI) mosaic from a grid which is one way of getting around ESRI's internal tiling (multitiled grids) so that they can be used with gridio.
}
\keyword{ spatial}

