\name{constrainedsample}
\alias{constrainedsample}

\title{
function to sample points from a data.frame while maintaining a minimum spacing among the sampled points
}
\description{
This function randomly samples points from a dataset while maintaining a minimum spacing among the sampled points. The points can be binned in which case the bins are sampled from evenly - as long as that is geometrically possible. 
}
\usage{
constrainedsample(data, min.dist, xcol = "x", ycol = "y", bincol = NULL, n)
}

\arguments{
  \item{data}{
A dataframe containing information on the points to be sampled
}
  \item{min.dist}{
the minimum required spacing between each point and all other points in the retained sample
}
  \item{xcol, ycol}{
the name of the columns containing x and y coordinates of the points in \code{data}.
}
  \item{bincol}{
  (optional) the name of a column containing bins (strata) for the sampling. selection will occur 
  evenly across bins for as long as possible. If not specified than no bins are used.  
}
  \item{n}{the number of points to select for each bin (or in total if there are no bins.)
}
}
\details{
This function randomly adds to the selection after disqualifying all points within min.dist of the
previously selected points. It attempts to select evenly from all bins by iterating through the bins.
However, it may run out of available points in a given bin prior to reaching the target in which case
that bin will be underpopulated.  If no bincol is specified n indicates the total desired sample size.
In either case if n is not specified the algorithm will proceed until no additional points are available.

Repeated runs will yield different results and possible different numbers of points in the samples.
}
\value{
The function returns a dataframe with the same columns as the input data but with fewer rows.  The
data will be sorted by bin with earlier selections preceding later selections (within each bin).
}
\author{
Ethan Plunkett
}

\examples{

  # Make example data and plot it
  data <- data.frame(x= runif(1000, 0, 1000), y=runif(1000, 0, 1000), 
                     bin=sample(rep(1:5, 200)), id=1:1000)
  min.dist=50
  plot(data[, c("x", "y")], col="grey") # plot the data points
  lines(x=c(0, min.dist), y=c(-25, -25)) # the distance threshold we are using
  
  # Make selection and plot it
  s <- constrainedsample(data=data, min.dist=min.dist, bincol="bin", n=20)
  points(s[, c("x", "y")], col="red")
  
  # Examine selection
  table(s$bin)  
  d <- dist(s[, c("x", "y")])
  min(d)
  if(min(d) < min.dist) stop("No points should be selected less than the min.dist threshold")
  
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ spatial }

