\name{friskcache}
\alias{friskcache}
\title{
function to purge expired grids from the index and the gridcache,  stale copying lines from the index and gridcache, files in the cache that aren't in the index, and grids from the index that aren't in the cache.  Basically it cleans the cache. 
}
\description{
This function purges any records in the gridcache with a status of "copying",  deletes the associated files, checks for and deletes extra files in the cache directory, and deletes rows from the cache index that are not actually in the cache.  Extra directories accumulate when Windows file locking prevents their deletion.  The other problems can arise when threads crash or are interrupted while working with the grid cache.  
}
\usage{
friskcache(freeup = 0, deletecopies = TRUE, getlock = TRUE)
}
\arguments{
  \item{freeup}{ Indicates the amount of space that should be created in the cache in MB.  This is used when \code{friskcache} is called from \code{\link{readblockc}} to free up space for new grids in the cache. Grids that have a status of "copying" and grids that have been read in the preceding hour are both exempt from deletion.  Otherwise the grids with the oldest lastread will be deleted until sufficient space is cleared.
}
\item{deletecopies}{If \code{TRUE} than all girds with status "copying" will be deleted from the disk and cache.  If \code{FALSE} than  grids with status "copying" will be deleted from the cache only if they have been in the index for more than 24 hours - in which case they will be presumed to be a failed copy and deleted.
}

\item{getlock}{  If \code{TRUE} \code{friskcache} will get a cache lock on the machine prior to frisking if \code{FALSE} it will assume that lock is already held.  Either way locks will be obtained on each index file prior to reading it.}

\item{test}{ Passed to \code{\link{checkgrid}} if \code{FALSE} (the default) then checking the grids will be limited to verifying that the info directory and component files are present. If \code{TRUE} then each grid will be tested with \code{\link{griddescribe}} and \code{\link{readblock}}.  These tests will slow down frisking substantially so are off by default.}
}
\value{
Returns \code{TRUE} if \code{freeup} space was made in the cache, \code{FALSE} otherwise.
}

\note{
This functions is intended to be called in 2 ways:

At initial launch: called with freeup = 0, deletecopies = TRUE, getlock = TRUE (when no threads are running yet).  Deletes all grids that are not indexed, removes index entries that have no corresponding grid, and deletes grids/removes entries for all grids that have status "copying".  

From \code{\link{readblockc}}, when space needs to be made to copy a grid: called with freeup = getcacheconfig()$deletesize, deletecopies = FALSE, getlock = FALSE.  Does frisking as above, but only deletes "copying" grids if they are more than an hour old.  Deletes least-recently accessed grids in order to free up at least freeup MB.

It could be called manually in which case deletecopies = FALSE, getlock = TRUE, and freeup = 0 is probably appropriate.

}

\author{
Ethan Plunkett
}

\keyword{ cluster }

