\name{griddescribe, gridtype, gridlist, ismosaic}
\alias{griddescribe}
\alias{gridtype}
\alias{gridlist}
\alias{ismosaic}
\title{
Functions that return information about grids on disk
}
\description{
\code{griddescribe} returns the extent, location, and type of the grid specified by \code{path}.  
\code{gridlist} returns a list of grids in the directory specified by \code{path}.
\code{gridtype} returns the type of grid specified by \code{path}.
\code{ismosaic} returns TRUE if the path points to a mosaic.
}
\usage{
griddescribe(path, getstats = FALSE, cache = TRUE)
gridtype(path, cache = TRUE)
gridlist(path)
ismosaic(path, lock=anthillrunning())
}
\arguments{
  \item{path}{
For \code{griddescribe}, \code{gridtype}, and \code{ismosaic} the path to a grid file on disk.  For \code{gridlist} \code{path} should specify a directory containing one or more grids.
}

 \item{getstats}{
If the grid is a mosaic generally stats aren't calculated. However, if \code{getstats = TRUE} then the min and max will be calculated for the mosaic.  \code{getstats} has no effect on the results from a standard grid.
 }
 \item{lock}{ If TRUE the function locks the directory prior to reading and unlocks after.  Requires anthill to be installed and configured.
 }
 
  \item{cache}{
If \code{TRUE} cached information stored during a prior call to \code{\link{griddescribe}} will be used. If \code{FALSE} then the files will be checked on disk.  Note this is grid information caching in memory which is different from grid caching on the local drive used by grid reading functions.
}
}
\value{

\code{griddescribe} returns a list:
	\item{ncol, nrow }{The number of columns and rows in the grid}
	\item{xll, yll }{The x and y coordinates of the lower left corner of the lower left cell of the grid}
	\item{cellsize }{The size of each cell in map units}
	\item{type }{The type of the grid, either "real" or "integer"}
	\item{min, max, mean, sd }{Summary statistics about the grid as calculated by ESRI.}
  \item{mosaicinfo}{Only if the target is a mosaic, a list as returned by \code{\link{mosaicinfo}}}

\code{gridtype} returns the \code{type} component of \code{griddescribe}.

\code{gridlist} returns a character vector with the name of each grid in the directory. If there are no grids it returns a vector of zero length.

\code{ismosaic} returns a logical TRUE if the path is to a mosaic on disk. FALSE otherwise.



}



\author{
Ethan Plunkett
}
\note{
The summary statistics are calculated by ESRI and stored with the grid; they may not be trustworthy.
If the grid is a mosaic and \code{getstats} is \code{TRUE} then the min and max will be generated based on the min and max of each component grid, other stats can't be calculated from the summary stats for each grid alone and consequently are always NA for mosaic grids.
}

\seealso{
\code{\link{gridkill}}, \code{\link{gridcopy}}
}
\examples{
# gridlist() # list any grids in the current working directory - mustcall gridinit first
}
\keyword{spatial}
