\name{gridinit}
\alias{gridinit}
\title{
Function to initialize the grid server
}
\description{
This function sets up a connection to a gridserver.  It must be called prior to any other functions in this library which interact with grids on disk.
}
\usage{
gridinit(server = NA, port = 3333, log = FALSE, add=FALSE, drive=NA)
}

\arguments{
  \item{server}{
If not NA indicates the name of the server to connect to in server mode.  NA indicates a local connection.
}
  \item{port}{
Specifies to the port to be used.  This is only relevant in server mode.   
}
  \item{log}{
if set to \code{TRUE} a log file will be stored on disk.
}
\item{add}{
if TRUE the connection will be added to prior connections in the connection list. If FALSE any prior connections are replaced with the new connection.  Prior to gridio 1.129 only one connection at a time was
supported and FALSE mimics the behavior of the older library.
}
\item{drive}{
If specified the drive (or beginning of the path) that the gridserver is associated with. This allows establishing connections with several gridservers and then connecting on the fly to the gridserver associated with the path (drive) of the grid that is being read or written.
}

}
\details{
Gridinit sets up a connection to a new server or a new local connection.  If add is FALSE all prior connections are also deleted.  If ADD is TRUE the new connection is added to the list of connections.
All connections must share the same grid extent, cellsize, and alignment. Currently this means the main 
reason you might want to call gridinit with add=TRUE are if (1) you've already called \code{\link{mosaicinit}} or (2)
you want to have multiple connections with the same access window but with varying drives and servers so that, for example reading from the X: drive is done via one server and the w: drive via another.

Note for local access using a single connection (is ideal )
}
\value{
This function is called for its side effects and returns nothing.
}
\author{
Ethan Plunkett
}
\seealso{
\code{\link{setwindow}} or \code{\link{makewindow}} are usually called right after this.
\code{\link{cleanup}} reverses the effect of this call by deleting all connections.
\code{\link{mosaicinit}} is an analogous function for initiating a set of connections for the panes in a mosaic. 
\code{\link{refgridinit}} to initialize connections based on a reference grid or mosaic while \pkg{anthill} is running.
}
\examples{
# gridinit() 
}
\keyword{ spatial }
