\name{gridstats}
\alias{gridstats}
\alias{pgridstats}
\alias{tilestats}
\alias{mergestats}
\title{
  functions to calculate statistics on one grid for classes defined in one or more categorical grids
}
\description{
 these functions calculate statistics on cells in \code{x} for each unique combination of classes defined in \code{by}
}
\usage{
gridstats(x, by, tilesize = 2000, tiles, cacheok = TRUE)
pgridstats(x, by, result.file, owner, name, tilesize = 2000, tiles, cacheok = TRUE, ...)

tilestats(tile, x, by, cacheok = TRUE )
mergestats(x)
}

\arguments{
  \item{x}{ A grid object or the path to a grid on disk.  Or, in the case of \code{mergestats} a list of objects created by calls to tilestats.
}
  \item{by}{
A named list of either grids in memory or paths to grids on disks.
}
  \item{result.file}{
  The path where the results should be created (with \code{\link{saveRDS}}).  Once the project has completed you should use \code{\link{readRDS}} on this file to obtain the results.
}
  \item{owner}{
Your name.
}
  \item{name}{
The project name. 
}
  \item{tilesize}{
The tilesize that you would like to process the landscape in.
}
  \item{tiles}{
Optionally the specific tiles you would like to analyze. If no tiles are specified then the entire landscape is processed.
}
  \item{cacheok}{
Passed to \code{\link{readtile}}
}
  \item{\dots}{
Other arguments to be passed to \code{\link{simple.launch}} such as \code{maxthreads} and \code{priority}.
}
}
\value{
A data.frame the first columns will be named the same as \code{by} and list values from those grids.  The remaining columns will have stats on the cells that fall into each unique category.  NA is treated as a separate grouping value in the \code{by} grids.  In {x} NA values are dropped prior to calculating the statistics but also tallied as a separate statistic.  The count field does NOT include NA's.
}

\note{
\code{tilestats} and \code{mergestats} are not really intended as user functions.  They are both used by \code{pgridstats} and are exported because a user might want to (1) use something other than anthill to run in parallel or (2) combine them with other functions in one large anthill project.
}

\author{
Ethan Plunkett
}
\seealso{
\code{\link{gridtable}} for calculating crosswise counts on categories in one or more grids (an extension of table to one or more grids).
}
\examples{

  # Make dataset (include NA's in all grids)
  a <- as.grid(x = matrix(rnorm(10000, mean = seq(from = 1, to = 3, length.out = 10000)),nrow = 100, ncol = 100 ), xll = 0, yll = 0, cellsize = 30)
  b <- a
  b$m[] <- rep(1:10, each = 1000)
  c <- b
  c$m <- matrix(rep(1:10, each = 1000), nrow = 100, ncol = 100, byrow = TRUE) 
  a$m[2, ] <- NA
  b$m[, 2] <- NA
  c$m[6:15, 6:15] <- NA
  
  
  # Plot
  plot(a)
  plot(b)
  plot(c)

  
  # Calculate stats on grids in memory
  res <- gridstats(x = a, by = list(b= b, c= c))
  
  \dontrun{
  
  # Setup grids on disk
  dir <- tempdir()
  dir.create(dir)
  paths <- paste0(dir, letters[1:3])
  gridinit()
  setwindow(a)
  writegrid(a, path = paths[1])
  writegrid(b, path = paths[2])
  writegrid(c, path = paths[3])
    

  # Calculate stats on grids on disk (using local session)
  res2 <-  gridstats(x = paths[1], by = list(b = paths[2], c = paths[3]))
  standard.cols <- c("min", "max", "count", "sum", "sd", "mean", "countNA")

  # And via anthill
  library(anthill)
  config()
  pgridstats(x = paths[[1]], by = list(b= paths[2], c= paths[3]), 
             result.file = paste0(dir, "results.rds"), owner = "Your Initials", name = "statstest")
  
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
