\name{makeparetokernel}
\alias{makeparetokernel}

\title{
function to make a Pareto kernel
}
\description{
This function created a Pareto kernel for use with \code{\link{kernelsmooth}}.
It is currently inoperable because the POT library it depended on is no longer
supported.  I have kept this help and the function as a place holder.
The previous version of the function is in the example.  The current version 
just throws an error that it is defunct.
}
\usage{
makeparetokernel(scale, shape, max.r = max.r, cellsize)
}
\arguments{
  \item{scale, shape}{
These control the shape of the kernel.  See \code{\link{dgpd}} in the POT library. }

\item{max.r}{
The maximum radius for which which weights are calculated.
}
  \item{cellsize}{
The cellsize of the data to which the kernel will be applied.
}
}
\value{
it returns a square matrix where each cell contains a weight that is a Pareto function of the distance to the center of the kernel.

}
\author{
Ethan Plunkett, Kathy Zeller
}
\note{
The value of the center cell is calculated as 1/scale. This cell has a distance of zero and dpgd(x) approaches 1/scale as x approaches zero but is zero when x is zero.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{makegaussiankernel}}, \code{\link{kernelsmooth}}
}
\examples{
  

\dontrun{



# This function was previously definied as:
makeparetokernel<-function(scale, shape, max.r = max.r, 
                             cellsize) {
  library("POT")
  max.r.cells <- max.r/cellsize
  size = ceiling(max.r.cells) * 2 + 1
  center = ceiling(max.r.cells) + 1
  kernel <- new("matrix", 0, size, size)
  for (i in 1:size) for (j in 1:size) {
    r = sqrt((i - center)^2 + (j - center)^2) * cellsize  # distance in map units
    if (r <= max.r) 
      kernel[i, j] <- dgpd(r,scale=scale,shape=shape,log=FALSE)
  }
  
  kernel[center, center] <- 1/scale  ### We don't want a donut
  # dgpd(x) approaches 1/scale as x approaches zero but is zero when 
  # x is zero.  That's unfortunate beause I'm pretty sure we want 
  #  to include the center cell.
  # This is a hack to give the center cell weight.  It whould work as long as 
  #  the loc argument of dgpd is 0. (which it is here)
  # This generally will put a lot of weight on the center cell.
  
  kernel <- kernel/sum(kernel)
  # This last part deletes the cells at the edge if they are all zero
  if (all(kernel[1, ] == 0, kernel[, 1] == 0, 
          kernel[nrow(kernel),] == 0, kernel[, ncol(kernel)] == 0))
    kernel <- kernel[2:(nrow(kernel) - 1), 2:(ncol(kernel) - 1)]
  return(kernel)
}

k <- makeparetokernel(scale=10, shape=.8, max.r=250, cellsize=30)


# Plot the kernel
image(k)  
plot(k[ , ceiling(nrow(k)/2)])

}


}
\keyword{ spatial}

