\name{mgridpredict}
\alias{mgridpredict}
\title{
function to apply statistical models to gridded data in memory 
}
\description{
This function takes a model fit or fits and a list of grids; generates predictions; and returns those predictions as a list of grids. 
}
\usage{
mgridpredict(fit, grids, na.rm=TRUE, list=NULL,  force=NULL, ...)
}

\arguments{
  \item{fit}{
	A  model fit to base predictions on.
}
  \item{grids}{
	A list of grid objects specifying the data to use to make the predictions.  The names of the list items should match the variable names in the fit object(s).
}
 
  \item{na.rm}{
	If \code{TRUE} then any cell for which there is missing data in a prediction grid will not be passed to the fitted model but will instead receive NA.  If \code{FALSE} then data for all cells will be passed to the model. If the \code{list} argument is used (there are more than one fit) then this can either be a single value to be used for all models or a vector of the same length as \code{list}. 
}
  \item{list}{
	A list of fitted objects may be passed with this argument (one for each fit in list).  If list is specified the fit argument is ignored. The names of the grids in the return list will math the names of the fits in this list.
}
  \item{force}{
	A named list containing variable names and associated values for variables that will be forced (to a single value).  We needed this to force a sample effort covariate to a constant value when making predictions with new data.  In most cases it will not be needed.
}
  \item{\dots}{
  Other arguments to be passed to the predict method(s). 
}

 
}

\value{
Thus function returns a single grid if the fit argument is used and a list of grids if the list argument is used. 
}

\author{
Ethan Plunkett
}
\note{

Data is passed to the \code{\link{predict}} method for the \code{fit} object via the \code{newdata} argument (to predict).  If that is not the right argument for your fit than this will not work for you.

If variables needed by fit are missing or misnamed an error will occur but it may not be very informative.
}


\seealso{
\code{\link{gridpredict}}  and \code{\link{tilepredict}} are similar but perform predictions on grids on disk where this function performs predictions on grids in memory
}
\examples{

# make some small grids
b <- a <-  list(m=matrix(1:20, nrow=4, ncol=5), xll=0, yll=0, nrow=4, ncol=5, cellsize=1)
class(a)  <- class(b) <- c("grid", class(a))
b$m <- a$m + rnorm(20,sd=1)
y <- a 
y$m[,] <- a$m[,] + b$m[,] + rnorm(20, sd=.5)

# make a dataframe out of the grids
d <- data.frame(a=as.vector(a$m), b=as.vector(b$m), y=as.vector(y$m))

# make a linear model
fit <- lm(y~a+b, data=d)
summary(fit)

# and a linear model with a zero intercept
fit2 <- lm(y~a+b, data=d)

# Make a prediction using a single fit
pred <- mgridpredict(fit=fit, grids=list(a=a, b=b))

# Make two predictions using both fits
pred <- mgridpredict(grids=list(a=a, b=b), list=list(lm=fit, lm.no.intercept=fit))

# Plot the prediction for the full linear model
plot(pred[[1]])

# Make a prediction using force
pred <- mgridpredict(fit=fit, grids=list(a=a), force=list(b=10))


}
\keyword{ spatial }

