\name{mosaicinit}
\alias{mosaicinit}
\title{
function to initialize gridio to work with mosaic grids
}
\description{
This function defines the mosaic scheme.  It must be called before reading/writing mosaic grids.  
It adds connections for each pane in the mosaic to the connection list so that gridio can read and write from mosaic grids.
}
\usage{
mosaicinit(reference,  servers,  rowsize, colsize, panemap, log=FALSE, desc)
}
\arguments{
  \item{reference}{ (optional) either: 1. the path to a mosaic which is used to define rowsize, colsize, window, and panemap (all from mosaic descriptor); or 2. the path to a standard grid with the same extent of the mosaic which populates window and panemap (if not supplied as an argument).  When generating a panemap from an standard refrence grid panes that are composed entirely of NA and/or 0 are skipped.)
}
  \item{rowsize, colsize}{The number of rows and columns of cells that are included in each pane. Optional (and not used) if reference is a mosaic.
}
  \item{panemap}{ The panemap, which indicates which panes are included in the mosaic.  Only used if reference isn't a mosaic.
}
  \item{servers}{
   The body of gridservers.txt (used to populate servers and ports). Leave unspecified to use local servers. See \code{\link{makemosaic}} which also creates a template gridservers.txt and \code{\link[anthill]{readgridservers}} (in anthill) which returns the gridservers.txt from the anthill directory.
}

  \item{log}{
If TRUE then servers will be initiated with logging enabled.
}
\item{desc}{ The description of the reference grid (as returned by griddescribe). This is optional and intended for use within parent functions that have already called griddescribe to reduce calls to griddescribe.
}

}
\details{
Mosaic and extent input are defined either with 1. a mosaic reference grid. 2. with 
a standard reference grid, rowsize, and colsize, with or without a panemap, or 3. based on the previosly defined extent (from a call to gridinit), rowsize, colsize, and panemap.

Server information comes from \code{servers} a data.frame with required columns: drive, server, port, ncol, nrow, xll, yll, and cellsize. See readgridservers in the anthill package. For local connections \code{servers} can be omitted. 

}
\value{
This function returns nothing; it is called for its side effect of adding connections for each pane to the connection list.
}
\author{
Ethan Plunkett
}

\seealso{
See \code{\link{gridinit}} for adding connections to standard (non-mosaic) grids.
See \code{\link{refgridinit}} for adding connections based on a reference grid or mosaic when \pkg{anthill} is running.

If you are setting up a new mosaic scheme the general procedure is to (1) call \code{\link{makemosaic}} (2) Edit gridservers.txt and (if using anthill) add it to the anthill directory, possibly appending it to previously defined gridservers.  (3) Call this function using the grid created in (1) as \code{reference} and the data from (2) as the \code{servers} argument.
}
\examples{

# see makemosaic

}

\keyword{ spatial}

