\name{nibbleNA}
\alias{nibbleNA}
\alias{nibbleNA.grid}
\alias{nibbleNA.matrix}
\title{
function to replace NA values in a grid with the mode of the neighboring values
}
\description{
This function replaces NA values with the mode of the 8 closest neighbors.
NA cells that are surrounded by NA will be unaltered but the function can be reapplied to iteratively
nibble values into a patch of NA, filling it in from the edges inward.
}
\usage{
nibbleNA(x)
\method{nibbleNA}{grid}(x)
\method{nibbleNA}{matrix}(x)
}
\arguments{
  \item{x}{ A grid or matrix with some NA values
}
}

\value{
it returns an object of the same class as  x (either a grid or matrix) in which NA cells that abut cells
with values will have the mode of the neighboring values. Ties are broken deterministically based on position in this order: right, left, bottom, top, top left, bottom right, bottom left, and  top right.  
}
\author{
Ethan Plunkett
}
\note{
1. This function should only be applied to categorical grids where cells are likely to have identical values.
Replacing NA in continuous grids would be better done with a kernel smooth.  See \code{\link{calckernel}} and \code{\link{gaussiansmooth}} for a couple of possibilities.

2. This function currently always uses all 8 neighbors.

3. Currently this works only on grids or matricies in memory.  It would be possible to write a version that works on grids on disk but I haven't done that yet.
}

\seealso{
\code{\link{eliminatesmallpatches}} uses this function to eliminate patches below a certain size threshold.
}
\examples{
  set.seed(1)
  g <- as.grid(matrix(runif(n = 48)> .7, 6, 8), xll = 0, yll = 0, cellsize = 10)
  g$m[2, 2] <- NA
  plot(g)
  plot(nibbleNA(g))
}
\keyword{spatial }
