\name{overwrite}
\alias{overwrite}
\alias{gridoverwrite}
\alias{tileoverwrite}
\title{
 functions to overwrite every cell in a grid or tile with a single value
}
\description{
These functions overwrite every cell in either the tile or grid with the specified value.   
}
\usage{
gridoverwrite(path, value, tilesize = 2000)
tileoverwrite(path, value, tile)
}
\arguments{
  \item{path}{
The path to the grid. It can either be absolute or relative the path specified when the gridserver was initiated (see \code{\link{gridinit}})
}
  \item{value}{
The value which will be written to every cell in the tile or grid.
}
  \item{tilesize}{
The tilesize to use while processing the grid.
}
 \item{tile}{
The tile to overwrite.
}

}
\details{
Overwrite grid calls tileinit disturbing any previously set up tile scheme.  Overwrite tile requires that a tilescheme already be setup.
}
\value{
Nothing is returned.
}
\author{
Ethan Plunkett
}
\seealso{
\code{\link{gridcreate}} which produces a new grid full of NA values.
}
\examples{


# Make a temporary directory to create new grids in
dir <- tempdir() # get temporary directory
dir.create(dir)

cleanup() # disconnect from any prior gridservers 
gridinit() # initialize local gridserver with base path in temporary dir
setwindow(list(nrow=200, ncol=200, xll=0, yll=0, cellsize=30)) # setwindow 

temp <- paste(dir, "/temp", sep="")


gridcreate(temp)  # new grid full of zeros
g <- readgrid(temp)
g$m[1:10, 1:10]
gridoverwrite(temp, 0)
g <- readgrid(temp)
g$m[1:10, 1:10]

cleanup()


}
\keyword{ spatial}

