\name{plot.tilehist}
\alias{plot.tilehist}
\title{
Function to plot the results of a call to tilehist 
}
\description{
This function plots histograms from data compiled for an entire grid one tile at a time.
}
\usage{
\method{plot}{tilehist}(x, which, ...)
}
\arguments{
  \item{x}{
The result of a call to \code{\link{tilehist}}.
}
  \item{which}{
If the original call to \code{tilehist} contained a class grid than this specifies which class to plot. 
}
  \item{\dots}{
Other arguments to be passed to \code{\link{plot.histogram}}.
}
}
\details{
This function extracts data from the an object of class "tilehist" (created by a call to \code{\link{tilehist}}) and formats it to look like the output to a call to \code{\link{hist}} and finally submits it to \code{\link{plot.histogram}}. Like \code{\link{hist}} it invisibly returns the data used in the plot as an object of class "histogram".
}
\value{
It invisible returns a "histogram" object.  See the value section of \code{\link{hist}} for details. 
}
\author{
Ethan Plunkett
}

\seealso{
\code{\link{tilehist}} \code{\link{hist}}, \code{\link{plot.histogram}}
}
\examples{

### Setup a temporary directory with a sample grid in it 
# Get path to example dem grid (included with package)
require(gridio)
datapath <- system.file("exampledata", package="gridio")  # grid path to example grid
datapath <- shortPathName(datapath)
datapath <- paste(datapath, "/.", sep="")

# Make a temporary directory to write new grids to
dir <- tempdir() # get temporary directory
dir.create(dir)

# Copy example data into temporary directory
file.copy(datapath, dir, recursive=TRUE)
# system(paste("open", dir)) # if you want to look at contents of temporary directory
###  Done setting up directory


dem <- paste(dir, "/dem", sep="") # path to dem file.
groupspath <- paste(dir, "/groups", sep="")

cleanup() # disconnect from any prior gridservers 
gridinit()
setwindow(dem) # setwindow to dem file

### Make up a grouping grid
g <- readgrid(dem)
groups <- g
groups$m[,] <- 1
groups$m[1:groups$nrow > 150,] <- 3
groups$m[,1:groups$ncol > 150] <- groups$m[,1:groups$ncol > 150] +1 
groups$m[g$m > 200] <- 5
writegrid(groups, groupspath, as.integer=TRUE)


# Note these are trivial example because the grid can easily fit in memory.  
# I'm using a excessively small tilesize so that there are multiple tiles but I 
# recommend using a tilesize of 2000 or more. I'm not sure where the optimum is.

# Call with a class (grouping) grid.
th <- tilehist(dem, groupspath, tilesize=100)
plot(g)  # the dem 
plot(groups) # the arbitrary grouping
plot(th, "1") # this is the group in the northwest of the area
plot(th, "5")  # this is the group made up of all the values greater than 200.
plot(th, "5" , freq=FALSE) # density plot of group 5

# call with no grouping grid (histogram of entire grid)
th <- tilehist(dem, tilesize=200) 
par(mfrow=c(2, 1))
d <- plot(th)
hist(g$m, breaks=d$breaks) # compare to hist of entire grid with same breaks
gridkill(c(dem, groupspath))  # delete grids
cleanup()
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
