\name{plotextent, plotbounds}
\alias{plotextent}
\alias{plotbounds}
\title{
Function to plot the extent of the access window and the extent of a grid
}
\description{
This function plots the extent of the current access window, the boundaries between tiles (if \code{\link{tileinit}} has been called), and if the \code{grid} argument is not missing the extent of \code{grid}.
}
\usage{
plotextent(grid, list, subtiles=TRUE)
plotbounds(x, border, lwd, ...)
}
\arguments{
  \item{grid}{
  (optional) either a \code{\link{grid}} object, a path to a grid on disk, a list containing the
  items xll, yll, nrow, ncol, cellsize that define an extent,  or an object of a spatial class 
  defined in \pkg{sp} on which the function \code{\link{bbox}} can be called.  If grid is included then 
  a red box will be plotted representing its bounding box. 
}
  \item{list}{ This is here for backwards compatibility. It's an alternative way of specifying grid.
}
  \item{subtiles}{
FALSE prevents plotting of subtile boundaries; if TRUE subtile boundaries will be plotted if they exist.  
  }
\item{x}{
  either a \code{\link{grid}} object, a path to a grid on disk, a list containing the
  items xll, yll, nrow, ncol, cellsize that define an extent,  or an object of a spatial class 
  defined in \pkg{sp} on which the function \code{\link{bbox}} can be called.  
}
\item{border}{
  the color to use for the border of the bounding box
}
\item{lwd}{
the line weight for the border of the bounding box
}
\item{...}{
Other arguments to be passed onto \code{\link{polygon}}
}
}
\details{
\code{plotextent} plots the extent of the current access window in black, tile boundaries in gray, 
 and the extent of \code{grid} (if supplied) in red.

\code{plotbounds} adds the bounding box of x to an existing plot.
}
\value{
These functions return nothing.
}
\author{
Ethan Plunkett
}

\seealso{
\code{\link{plot.grid}}, \code{\link{setwindow}}, \code{\link{tileinit}}, and \code{\link{getbounds}}
}
\examples{
  x <- list(xll=0, yll=10, nrow=200, ncol=300, cellsize=10)
  gridinit()  
  setwindow(x)
  plotextent()
  tileinit(80, 0)
  plotextent()

  settile(8)
  plotbounds(tiledetails(), border="blue")
  
  subtileinit(80, buffer=20, 200)
  plotextent()
  plotextent(x)
  
}
\keyword{ spatial }
