\name{read and write tiles}
\alias{readtile}
\alias{writetile}
\alias{writetile.grid}
\alias{writetile.matrix}
\title{
Functions to read and write the current tile from or to the specified grid.
}
\description{
These functions read and write the current tile from or to the grid specified in path.  They rely on the tile scheme and current tile indicies, which are set by \code{\link{tileinit}}, \code{\link{subtileinit}}, and \code{\link{settile}} and can be viewed by calling  \code{\link{tilescheme}}.
If the buffer specified in \code{\link{tile.scheme}} is not zero than extra cells are read in and deleted prior to writing as specified by \code{coreonly} by default the buffer will be included when reading and excluded when writing. 
}
\usage{
readtile(path, coreonly=FALSE, as.matrix = FALSE, na.value = -9999, cacheok = FALSE, ...)
writetile(x, path, coreonly=TRUE, ...)

}
\arguments{
 \item{x}{
an object storing the data to write to the grid.  It should either be a \code{\link{grid}} object or a matrix. The extent should match that of the current tile (either with or without the buffer).
}
  \item{path}{
The path of the grid to read or write from relative to the base directory specified when \code{\link{gridinit}} was first called or an absolute path.
}
 \item{coreonly}{if TRUE then only the core of the tile is read or written.}
  \item{as.matrix}{
If \code{TRUE} the function returns a matrix rather than an \code{grid} object.
}
  \item{na.value}{
This value is used to represent NA values in communications with the underlying C code.  These values are converted back into \code{NA} in the objects \code{readtile} returns and in the grids (on disk) that \code{writetile} writes to.  The only reason to set this to something other than the default -9999 is if there are legitimate (non-NA) -9999 values in any cells in your grid.
}
 
 \item{cacheok}{if TRUE than this grid is eligible for caching (if caching is configured). See \code{\link{cacheinit}}.
}
 
  \item{\dots}{Arguments to be passed to the \code{\link{writeblock}} such as:

\describe{
  \item{\code{transparent}}{If \code{TRUE} \code{NA} values will be skipped and existing values for those cells will be retained in the grid. Defaults to \code{FALSE}.}
  
  \item{\code{add}}{If TRUE non-NA values will be added to the existing grid. Defaults to \code{FALSE} }
  
  \item{\code{as.integer}}{This specifies if the grid is (or should be) integer (\code{TRUE}) or real
  (\code{FALSE}).  In both readtile and writetile specifying \code{as.integer} is optional but if it
  is specified the function will assume that the grid on disk is of the type indicated saving an 
  extra check but possible producing an error if the type does not match.  Additionally in 
  \code{writetile} \code{as.integer} also indicates what type of grid should be created if the grid 
  does not already exist on disk. In this case if \code{as.integer} is missing and the grid does not
  exist than it will by default create a new real grid and will issue a warning that it is doing so.
  }
 }

}
}

\details{
\code{\link{gridinit}}; either \code{\link{setwindow}} or \code{\link{makewindow}}; and either
\code{\link{tileinit}} or \code{\link{subtileinit}} should be called prior to these functions. 
If \code{x} only includes the core of the tile and \code{coreonly=FALSE} than \code{writegrid} 
will throw an error.
}
\value{
\code{writetile} returns nothing.  \code{readtile} returns an object containing information about the current tile and (by default with \code{coreonly=FALSE}) the buffer of additional cells around that core; whether it is a matrix or a grid depends on the argument \code{as.matrix}.
}
\author{
Ethan Plunkett
}

\seealso{
Necessary for set up prior to calling these functions: \code{\link{gridinit}}, 
\code{\link{setwindow}},and either \code{\link{tileinit}} or \code{\link{subtileinit}}

Other means of reading and writing grids:
  \code{\link{readblock}}, \code{\link{writeblock}}, 
  \code{\link{readgrid}}, and \code{\link{writegrid}}
  
For a working example usage see \code{\link{readgrid}}.
}

\keyword{ spatial }
