\name{savegridinfo, restoregridinfo, cleargridinfo}
\alias{savegridinfo}
\alias{restoregridinfo}
\title{
functions to save and restore gridinfo
}
\description{
These functions save and restore the grid information cache.
}
\usage{
savegridinfo()
restoregridinfo(x)
cleargridinfo()
}

\arguments{
  \item{x}{
The result of a prior call to savegridinfo containing the grid information to be restored.
}
}
\details{
These functions are used to capture and restore the grid info cache. The anticipated use is to allow for caching grid information prior to a parallel run and then restoring it within each node of the parallel run.  
}
\value{
\code{savegridinfo} returns a list of grids and their associated information suitable for use with \code{restoregridinfo}.  \code{restoregridinfo} restores \code{x} to the gridinfo cache and returns nothing.
\code{cleargridinfo} clears the cache and returns nothing.
}
\author{
Ethan Plunkett
}
\note{
Generally gridinfocaching should work seamlessly in the background.  \code{\link{griddescribe}} handles most of the caching and retrieving information from the cache and will use the cached information unless specifically asked not to.
All functions that read from grids create and use information in the cache while functions that write and delete grids clear information on the grid from the cache and inspect the grid on disk.  Thus, actions that would make cached information obsolete automatically remove that information from the cache. 

However, occasionally, the cached information will become out-of-date either because the grid has been changed by some other process or because an out-of-date cache was restored.  In this case clearing the cache is advisable via \code{cleargridinfo}.  One common such occurence would be after deleting a grid manually (instead of via \code{\link{gridkill}}).

\code{savegridinfo} and \code{restoregridinfo} are designed for use in parallel computing.  
If \code{\link{griddescribe}} is called ahead of time on the grids of interest then the cache can be saved prior to running in parallel and restored on the nodes performing the task.

gridio also implements caching of grids from a networked drive onto a local drive to speed read operations.  This is independent from gridinfo caching; see \code{\link{cacheinfo}} as well as the \code{cacheok} arguments to \code{\link{readgrid}} and \code{\link{readtile}}.

}


\seealso{
\code{\link{griddescribe}} and \code{\link{mosaicinfo}} add to and utilize the cached grid information.
}


\keyword{ spatial} 
