\name{shapefiles, writeshape, readshape}
\alias{shapefiles} 
\alias{writeshape} 
\alias{readshape} 

\title{
functions to write and read shapefiles
}
\description{
These functions are convenience wrappers to functions in \pkg{rgdal}. They allow you to read and write shapefiles without breaking up the path into components as required by the functions they call. 
}
\usage{
writeshape(obj, file, ...)
readshape(file, ...)
}

\arguments{
  \item{obj}{
An object of as class defined in the \pkg{sp} package. 
}
  \item{file}{
The full path to the shapefile to be read or written. The ".shp" extension is optional.
}
  \item{\dots}{
Other arguments to be passed to \code{\link[rgdal]{writeOGR}} and \code{\link[rgdal]{readOGR}}. These functions both supply  \code{dsn} and \code{layer} arguments.  \code{writeshape} also supplies the \code{obj} and \code{driver} arguments. 
}
}
\value{
\code{writeshape} doesn't return anything.  \code{readshape} returns an object of a class defined in the \pkg{sp} package.  
}
\author{
Ethan Plunkett
}
\examples{

library(gridio)
library(rgdal)

# Make SpatialPointsDataFrame
pts <- data.frame(x= runif(20, 1, 1000), y =runif(20, 1000, 2000), a=1:20)
coordinates(pts) <- c("x", "y")

file <- tempfile()
writeshape(pts, file=file)  #  write to a shapefile
a <- readshape(file)        # read the shapefile

file.remove(paste(file, c(".shp", ".dbf", ".shx" ), sep=""))  # cleanup


}

\seealso{
\code{\link[rgdal]{readOGR}}, \code{\link[rgdal]{writeOGR}}
}

\keyword{ spatial}

