\name{stitchpy}
\alias{stitchpy}
\alias{batchstitch}

\title{
functions to stitch together the components of a mosaic into a single grid
}
\description{
These function make single grids out of a mosaics.
}
\usage{
stitchpy(mosaic, complete, reference, python.path = "C:/Python26/ArcGIS10.0/python.exe", script.path, pyramids = TRUE)
batchstitch(x, reference, ...)
}

\arguments{
  \item{mosaic}{
The path to a mosaic.  This is the root directory of a mosaic as created and used by gridio (see \code{\link{makemosaic}})
}
  \item{complete}{
The path to the complete, output grid to be created.
}
  \item{reference}{
A path to a reference grid that defines the extent of the output grid created by make mosaic.
}
  \item{python.path}{
The path to the python executable on the system.  It is currently set to work with ArcGIS 10.0. 
}
  \item{script.path}{
This argument is for package development, not for end user use. This is the path to a template python script to use instead of the standard script included in the package.
}
  \item{pyramids}{
If TRUE (the default) the stitch function builds pyramids on the complete grid based on nearest neighbor interpolation for integer grids and bilinear interpolation for real grids.  
}
\item{x}{A vector of paths to mosaics.}
\item{...}{Other arguments to be passed to \code{stitchpy} such as \code{script.path} and \code{pyramids}. }
}
\details{
These functions require ArcGIS and sometimes fail on network drives.

\code{stitchpy}  writes a python script to the mosaic directory and then runs the python script to stitch together a complete grid from the mosaic.  In the process is also creates a raster catalog in a geodatabase, and an \file{.amd} (ESRI mosaic) file,  both within the mosaic directory.  These can be used to display the mosaic as a unit.  

If the python script fails you may get a more informative error message by running it directly. Look for it in the mosaic director.
}
\value{
\code{stitchpy} returns nothing.  

\code{batchstitch} returns a dataframe with columns:
\describe{
\item{\code{mosaic}}{the name of the input mosaic (from \code{x})}
\item{\code{error}}{\code{TRUE} if an error occurred or the mosaic could not be stitched, \code{FALSE} otherwise}
\item{\code{message}}{"A description of the outcome."}
\item{\code{complete}}{"The path where the stitched grid was created or failed to be created"}
}
}
\note{
As of gridio 1.171 (May 2, 2014) \code{stitchpy} creates a log file within the mosaic directory of every stitch operation on the mosaic. If the stitched grid already exists \code{batchmosaic} checks to see if (based on the log) the grid was created before or after the last edit to the mosaic and skips stitching grids that are up-to-date.  However, any grid stitched with an older version of this package will not be in the log and thus manifest as out-of-date regardless of its status.
}

\author{
Ethan Plunkett
}


\seealso{
\code{\link{launchbatchstitch}} uses anthill to run stitching on another computer, possibly in parallel.
\code{\link{makemosaic}} does the opposite of stitching.
}
\keyword{ spatial}
