

# Generate test data
library(gridio)
library(sp)
set.seed(1)
n <- 15
x <- runif(n, 0, 50)
y <- runif(n, 0, 50)
z <- sample(x=c(0,0, 1), replace=TRUE, size=n)

a <- data.frame(x,y, z)
coordinates(a) <- c("x", "y")  # convert to SpatialPointsDataFrame


# Test with no refgrid gaussianinterpolate  using buffer and cellsize 
g <- gaussianinterpolate (x=a, sd=5,max.r=300, data.col="z", buffer=0, cellsize=10)

# Plot results
if(FALSE){
plot(g)
cols <- rgb(.5, 0, 0, (z - min(z) + .1 * (max(z)- min(z)))/(1.1 * (max(z)-min(z))) ) 
cex <- (z - min(z) + .5 * (max(z)- min(z)))/(1.5 * (max(z)-min(z))) *2
points(x, y, col=c("red", "green")[z+1], pch=16, cex=cex) 
}


# define extent 
extent <- list(xll=0, yll=0, cellsize=10, nrow=5, ncol=5)

cleanup()
gridinit()
setwindow(extent)

# test using a list as the refgrid
g <- gaussianinterpolate (x=a, sd=5,max.r=300, data.col="z", refgrid=extent)

# test writing a grid to disk
dir <- tempdir() # get temporary directory
if(!file.exists(dir)) dir.create(dir)
path <- paste(dir, "/test", sep="" )
gaussianinterpolate (x=a, sd=5,max.r=300, data.col="z", refgrid=extent, path=path)

# Test using a grid on disk as the refrence grid
g2 <- gaussianinterpolate (x=a, sd=5,max.r=300, data.col="z", refgrid=path)
g3 <- readgrid(path)

plot(g3)






