# test swap
library(gridio)

# No NA values - all values in matrix present in "original"
x <- matrix(rep(1:25, each=2), 5, 10)
desired.result <- x*3
o <- 1:25
r <- o *3
x2 <- swap(x, o, r)
if(!all.equal(desired.result, x2)) stop("Swap with no NA's and all values present didn't work")


# No NA values - missing values in original
o <- 1:10
r <- o*3
desired.result <- x*3
desired.result[!x %in% o] <- NA
x2 <- swap(x, o, r)
if(!isTRUE(all.equal(desired.result, x2))) stop("Swap with no NA's and incomplete original didn't work")



# With NA values in matrix - all values in matrix present in "original"
o <- 1:25
r <- o *3
x[1, 1] <- NA
desired.result <- x*3
desired.result[1,1] <- NA
x2 <- swap.matrix(x, o, r)
if(!isTRUE(all.equal(desired.result, x2))) stop("Results not as expected with NA value")

# with NA value in matrix - and missing values in "orginal"
o <- 1:10
r <- o*3
desired.result[!x %in% o] <- NA
x2 <- swap.matrix(x, o, r)
if(!isTRUE(all.equal(desired.result, x2))) stop("Results not as expected with NA value")

# with NA value in matrix - and missing values in "orginal" using na.value argument
nv <- 0 # na.value
nm <- NA # no match
desired.result <- x*3
desired.result[is.na(x)] <- nv
desired.result[!x %in% o & !is.na(x)] <- nm
x2 <- swap.matrix(x, o, r, na.value=nv, no.match=nm)
if(!isTRUE(all.equal(desired.result, x2))) stop("Results not as expected with NA value")


# with NA value in matrix - and missing values in "orginal" using na.value argument and no.match argument
nv <- 0 # na.value
nm <- 200 # no match
desired.result <- x*3
desired.result[is.na(x)] <- nv
desired.result[!x %in% o & !is.na(x)] <- nm
x2 <- swap.matrix(x, o, r, na.value=nv, no.match=nm)
if(!isTRUE(all.equal(desired.result, x2))) stop("Results not as expected with NA value")


# With NA in original and using no.match argument
o <- c(o, NA)
r <- c(r, 0)
nv <- NA # na.value  # NOTE this isn't used because the NA in original is used first.
nm <- 200 # no match

desired.result <- x*3
desired.result[is.na(x)] <- 0
desired.result[!x %in% o & !is.na(x)] <- nm
x2 <- swap.matrix(x, o, r, na.value=nv, no.match=nm)
if(!isTRUE(all.equal(desired.result, x2))) stop("Results not as expected with NA value")








